/* For D3 graph visualizations */

.line {
    fill: none;
    stroke: steelblue;
    stroke-width: 2px;
}

.circle {
    fill: steelblue;
    stroke: white;
    stroke-width: 1px;
}

.circle:hover {
    fill: lightblue;
    stroke: steelblue;
    stroke-width: 2px;
}

.second.line {
    stroke: seagreen;
}

.second.circle {
    fill: seagreen;
}

.second.circle:hover {
    fill: lightgreen;
    stroke: seagreen;
}

.dense.circle {
    stroke: none;
}

.dense.circle:hover {
    stroke: none;
}

.area {
    fill: lightblue;
}

.legend {
    font: 12px sans-serif;
}
rect {
    stroke: none;
}

.refline {
    fill: none;
    stroke: gray;
    stroke-width: 1px;
}

.reftext {
    font-size: 14px;
    font-weight: normal;
}

.reftext.sub {
    font-size: 10px;
}

.axis text {
    font: 10px sans-serif;
}

.axis path,
.axis line {
    fill: none;
    stroke: black;
    shape-rendering: crispEdges;
}

.xbar.axis path {
    display: none;
}

.graphtitle {
    font-size: 18px;
    font-weight: bold;
}

.graphtitle.bignum {
    font-size: 55px;
}

.axistitle {
    font-size: 16px;
    font-weight: bold;
}

.d3-tip {
    line-height: 1;
    padding: 6px;
    background: black;
    color: white;
    border-radius: 4px;
    font: 12px sans-serif;
    text-align: center;
}

.cloudtext {
    font-family: Impact;
    font: Impact;
    pointer-events: all;
}
