<h1 class="ui dividing header">Keyboard Shortcuts</h1>

<div class="content">
<table class="ui very basic table"><tbody>
  <tr>
    <td class="right aligned"><div class="ui basic label">s</div></td>
    <td>focus <strong>s</strong>earch bar (<div class="ui very tight label">enter</div> to select, <div class="ui very tight label">▲ / ▼</div> to change selection)</td>
  </tr>
  {% for collection in site.collections %}
  {% unless collection.label == 'posts' %}
  {% capture label %}{{ collection.label | downcase }}{% endcapture %}
  {% capture key %}{{ label | split: '' | first }}{% endcapture %}
  <tr>
    <td class="right aligned"><div class="ui basic label">g {{ key }}</div></td>
    <td><strong>g</strong>o to <strong>{{ key }}</strong>{{ label | remove_first: key }}</td>
  </tr>
  {% endunless %}
  {% endfor %}
  <tr>
    <td class="right aligned"><div class="ui basic label">h</div></td>
    <td>toggle this help (<div class="ui very tight label">esc</div> also exits)</td>
  </tr>
</tbody></table>
</div>
