---
layout: compress
---

<!doctype html>
<html lang="en">

<head>
<meta charset="utf-8">
<meta name="viewport" content="width=device-width, initial-scale=1">
<title>{{ page.title }}</title>
<style>svg.icon{width:1em;height:1em}</style>
<link rel="preload" as="style" href="{{ site.baseurl }}/assets/css/site.css" onload="this.onload=null;this.rel='stylesheet';">
<noscript><link rel="stylesheet" href="{{ site.baseurl }}/assets/css/site.css"></noscript>
<script>
{% include scripts/loadcss/loadcss-2.0.1.min.js %}
</script>
<script src="{{ site.baseurl }}/assets/js/site.js"></script>
<link rel="icon" href="{{ site.baseurl }}/favicon.png">
</head>

<body>
{{ content }}
</body>

</html>
