<div id="site-search" class="ui fluid search">
  <div class="ui inverted transparent left icon input" style="color:#CCC">
    {% include icon.liquid id='magnifier' %}
    <input class="prompt" type="text" placeholder="search...">
  </div>
  <div class="results"></div>
</div>
