<!-- jQuery first, then Bootstrap JS. -->
<script src="https://ajax.googleapis.com/ajax/libs/jquery/2.1.4/jquery.min.js"></script>
<script src="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.5/js/bootstrap.min.js"></script>
<script async id="twitter-wjs" src="https://platform.twitter.com/widgets.js"></script>

<script type="text/javascript">
$('.filterBtnGroup button').on('click', function(filterContent) {
    $('.filterBtnGroup button').attr('disabled', false);
    $(this).attr('disabled', true);
    var tag = $(this).text();
    $('.all').hide();
    $('.' + $(this).attr('id')).fadeIn();
    filterContent.preventDefault();
});
if (document.getElementById('allB')){
    document.getElementById('allB').click();
}
</script>

{% include google_analytics.html %}
