---
layout: page
---

<a style="position:absolute; top:10px; padding-left:10px; padding-bottom:10px" href="{{ site.baseurl }}/">< back</a>
<h2>{% if page.heading %}{{ page.heading }}{% endif %}</h2>

<script src="https://ajax.googleapis.com/ajax/libs/d3js/5.16.0/d3.min.js" charset="UTF-8"></script>
<script type="text/javascript" src="{{ site.baseurl }}/assets/js/dependencies/d3-tip/1.0/d3-tip.js"></script>
<script type="text/javascript" src="{{ site.baseurl }}/assets/js/dependencies/d3-v4-cloud/1.2.2/build/d3.layout.cloud.js"></script>
<script type="text/javascript" src="https://unpkg.com/d3-simple-slider@1.8.0/dist/d3-simple-slider.min.js"></script>
<script type="text/javascript" src="{{ site.baseurl }}/assets/js/dependencies/helpers.js"></script>

<link rel="stylesheet" type="text/css" href="{{ site.baseurl }}/assets/css/graphstyle.css" />

<script>
// Global chart standards
var stdTotalWidth = 700,
    stdTotalHeight = 600;
var stdMargin = { top: 40, right: 40, bottom: 40, left: 40 },
    stdWidth = stdTotalWidth - stdMargin.left - stdMargin.right,
    stdHeight = stdTotalHeight - stdMargin.top - stdMargin.bottom,
    stdMaxBuffer = 1.07;
var stdDotRadius = 4,
    stdLgndDotRadius = 5,
    stdLgndSpacing = 20;
</script>

{{ content }}

