query ($ownName: String!, $repoName: String!, $numLangs: Int!, $pgCursor: String) {
  repository(owner: $ownName, name: $repoName) {
    languages(first: $numLangs, after: $pgCursor, orderBy: {field: SIZE, direction: DESC}) {
      totalCount
      totalSize
      nodes {
        name
        color
      }
      edges {
        size
      }
      pageInfo {
        endCursor
        hasNextPage
      }
    }
  }
}
# {"ownName": "LLNL", "repoName": "llnl.github.io", "numLangs": 25, "pgCursor": null}
