---
layout: null
---
@charset "UTF-8";
/*!
* Semantic UI 2.4.2
* http://github.com/semantic-org/semantic-ui/
* http://opensource.org/licenses/MIT
*/
@import url(https://fonts.googleapis.com/css?family=Montserrat:400,700|Raleway:700);
body, html { height: 100%; }
html { font-size: 16px; }
body { margin: 0; padding: 0; overflow-x: hidden; min-width: 320px; background: #fff; font-family: Montserrat,sans-serif; font-size: 16px; line-height: 1.4285em; color: rgba(0, 0, 0, 0.87); font-smoothing: antialiased; }
h1, h2, h3, h4, h5 { font-family: Raleway,sans-serif; line-height: 1.28571429em; margin: calc(2rem - .14285714em) 0 1rem; font-weight: 700; padding: 0; }
h1 { min-height: 1rem; font-size: 2rem; }
h2 { font-size: 1.71428571rem; }
h3 { font-size: 1.28571429rem; }
h4 { font-size: 1.07142857rem; }
h5 { font-size: 1rem; }
h1:first-child, h2:first-child, h3:first-child, h4:first-child, h5:first-child { margin-top: 0; }
h1:last-child, h2:last-child, h3:last-child, h4:last-child, h5:last-child { margin-bottom: 0; }
p { margin: 0 0 1em; line-height: 1.4285em; }
p:first-child { margin-top: 0; }
p:last-child { margin-bottom: 0; }
a { color: #3a76bb; text-decoration: none; }
a:hover { color: #1c63b4; text-decoration: none; }
::-webkit-selection { background-color: #cce2ff; color: rgba(0, 0, 0, 0.87); }
::-moz-selection { background-color: #cce2ff; color: rgba(0, 0, 0, 0.87); }
::selection { background-color: #cce2ff; color: rgba(0, 0, 0, 0.87); }
input::-webkit-selection, textarea::-webkit-selection { background-color: rgba(100, 100, 100, 0.4); color: rgba(0, 0, 0, 0.87); }
input::-moz-selection, textarea::-moz-selection { background-color: rgba(100, 100, 100, 0.4); color: rgba(0, 0, 0, 0.87); }
input::selection, textarea::selection { background-color: rgba(100, 100, 100, 0.4); color: rgba(0, 0, 0, 0.87); }
body ::-webkit-scrollbar { -webkit-appearance: none; width: 10px; height: 10px; }
body ::-webkit-scrollbar-track { background: rgba(0, 0, 0, 0.1); border-radius: 0; }
body ::-webkit-scrollbar-thumb { cursor: pointer; border-radius: 5px; background: rgba(0, 0, 0, 0.25); -webkit-transition: color .2s ease; transition: color .2s ease; }
body ::-webkit-scrollbar-thumb:window-inactive { background: rgba(0, 0, 0, 0.15); }
body ::-webkit-scrollbar-thumb:hover { background: rgba(128, 135, 139, 0.8); }
body .ui.inverted::-webkit-scrollbar-track { background: rgba(255, 255, 255, 0.1); }
body .ui.inverted::-webkit-scrollbar-thumb { background: rgba(255, 255, 255, 0.25); }
body .ui.inverted::-webkit-scrollbar-thumb:window-inactive { background: rgba(255, 255, 255, 0.15); }
body .ui.inverted::-webkit-scrollbar-thumb:hover { background: rgba(255, 255, 255, 0.35); }
*, :after, :before { -webkit-box-sizing: inherit; box-sizing: inherit; }
html { -webkit-box-sizing: border-box; box-sizing: border-box; }
input[type=email], input[type=password], input[type=search], input[type=text] { -webkit-appearance: none; -moz-appearance: none; }
/*! normalize.css v7.0.0 | MIT License | github.com/necolas/normalize.css */
html { line-height: 1.15; -ms-text-size-adjust: 100%; -webkit-text-size-adjust: 100%; }
body { margin: 0; }
article, aside, footer, header, nav, section { display: block; }
h1 { font-size: 2em; margin: .67em 0; }
figcaption, figure, main { display: block; }
figure { margin: 1em 40px; }
hr { -webkit-box-sizing: content-box; box-sizing: content-box; height: 0; overflow: visible; }
pre { font-family: monospace,monospace; font-size: 1em; }
a { background-color: transparent; -webkit-text-decoration-skip: objects; }
abbr[title] { border-bottom: none; text-decoration: underline; -webkit-text-decoration: underline dotted; text-decoration: underline dotted; }
b, strong { font-weight: inherit; }
b, strong { font-weight: bolder; }
code, kbd, samp { font-family: monospace,monospace; font-size: 1em; }
dfn { font-style: italic; }
mark { background-color: #ff0; color: #000; }
small { font-size: 80%; }
sub, sup { font-size: 75%; line-height: 0; position: relative; vertical-align: baseline; }
sub { bottom: -.25em; }
sup { top: -.5em; }
audio, video { display: inline-block; }
audio:not([controls]) { display: none; height: 0; }
img { border-style: none; }
svg:not(:root) { overflow: hidden; }
button, input, optgroup, select, textarea { font-family: sans-serif; font-size: 100%; line-height: 1.15; margin: 0; }
button, input { overflow: visible; }
button, select { text-transform: none; }
[type=reset], [type=submit], button, html [type=button] { -webkit-appearance: button; }
[type=button]::-moz-focus-inner, [type=reset]::-moz-focus-inner, [type=submit]::-moz-focus-inner, button::-moz-focus-inner { border-style: none; padding: 0; }
[type=button]:-moz-focusring, [type=reset]:-moz-focusring, [type=submit]:-moz-focusring, button:-moz-focusring { outline: 1px dotted ButtonText; }
fieldset { padding: .35em .75em .625em; }
legend { -webkit-box-sizing: border-box; box-sizing: border-box; color: inherit; display: table; max-width: 100%; padding: 0; white-space: normal; }
progress { display: inline-block; vertical-align: baseline; }
textarea { overflow: auto; }
[type=checkbox], [type=radio] { -webkit-box-sizing: border-box; box-sizing: border-box; padding: 0; }
[type=number]::-webkit-inner-spin-button, [type=number]::-webkit-outer-spin-button { height: auto; }
[type=search] { -webkit-appearance: textfield; outline-offset: -2px; }
[type=search]::-webkit-search-cancel-button, [type=search]::-webkit-search-decoration { -webkit-appearance: none; }
::-webkit-file-upload-button { -webkit-appearance: button; font: inherit; }
details, menu { display: block; }
summary { display: list-item; }
canvas { display: inline-block; }
template { display: none; }
[hidden] { display: none; }
.ui.breadcrumb { line-height: 1; display: inline-block; margin: 0 0; vertical-align: middle; }
.ui.breadcrumb:first-child { margin-top: 0; }
.ui.breadcrumb:last-child { margin-bottom: 0; }
.ui.breadcrumb .divider { display: inline-block; opacity: .7; margin: 0 .1875rem 0; font-size: .875em; color: rgba(0, 0, 0, 0.4); vertical-align: baseline; }
.ui.breadcrumb a { color: #3a76bb; }
.ui.breadcrumb a:hover { color: #1c63b4; }
.ui.breadcrumb .icon.divider { font-size: .75em; vertical-align: baseline; }
.ui.breadcrumb a.section { cursor: pointer; }
.ui.breadcrumb .section { display: inline-block; margin: 0; padding: 0; }
.ui.breadcrumb.segment { display: inline-block; padding: .625em 1em; }
.ui.breadcrumb .active.section { font-weight: 700; }
.ui.mini.breadcrumb { font-size: .625rem; }
.ui.tiny.breadcrumb { font-size: .75rem; }
.ui.small.breadcrumb { font-size: .875rem; }
.ui.breadcrumb { font-size: 1rem; }
.ui.large.breadcrumb { font-size: 1.125rem; }
.ui.big.breadcrumb { font-size: 1.25rem; }
.ui.huge.breadcrumb { font-size: 1.5rem; }
.ui.massive.breadcrumb { font-size: 2rem; }
.ui.container { display: block; max-width: 100% !important; }
@media only screen and (max-width: 767px) { .ui.container { width: auto !important; margin-left: 1em !important; margin-right: 1em !important; }
  .ui.grid.container { width: auto !important; }
  .ui.relaxed.grid.container { width: auto !important; }
  .ui.very.relaxed.grid.container { width: auto !important; } }
@media only screen and (min-width: 768px) and (max-width: 991px) { .ui.container { width: 719px; margin-left: auto !important; margin-right: auto !important; }
  .ui.grid.container { width: calc(719px + 2rem) !important; }
  .ui.relaxed.grid.container { width: calc(719px + 3rem) !important; }
  .ui.very.relaxed.grid.container { width: calc(719px + 5rem) !important; } }
@media only screen and (min-width: 992px) and (max-width: 1199px) { .ui.container { width: 927px; margin-left: auto !important; margin-right: auto !important; }
  .ui.grid.container { width: calc(927px + 2rem) !important; }
  .ui.relaxed.grid.container { width: calc(927px + 3rem) !important; }
  .ui.very.relaxed.grid.container { width: calc(927px + 5rem) !important; } }
@media only screen and (min-width: 1200px) { .ui.container { width: 1119px; margin-left: auto !important; margin-right: auto !important; }
  .ui.grid.container { width: calc(1119px + 2rem) !important; }
  .ui.relaxed.grid.container { width: calc(1119px + 3rem) !important; }
  .ui.very.relaxed.grid.container { width: calc(1119px + 5rem) !important; } }
.ui.text.container { font-family: Montserrat,sans-serif; max-width: 700px !important; line-height: 1.5; }
.ui.text.container { font-size: 1.125rem; }
.ui.fluid.container { width: 100%; }
.ui[class*="left aligned"].container { text-align: left; }
.ui[class*="center aligned"].container { text-align: center; }
.ui[class*="right aligned"].container { text-align: right; }
.ui.justified.container { text-align: justify; -webkit-hyphens: auto; -ms-hyphens: auto; hyphens: auto; }
.dimmable:not(body) { position: relative; }
.ui.dimmer { display: none; position: absolute; top: 0 !important; left: 0 !important; width: 100%; height: 100%; text-align: center; vertical-align: middle; padding: 1em; background-color: rgba(0, 0, 0, 0.85); opacity: 0; line-height: 1; -webkit-animation-fill-mode: both; animation-fill-mode: both; -webkit-animation-duration: .5s; animation-duration: .5s; -webkit-transition: background-color .5s linear; transition: background-color .5s linear; -webkit-box-orient: vertical; -webkit-box-direction: normal; -ms-flex-direction: column; flex-direction: column; -webkit-box-align: center; -ms-flex-align: center; align-items: center; -webkit-box-pack: center; -ms-flex-pack: center; justify-content: center; -webkit-user-select: none; -moz-user-select: none; -ms-user-select: none; user-select: none; will-change: opacity; z-index: 1000; }
.ui.dimmer > .content { -webkit-user-select: text; -moz-user-select: text; -ms-user-select: text; user-select: text; color: #fff; }
.ui.segment > .ui.dimmer { border-radius: inherit !important; }
.ui.dimmer:not(.inverted)::-webkit-scrollbar-track { background: rgba(255, 255, 255, 0.1); }
.ui.dimmer:not(.inverted)::-webkit-scrollbar-thumb { background: rgba(255, 255, 255, 0.25); }
.ui.dimmer:not(.inverted)::-webkit-scrollbar-thumb:window-inactive { background: rgba(255, 255, 255, 0.15); }
.ui.dimmer:not(.inverted)::-webkit-scrollbar-thumb:hover { background: rgba(255, 255, 255, 0.35); }
.animating.dimmable:not(body), .dimmed.dimmable:not(body) { overflow: hidden; }
.dimmed.dimmable > .ui.animating.dimmer, .dimmed.dimmable > .ui.visible.dimmer, .ui.active.dimmer { display: -webkit-box; display: -ms-flexbox; display: flex; opacity: 1; }
.ui.disabled.dimmer { width: 0 !important; height: 0 !important; }
.dimmed.dimmable > .ui.animating.legacy.dimmer, .dimmed.dimmable > .ui.visible.legacy.dimmer, .ui.active.legacy.dimmer { display: block; }
.ui[class*="top aligned"].dimmer { -webkit-box-pack: start; -ms-flex-pack: start; justify-content: flex-start; }
.ui[class*="bottom aligned"].dimmer { -webkit-box-pack: end; -ms-flex-pack: end; justify-content: flex-end; }
.ui.page.dimmer { position: fixed; -webkit-transform-style: ''; transform-style: ''; -webkit-perspective: 2000px; perspective: 2000px; -webkit-transform-origin: center center; transform-origin: center center; }
body.animating.in.dimmable, body.dimmed.dimmable { overflow: hidden; }
body.dimmable > .dimmer { position: fixed; }
.blurring.dimmable > :not(.dimmer) { -webkit-filter: blur(0) grayscale(0); filter: blur(0) grayscale(0); -webkit-transition: .8s -webkit-filter ease; transition: .8s -webkit-filter ease; transition: .8s filter ease; transition: .8s filter ease,.8s -webkit-filter ease; }
.blurring.dimmed.dimmable > :not(.dimmer) { -webkit-filter: blur(5px) grayscale(0.7); filter: blur(5px) grayscale(0.7); }
.blurring.dimmable > .dimmer { background-color: rgba(0, 0, 0, 0.6); }
.blurring.dimmable > .inverted.dimmer { background-color: rgba(255, 255, 255, 0.6); }
.ui.dimmer > .top.aligned.content > * { vertical-align: top; }
.ui.dimmer > .bottom.aligned.content > * { vertical-align: bottom; }
.ui.inverted.dimmer { background-color: rgba(255, 255, 255, 0.85); }
.ui.inverted.dimmer > .content > * { color: #fff; }
.ui.simple.dimmer { display: block; overflow: hidden; opacity: 1; width: 0%; height: 0%; z-index: -100; background-color: rgba(0, 0, 0, 0); }
.dimmed.dimmable > .ui.simple.dimmer { overflow: visible; opacity: 1; width: 100%; height: 100%; background-color: rgba(0, 0, 0, 0.85); z-index: 1; }
.ui.simple.inverted.dimmer { background-color: rgba(255, 255, 255, 0); }
.dimmed.dimmable > .ui.simple.inverted.dimmer { background-color: rgba(255, 255, 255, 0.85); }
.ui.divider { margin: 1rem 0; line-height: 1; height: 0; font-weight: 700; text-transform: uppercase; letter-spacing: .05em; color: rgba(0, 0, 0, 0.85); -webkit-user-select: none; -moz-user-select: none; -ms-user-select: none; user-select: none; -webkit-tap-highlight-color: transparent; }
.ui.divider:not(.vertical):not(.horizontal) { border-top: 1px solid rgba(34, 36, 38, 0.15); border-bottom: 1px solid rgba(255, 255, 255, 0.1); }
.ui.grid > .column + .divider, .ui.grid > .row > .column + .divider { left: auto; }
.ui.horizontal.divider { display: table; white-space: nowrap; height: auto; margin: ''; line-height: 1; text-align: center; }
.ui.horizontal.divider:after, .ui.horizontal.divider:before { content: ''; display: table-cell; position: relative; top: 50%; width: 50%; background-repeat: no-repeat; }
.ui.horizontal.divider:before { background-position: right 1em top 50%; }
.ui.horizontal.divider:after { background-position: left 1em top 50%; }
.ui.vertical.divider { position: absolute; z-index: 2; top: 50%; left: 50%; margin: 0; padding: 0; width: auto; height: 50%; line-height: 0; text-align: center; -webkit-transform: translateX(-50%); transform: translateX(-50%); }
.ui.vertical.divider:after, .ui.vertical.divider:before { position: absolute; left: 50%; content: ''; z-index: 3; border-left: 1px solid rgba(34, 36, 38, 0.15); border-right: 1px solid rgba(255, 255, 255, 0.1); width: 0%; height: calc(100% - 1rem); }
.ui.vertical.divider:before { top: -100%; }
.ui.vertical.divider:after { top: auto; bottom: 0; }
@media only screen and (max-width: 767px) { .ui.grid .stackable.row .ui.vertical.divider, .ui.stackable.grid .ui.vertical.divider { display: table; white-space: nowrap; height: auto; margin: ''; overflow: hidden; line-height: 1; text-align: center; position: static; top: 0; left: 0; -webkit-transform: none; transform: none; }
  .ui.grid .stackable.row .ui.vertical.divider:after, .ui.grid .stackable.row .ui.vertical.divider:before, .ui.stackable.grid .ui.vertical.divider:after, .ui.stackable.grid .ui.vertical.divider:before { position: static; left: 0; border-left: none; border-right: none; content: ''; display: table-cell; position: relative; top: 50%; width: 50%; background-repeat: no-repeat; }
  .ui.grid .stackable.row .ui.vertical.divider:before, .ui.stackable.grid .ui.vertical.divider:before { background-position: right 1em top 50%; }
  .ui.grid .stackable.row .ui.vertical.divider:after, .ui.stackable.grid .ui.vertical.divider:after { background-position: left 1em top 50%; } }
.ui.divider > .icon { margin: 0; font-size: 1rem; height: 1em; vertical-align: middle; }
.ui.hidden.divider { border-color: transparent !important; }
.ui.hidden.divider:after, .ui.hidden.divider:before { display: none; }
.ui.divider.inverted, .ui.horizontal.inverted.divider, .ui.vertical.inverted.divider { color: #fff; }
.ui.divider.inverted, .ui.divider.inverted:after, .ui.divider.inverted:before { border-top-color: rgba(34, 36, 38, 0.15) !important; border-left-color: rgba(34, 36, 38, 0.15) !important; border-bottom-color: rgba(255, 255, 255, 0.15) !important; border-right-color: rgba(255, 255, 255, 0.15) !important; }
.ui.fitted.divider { margin: 0; }
.ui.clearing.divider { clear: both; }
.ui.section.divider { margin-top: 2rem; margin-bottom: 2rem; }
.ui.divider { font-size: 1rem; }
.ui.horizontal.divider:after, .ui.horizontal.divider:before { background-image: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAABaAAAAACCAYAAACuTHuKAAAAGXRFWHRTb2Z0d2FyZQBBZG9iZSBJbWFnZVJlYWR5ccllPAAAAyFpVFh0WE1MOmNvbS5hZG9iZS54bXAAAAAAADw/eHBhY2tldCBiZWdpbj0i77u/IiBpZD0iVzVNME1wQ2VoaUh6cmVTek5UY3prYzlkIj8+IDx4OnhtcG1ldGEgeG1sbnM6eD0iYWRvYmU6bnM6bWV0YS8iIHg6eG1wdGs9IkFkb2JlIFhNUCBDb3JlIDUuNS1jMDE0IDc5LjE1MTQ4MSwgMjAxMy8wMy8xMy0xMjowOToxNSAgICAgICAgIj4gPHJkZjpSREYgeG1sbnM6cmRmPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgtbnMjIj4gPHJkZjpEZXNjcmlwdGlvbiByZGY6YWJvdXQ9IiIgeG1sbnM6eG1wPSJodHRwOi8vbnMuYWRvYmUuY29tL3hhcC8xLjAvIiB4bWxuczp4bXBNTT0iaHR0cDovL25zLmFkb2JlLmNvbS94YXAvMS4wL21tLyIgeG1sbnM6c3RSZWY9Imh0dHA6Ly9ucy5hZG9iZS5jb20veGFwLzEuMC9zVHlwZS9SZXNvdXJjZVJlZiMiIHhtcDpDcmVhdG9yVG9vbD0iQWRvYmUgUGhvdG9zaG9wIENDIChXaW5kb3dzKSIgeG1wTU06SW5zdGFuY2VJRD0ieG1wLmlpZDo1OThBRDY4OUNDMTYxMUU0OUE3NUVGOEJDMzMzMjE2NyIgeG1wTU06RG9jdW1lbnRJRD0ieG1wLmRpZDo1OThBRDY4QUNDMTYxMUU0OUE3NUVGOEJDMzMzMjE2NyI+IDx4bXBNTTpEZXJpdmVkRnJvbSBzdFJlZjppbnN0YW5jZUlEPSJ4bXAuaWlkOjU5OEFENjg3Q0MxNjExRTQ5QTc1RUY4QkMzMzMyMTY3IiBzdFJlZjpkb2N1bWVudElEPSJ4bXAuZGlkOjU5OEFENjg4Q0MxNjExRTQ5QTc1RUY4QkMzMzMyMTY3Ii8+IDwvcmRmOkRlc2NyaXB0aW9uPiA8L3JkZjpSREY+IDwveDp4bXBtZXRhPiA8P3hwYWNrZXQgZW5kPSJyIj8+VU513gAAADVJREFUeNrs0DENACAQBDBIWLGBJQby/mUcJn5sJXQmOQMAAAAAAJqt+2prAAAAAACg2xdgANk6BEVuJgyMAAAAAElFTkSuQmCC); }
@media only screen and (max-width: 767px) { .ui.grid .stackable.row .ui.vertical.divider:after, .ui.grid .stackable.row .ui.vertical.divider:before, .ui.stackable.grid .ui.vertical.divider:after, .ui.stackable.grid .ui.vertical.divider:before { background-image: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAABaAAAAACCAYAAACuTHuKAAAAGXRFWHRTb2Z0d2FyZQBBZG9iZSBJbWFnZVJlYWR5ccllPAAAAyFpVFh0WE1MOmNvbS5hZG9iZS54bXAAAAAAADw/eHBhY2tldCBiZWdpbj0i77u/IiBpZD0iVzVNME1wQ2VoaUh6cmVTek5UY3prYzlkIj8+IDx4OnhtcG1ldGEgeG1sbnM6eD0iYWRvYmU6bnM6bWV0YS8iIHg6eG1wdGs9IkFkb2JlIFhNUCBDb3JlIDUuNS1jMDE0IDc5LjE1MTQ4MSwgMjAxMy8wMy8xMy0xMjowOToxNSAgICAgICAgIj4gPHJkZjpSREYgeG1sbnM6cmRmPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgtbnMjIj4gPHJkZjpEZXNjcmlwdGlvbiByZGY6YWJvdXQ9IiIgeG1sbnM6eG1wPSJodHRwOi8vbnMuYWRvYmUuY29tL3hhcC8xLjAvIiB4bWxuczp4bXBNTT0iaHR0cDovL25zLmFkb2JlLmNvbS94YXAvMS4wL21tLyIgeG1sbnM6c3RSZWY9Imh0dHA6Ly9ucy5hZG9iZS5jb20veGFwLzEuMC9zVHlwZS9SZXNvdXJjZVJlZiMiIHhtcDpDcmVhdG9yVG9vbD0iQWRvYmUgUGhvdG9zaG9wIENDIChXaW5kb3dzKSIgeG1wTU06SW5zdGFuY2VJRD0ieG1wLmlpZDo1OThBRDY4OUNDMTYxMUU0OUE3NUVGOEJDMzMzMjE2NyIgeG1wTU06RG9jdW1lbnRJRD0ieG1wLmRpZDo1OThBRDY4QUNDMTYxMUU0OUE3NUVGOEJDMzMzMjE2NyI+IDx4bXBNTTpEZXJpdmVkRnJvbSBzdFJlZjppbnN0YW5jZUlEPSJ4bXAuaWlkOjU5OEFENjg3Q0MxNjExRTQ5QTc1RUY4QkMzMzMyMTY3IiBzdFJlZjpkb2N1bWVudElEPSJ4bXAuZGlkOjU5OEFENjg4Q0MxNjExRTQ5QTc1RUY4QkMzMzMyMTY3Ii8+IDwvcmRmOkRlc2NyaXB0aW9uPiA8L3JkZjpSREY+IDwveDp4bXBtZXRhPiA8P3hwYWNrZXQgZW5kPSJyIj8+VU513gAAADVJREFUeNrs0DENACAQBDBIWLGBJQby/mUcJn5sJXQmOQMAAAAAAJqt+2prAAAAAACg2xdgANk6BEVuJgyMAAAAAElFTkSuQmCC); } }
.ui.grid { display: -webkit-box; display: -ms-flexbox; display: flex; -webkit-box-orient: horizontal; -webkit-box-direction: normal; -ms-flex-direction: row; flex-direction: row; -ms-flex-wrap: wrap; flex-wrap: wrap; -webkit-box-align: stretch; -ms-flex-align: stretch; align-items: stretch; padding: 0; }
.ui.grid { margin-top: -1rem; margin-bottom: -1rem; margin-left: -1rem; margin-right: -1rem; }
.ui.relaxed.grid { margin-left: -1.5rem; margin-right: -1.5rem; }
.ui[class*="very relaxed"].grid { margin-left: -2.5rem; margin-right: -2.5rem; }
.ui.grid + .grid { margin-top: 1rem; }
.ui.grid > .column:not(.row), .ui.grid > .row > .column { position: relative; display: inline-block; width: 6.25%; padding-left: 1rem; padding-right: 1rem; vertical-align: top; }
.ui.grid > * { padding-left: 1rem; padding-right: 1rem; }
.ui.grid > .row { position: relative; display: -webkit-box; display: -ms-flexbox; display: flex; -webkit-box-orient: horizontal; -webkit-box-direction: normal; -ms-flex-direction: row; flex-direction: row; -ms-flex-wrap: wrap; flex-wrap: wrap; -webkit-box-pack: inherit; -ms-flex-pack: inherit; justify-content: inherit; -webkit-box-align: stretch; -ms-flex-align: stretch; align-items: stretch; width: 100% !important; padding: 0; padding-top: 1rem; padding-bottom: 1rem; }
.ui.grid > .column:not(.row) { padding-top: 1rem; padding-bottom: 1rem; }
.ui.grid > .row > .column { margin-top: 0; margin-bottom: 0; }
.ui.grid > .row > .column > img, .ui.grid > .row > img { max-width: 100%; }
.ui.grid > .ui.grid:first-child { margin-top: 0; }
.ui.grid > .ui.grid:last-child { margin-bottom: 0; }
.ui.aligned.grid .column > .segment:not(.compact):not(.attached), .ui.grid .aligned.row > .column > .segment:not(.compact):not(.attached) { width: 100%; }
.ui.grid .row + .ui.divider { -webkit-box-flex: 1; -ms-flex-positive: 1; flex-grow: 1; margin: 1rem 1rem; }
.ui.grid .column + .ui.vertical.divider { height: calc(50% - (2rem / 2)); }
.ui.grid > .column:last-child > .horizontal.segment, .ui.grid > .row > .column:last-child > .horizontal.segment { -webkit-box-shadow: none; box-shadow: none; }
@media only screen and (max-width: 767px) { .ui.page.grid { width: auto; padding-left: 0; padding-right: 0; margin-left: 0; margin-right: 0; } }
@media only screen and (min-width: 768px) and (max-width: 991px) { .ui.page.grid { width: auto; margin-left: 0; margin-right: 0; padding-left: 2em; padding-right: 2em; } }
@media only screen and (min-width: 992px) and (max-width: 1199px) { .ui.page.grid { width: auto; margin-left: 0; margin-right: 0; padding-left: 3%; padding-right: 3%; } }
@media only screen and (min-width: 1200px) and (max-width: 1919px) { .ui.page.grid { width: auto; margin-left: 0; margin-right: 0; padding-left: 15%; padding-right: 15%; } }
@media only screen and (min-width: 1920px) { .ui.page.grid { width: auto; margin-left: 0; margin-right: 0; padding-left: 23%; padding-right: 23%; } }
.ui.grid > .column:only-child, .ui.grid > .row > .column:only-child { width: 100%; }
.ui[class*="one column"].grid > .column:not(.row), .ui[class*="one column"].grid > .row > .column { width: 100%; }
.ui[class*="two column"].grid > .column:not(.row), .ui[class*="two column"].grid > .row > .column { width: 50%; }
.ui[class*="three column"].grid > .column:not(.row), .ui[class*="three column"].grid > .row > .column { width: 33.33333333%; }
.ui[class*="four column"].grid > .column:not(.row), .ui[class*="four column"].grid > .row > .column { width: 25%; }
.ui[class*="five column"].grid > .column:not(.row), .ui[class*="five column"].grid > .row > .column { width: 20%; }
.ui[class*="six column"].grid > .column:not(.row), .ui[class*="six column"].grid > .row > .column { width: 16.66666667%; }
.ui[class*="seven column"].grid > .column:not(.row), .ui[class*="seven column"].grid > .row > .column { width: 14.28571429%; }
.ui[class*="eight column"].grid > .column:not(.row), .ui[class*="eight column"].grid > .row > .column { width: 12.5%; }
.ui[class*="nine column"].grid > .column:not(.row), .ui[class*="nine column"].grid > .row > .column { width: 11.11111111%; }
.ui[class*="ten column"].grid > .column:not(.row), .ui[class*="ten column"].grid > .row > .column { width: 10%; }
.ui[class*="eleven column"].grid > .column:not(.row), .ui[class*="eleven column"].grid > .row > .column { width: 9.09090909%; }
.ui[class*="twelve column"].grid > .column:not(.row), .ui[class*="twelve column"].grid > .row > .column { width: 8.33333333%; }
.ui[class*="thirteen column"].grid > .column:not(.row), .ui[class*="thirteen column"].grid > .row > .column { width: 7.69230769%; }
.ui[class*="fourteen column"].grid > .column:not(.row), .ui[class*="fourteen column"].grid > .row > .column { width: 7.14285714%; }
.ui[class*="fifteen column"].grid > .column:not(.row), .ui[class*="fifteen column"].grid > .row > .column { width: 6.66666667%; }
.ui[class*="sixteen column"].grid > .column:not(.row), .ui[class*="sixteen column"].grid > .row > .column { width: 6.25%; }
.ui.grid > [class*="one column"].row > .column { width: 100% !important; }
.ui.grid > [class*="two column"].row > .column { width: 50% !important; }
.ui.grid > [class*="three column"].row > .column { width: 33.33333333% !important; }
.ui.grid > [class*="four column"].row > .column { width: 25% !important; }
.ui.grid > [class*="five column"].row > .column { width: 20% !important; }
.ui.grid > [class*="six column"].row > .column { width: 16.66666667% !important; }
.ui.grid > [class*="seven column"].row > .column { width: 14.28571429% !important; }
.ui.grid > [class*="eight column"].row > .column { width: 12.5% !important; }
.ui.grid > [class*="nine column"].row > .column { width: 11.11111111% !important; }
.ui.grid > [class*="ten column"].row > .column { width: 10% !important; }
.ui.grid > [class*="eleven column"].row > .column { width: 9.09090909% !important; }
.ui.grid > [class*="twelve column"].row > .column { width: 8.33333333% !important; }
.ui.grid > [class*="thirteen column"].row > .column { width: 7.69230769% !important; }
.ui.grid > [class*="fourteen column"].row > .column { width: 7.14285714% !important; }
.ui.grid > [class*="fifteen column"].row > .column { width: 6.66666667% !important; }
.ui.grid > [class*="sixteen column"].row > .column { width: 6.25% !important; }
.ui.celled.page.grid { -webkit-box-shadow: none; box-shadow: none; }
.ui.column.grid > [class*="one wide"].column, .ui.grid > .column.row > [class*="one wide"].column, .ui.grid > .row > [class*="one wide"].column, .ui.grid > [class*="one wide"].column { width: 6.25% !important; }
.ui.column.grid > [class*="two wide"].column, .ui.grid > .column.row > [class*="two wide"].column, .ui.grid > .row > [class*="two wide"].column, .ui.grid > [class*="two wide"].column { width: 12.5% !important; }
.ui.column.grid > [class*="three wide"].column, .ui.grid > .column.row > [class*="three wide"].column, .ui.grid > .row > [class*="three wide"].column, .ui.grid > [class*="three wide"].column { width: 18.75% !important; }
.ui.column.grid > [class*="four wide"].column, .ui.grid > .column.row > [class*="four wide"].column, .ui.grid > .row > [class*="four wide"].column, .ui.grid > [class*="four wide"].column { width: 25% !important; }
.ui.column.grid > [class*="five wide"].column, .ui.grid > .column.row > [class*="five wide"].column, .ui.grid > .row > [class*="five wide"].column, .ui.grid > [class*="five wide"].column { width: 31.25% !important; }
.ui.column.grid > [class*="six wide"].column, .ui.grid > .column.row > [class*="six wide"].column, .ui.grid > .row > [class*="six wide"].column, .ui.grid > [class*="six wide"].column { width: 37.5% !important; }
.ui.column.grid > [class*="seven wide"].column, .ui.grid > .column.row > [class*="seven wide"].column, .ui.grid > .row > [class*="seven wide"].column, .ui.grid > [class*="seven wide"].column { width: 43.75% !important; }
.ui.column.grid > [class*="eight wide"].column, .ui.grid > .column.row > [class*="eight wide"].column, .ui.grid > .row > [class*="eight wide"].column, .ui.grid > [class*="eight wide"].column { width: 50% !important; }
.ui.column.grid > [class*="nine wide"].column, .ui.grid > .column.row > [class*="nine wide"].column, .ui.grid > .row > [class*="nine wide"].column, .ui.grid > [class*="nine wide"].column { width: 56.25% !important; }
.ui.column.grid > [class*="ten wide"].column, .ui.grid > .column.row > [class*="ten wide"].column, .ui.grid > .row > [class*="ten wide"].column, .ui.grid > [class*="ten wide"].column { width: 62.5% !important; }
.ui.column.grid > [class*="eleven wide"].column, .ui.grid > .column.row > [class*="eleven wide"].column, .ui.grid > .row > [class*="eleven wide"].column, .ui.grid > [class*="eleven wide"].column { width: 68.75% !important; }
.ui.column.grid > [class*="twelve wide"].column, .ui.grid > .column.row > [class*="twelve wide"].column, .ui.grid > .row > [class*="twelve wide"].column, .ui.grid > [class*="twelve wide"].column { width: 75% !important; }
.ui.column.grid > [class*="thirteen wide"].column, .ui.grid > .column.row > [class*="thirteen wide"].column, .ui.grid > .row > [class*="thirteen wide"].column, .ui.grid > [class*="thirteen wide"].column { width: 81.25% !important; }
.ui.column.grid > [class*="fourteen wide"].column, .ui.grid > .column.row > [class*="fourteen wide"].column, .ui.grid > .row > [class*="fourteen wide"].column, .ui.grid > [class*="fourteen wide"].column { width: 87.5% !important; }
.ui.column.grid > [class*="fifteen wide"].column, .ui.grid > .column.row > [class*="fifteen wide"].column, .ui.grid > .row > [class*="fifteen wide"].column, .ui.grid > [class*="fifteen wide"].column { width: 93.75% !important; }
.ui.column.grid > [class*="sixteen wide"].column, .ui.grid > .column.row > [class*="sixteen wide"].column, .ui.grid > .row > [class*="sixteen wide"].column, .ui.grid > [class*="sixteen wide"].column { width: 100% !important; }
@media only screen and (min-width: 320px) and (max-width: 767px) { .ui.column.grid > [class*="one wide mobile"].column, .ui.grid > .column.row > [class*="one wide mobile"].column, .ui.grid > .row > [class*="one wide mobile"].column, .ui.grid > [class*="one wide mobile"].column { width: 6.25% !important; }
  .ui.column.grid > [class*="two wide mobile"].column, .ui.grid > .column.row > [class*="two wide mobile"].column, .ui.grid > .row > [class*="two wide mobile"].column, .ui.grid > [class*="two wide mobile"].column { width: 12.5% !important; }
  .ui.column.grid > [class*="three wide mobile"].column, .ui.grid > .column.row > [class*="three wide mobile"].column, .ui.grid > .row > [class*="three wide mobile"].column, .ui.grid > [class*="three wide mobile"].column { width: 18.75% !important; }
  .ui.column.grid > [class*="four wide mobile"].column, .ui.grid > .column.row > [class*="four wide mobile"].column, .ui.grid > .row > [class*="four wide mobile"].column, .ui.grid > [class*="four wide mobile"].column { width: 25% !important; }
  .ui.column.grid > [class*="five wide mobile"].column, .ui.grid > .column.row > [class*="five wide mobile"].column, .ui.grid > .row > [class*="five wide mobile"].column, .ui.grid > [class*="five wide mobile"].column { width: 31.25% !important; }
  .ui.column.grid > [class*="six wide mobile"].column, .ui.grid > .column.row > [class*="six wide mobile"].column, .ui.grid > .row > [class*="six wide mobile"].column, .ui.grid > [class*="six wide mobile"].column { width: 37.5% !important; }
  .ui.column.grid > [class*="seven wide mobile"].column, .ui.grid > .column.row > [class*="seven wide mobile"].column, .ui.grid > .row > [class*="seven wide mobile"].column, .ui.grid > [class*="seven wide mobile"].column { width: 43.75% !important; }
  .ui.column.grid > [class*="eight wide mobile"].column, .ui.grid > .column.row > [class*="eight wide mobile"].column, .ui.grid > .row > [class*="eight wide mobile"].column, .ui.grid > [class*="eight wide mobile"].column { width: 50% !important; }
  .ui.column.grid > [class*="nine wide mobile"].column, .ui.grid > .column.row > [class*="nine wide mobile"].column, .ui.grid > .row > [class*="nine wide mobile"].column, .ui.grid > [class*="nine wide mobile"].column { width: 56.25% !important; }
  .ui.column.grid > [class*="ten wide mobile"].column, .ui.grid > .column.row > [class*="ten wide mobile"].column, .ui.grid > .row > [class*="ten wide mobile"].column, .ui.grid > [class*="ten wide mobile"].column { width: 62.5% !important; }
  .ui.column.grid > [class*="eleven wide mobile"].column, .ui.grid > .column.row > [class*="eleven wide mobile"].column, .ui.grid > .row > [class*="eleven wide mobile"].column, .ui.grid > [class*="eleven wide mobile"].column { width: 68.75% !important; }
  .ui.column.grid > [class*="twelve wide mobile"].column, .ui.grid > .column.row > [class*="twelve wide mobile"].column, .ui.grid > .row > [class*="twelve wide mobile"].column, .ui.grid > [class*="twelve wide mobile"].column { width: 75% !important; }
  .ui.column.grid > [class*="thirteen wide mobile"].column, .ui.grid > .column.row > [class*="thirteen wide mobile"].column, .ui.grid > .row > [class*="thirteen wide mobile"].column, .ui.grid > [class*="thirteen wide mobile"].column { width: 81.25% !important; }
  .ui.column.grid > [class*="fourteen wide mobile"].column, .ui.grid > .column.row > [class*="fourteen wide mobile"].column, .ui.grid > .row > [class*="fourteen wide mobile"].column, .ui.grid > [class*="fourteen wide mobile"].column { width: 87.5% !important; }
  .ui.column.grid > [class*="fifteen wide mobile"].column, .ui.grid > .column.row > [class*="fifteen wide mobile"].column, .ui.grid > .row > [class*="fifteen wide mobile"].column, .ui.grid > [class*="fifteen wide mobile"].column { width: 93.75% !important; }
  .ui.column.grid > [class*="sixteen wide mobile"].column, .ui.grid > .column.row > [class*="sixteen wide mobile"].column, .ui.grid > .row > [class*="sixteen wide mobile"].column, .ui.grid > [class*="sixteen wide mobile"].column { width: 100% !important; } }
@media only screen and (min-width: 768px) and (max-width: 991px) { .ui.column.grid > [class*="one wide tablet"].column, .ui.grid > .column.row > [class*="one wide tablet"].column, .ui.grid > .row > [class*="one wide tablet"].column, .ui.grid > [class*="one wide tablet"].column { width: 6.25% !important; }
  .ui.column.grid > [class*="two wide tablet"].column, .ui.grid > .column.row > [class*="two wide tablet"].column, .ui.grid > .row > [class*="two wide tablet"].column, .ui.grid > [class*="two wide tablet"].column { width: 12.5% !important; }
  .ui.column.grid > [class*="three wide tablet"].column, .ui.grid > .column.row > [class*="three wide tablet"].column, .ui.grid > .row > [class*="three wide tablet"].column, .ui.grid > [class*="three wide tablet"].column { width: 18.75% !important; }
  .ui.column.grid > [class*="four wide tablet"].column, .ui.grid > .column.row > [class*="four wide tablet"].column, .ui.grid > .row > [class*="four wide tablet"].column, .ui.grid > [class*="four wide tablet"].column { width: 25% !important; }
  .ui.column.grid > [class*="five wide tablet"].column, .ui.grid > .column.row > [class*="five wide tablet"].column, .ui.grid > .row > [class*="five wide tablet"].column, .ui.grid > [class*="five wide tablet"].column { width: 31.25% !important; }
  .ui.column.grid > [class*="six wide tablet"].column, .ui.grid > .column.row > [class*="six wide tablet"].column, .ui.grid > .row > [class*="six wide tablet"].column, .ui.grid > [class*="six wide tablet"].column { width: 37.5% !important; }
  .ui.column.grid > [class*="seven wide tablet"].column, .ui.grid > .column.row > [class*="seven wide tablet"].column, .ui.grid > .row > [class*="seven wide tablet"].column, .ui.grid > [class*="seven wide tablet"].column { width: 43.75% !important; }
  .ui.column.grid > [class*="eight wide tablet"].column, .ui.grid > .column.row > [class*="eight wide tablet"].column, .ui.grid > .row > [class*="eight wide tablet"].column, .ui.grid > [class*="eight wide tablet"].column { width: 50% !important; }
  .ui.column.grid > [class*="nine wide tablet"].column, .ui.grid > .column.row > [class*="nine wide tablet"].column, .ui.grid > .row > [class*="nine wide tablet"].column, .ui.grid > [class*="nine wide tablet"].column { width: 56.25% !important; }
  .ui.column.grid > [class*="ten wide tablet"].column, .ui.grid > .column.row > [class*="ten wide tablet"].column, .ui.grid > .row > [class*="ten wide tablet"].column, .ui.grid > [class*="ten wide tablet"].column { width: 62.5% !important; }
  .ui.column.grid > [class*="eleven wide tablet"].column, .ui.grid > .column.row > [class*="eleven wide tablet"].column, .ui.grid > .row > [class*="eleven wide tablet"].column, .ui.grid > [class*="eleven wide tablet"].column { width: 68.75% !important; }
  .ui.column.grid > [class*="twelve wide tablet"].column, .ui.grid > .column.row > [class*="twelve wide tablet"].column, .ui.grid > .row > [class*="twelve wide tablet"].column, .ui.grid > [class*="twelve wide tablet"].column { width: 75% !important; }
  .ui.column.grid > [class*="thirteen wide tablet"].column, .ui.grid > .column.row > [class*="thirteen wide tablet"].column, .ui.grid > .row > [class*="thirteen wide tablet"].column, .ui.grid > [class*="thirteen wide tablet"].column { width: 81.25% !important; }
  .ui.column.grid > [class*="fourteen wide tablet"].column, .ui.grid > .column.row > [class*="fourteen wide tablet"].column, .ui.grid > .row > [class*="fourteen wide tablet"].column, .ui.grid > [class*="fourteen wide tablet"].column { width: 87.5% !important; }
  .ui.column.grid > [class*="fifteen wide tablet"].column, .ui.grid > .column.row > [class*="fifteen wide tablet"].column, .ui.grid > .row > [class*="fifteen wide tablet"].column, .ui.grid > [class*="fifteen wide tablet"].column { width: 93.75% !important; }
  .ui.column.grid > [class*="sixteen wide tablet"].column, .ui.grid > .column.row > [class*="sixteen wide tablet"].column, .ui.grid > .row > [class*="sixteen wide tablet"].column, .ui.grid > [class*="sixteen wide tablet"].column { width: 100% !important; } }
@media only screen and (min-width: 992px) { .ui.column.grid > [class*="one wide computer"].column, .ui.grid > .column.row > [class*="one wide computer"].column, .ui.grid > .row > [class*="one wide computer"].column, .ui.grid > [class*="one wide computer"].column { width: 6.25% !important; }
  .ui.column.grid > [class*="two wide computer"].column, .ui.grid > .column.row > [class*="two wide computer"].column, .ui.grid > .row > [class*="two wide computer"].column, .ui.grid > [class*="two wide computer"].column { width: 12.5% !important; }
  .ui.column.grid > [class*="three wide computer"].column, .ui.grid > .column.row > [class*="three wide computer"].column, .ui.grid > .row > [class*="three wide computer"].column, .ui.grid > [class*="three wide computer"].column { width: 18.75% !important; }
  .ui.column.grid > [class*="four wide computer"].column, .ui.grid > .column.row > [class*="four wide computer"].column, .ui.grid > .row > [class*="four wide computer"].column, .ui.grid > [class*="four wide computer"].column { width: 25% !important; }
  .ui.column.grid > [class*="five wide computer"].column, .ui.grid > .column.row > [class*="five wide computer"].column, .ui.grid > .row > [class*="five wide computer"].column, .ui.grid > [class*="five wide computer"].column { width: 31.25% !important; }
  .ui.column.grid > [class*="six wide computer"].column, .ui.grid > .column.row > [class*="six wide computer"].column, .ui.grid > .row > [class*="six wide computer"].column, .ui.grid > [class*="six wide computer"].column { width: 37.5% !important; }
  .ui.column.grid > [class*="seven wide computer"].column, .ui.grid > .column.row > [class*="seven wide computer"].column, .ui.grid > .row > [class*="seven wide computer"].column, .ui.grid > [class*="seven wide computer"].column { width: 43.75% !important; }
  .ui.column.grid > [class*="eight wide computer"].column, .ui.grid > .column.row > [class*="eight wide computer"].column, .ui.grid > .row > [class*="eight wide computer"].column, .ui.grid > [class*="eight wide computer"].column { width: 50% !important; }
  .ui.column.grid > [class*="nine wide computer"].column, .ui.grid > .column.row > [class*="nine wide computer"].column, .ui.grid > .row > [class*="nine wide computer"].column, .ui.grid > [class*="nine wide computer"].column { width: 56.25% !important; }
  .ui.column.grid > [class*="ten wide computer"].column, .ui.grid > .column.row > [class*="ten wide computer"].column, .ui.grid > .row > [class*="ten wide computer"].column, .ui.grid > [class*="ten wide computer"].column { width: 62.5% !important; }
  .ui.column.grid > [class*="eleven wide computer"].column, .ui.grid > .column.row > [class*="eleven wide computer"].column, .ui.grid > .row > [class*="eleven wide computer"].column, .ui.grid > [class*="eleven wide computer"].column { width: 68.75% !important; }
  .ui.column.grid > [class*="twelve wide computer"].column, .ui.grid > .column.row > [class*="twelve wide computer"].column, .ui.grid > .row > [class*="twelve wide computer"].column, .ui.grid > [class*="twelve wide computer"].column { width: 75% !important; }
  .ui.column.grid > [class*="thirteen wide computer"].column, .ui.grid > .column.row > [class*="thirteen wide computer"].column, .ui.grid > .row > [class*="thirteen wide computer"].column, .ui.grid > [class*="thirteen wide computer"].column { width: 81.25% !important; }
  .ui.column.grid > [class*="fourteen wide computer"].column, .ui.grid > .column.row > [class*="fourteen wide computer"].column, .ui.grid > .row > [class*="fourteen wide computer"].column, .ui.grid > [class*="fourteen wide computer"].column { width: 87.5% !important; }
  .ui.column.grid > [class*="fifteen wide computer"].column, .ui.grid > .column.row > [class*="fifteen wide computer"].column, .ui.grid > .row > [class*="fifteen wide computer"].column, .ui.grid > [class*="fifteen wide computer"].column { width: 93.75% !important; }
  .ui.column.grid > [class*="sixteen wide computer"].column, .ui.grid > .column.row > [class*="sixteen wide computer"].column, .ui.grid > .row > [class*="sixteen wide computer"].column, .ui.grid > [class*="sixteen wide computer"].column { width: 100% !important; } }
@media only screen and (min-width: 1200px) and (max-width: 1919px) { .ui.column.grid > [class*="one wide large screen"].column, .ui.grid > .column.row > [class*="one wide large screen"].column, .ui.grid > .row > [class*="one wide large screen"].column, .ui.grid > [class*="one wide large screen"].column { width: 6.25% !important; }
  .ui.column.grid > [class*="two wide large screen"].column, .ui.grid > .column.row > [class*="two wide large screen"].column, .ui.grid > .row > [class*="two wide large screen"].column, .ui.grid > [class*="two wide large screen"].column { width: 12.5% !important; }
  .ui.column.grid > [class*="three wide large screen"].column, .ui.grid > .column.row > [class*="three wide large screen"].column, .ui.grid > .row > [class*="three wide large screen"].column, .ui.grid > [class*="three wide large screen"].column { width: 18.75% !important; }
  .ui.column.grid > [class*="four wide large screen"].column, .ui.grid > .column.row > [class*="four wide large screen"].column, .ui.grid > .row > [class*="four wide large screen"].column, .ui.grid > [class*="four wide large screen"].column { width: 25% !important; }
  .ui.column.grid > [class*="five wide large screen"].column, .ui.grid > .column.row > [class*="five wide large screen"].column, .ui.grid > .row > [class*="five wide large screen"].column, .ui.grid > [class*="five wide large screen"].column { width: 31.25% !important; }
  .ui.column.grid > [class*="six wide large screen"].column, .ui.grid > .column.row > [class*="six wide large screen"].column, .ui.grid > .row > [class*="six wide large screen"].column, .ui.grid > [class*="six wide large screen"].column { width: 37.5% !important; }
  .ui.column.grid > [class*="seven wide large screen"].column, .ui.grid > .column.row > [class*="seven wide large screen"].column, .ui.grid > .row > [class*="seven wide large screen"].column, .ui.grid > [class*="seven wide large screen"].column { width: 43.75% !important; }
  .ui.column.grid > [class*="eight wide large screen"].column, .ui.grid > .column.row > [class*="eight wide large screen"].column, .ui.grid > .row > [class*="eight wide large screen"].column, .ui.grid > [class*="eight wide large screen"].column { width: 50% !important; }
  .ui.column.grid > [class*="nine wide large screen"].column, .ui.grid > .column.row > [class*="nine wide large screen"].column, .ui.grid > .row > [class*="nine wide large screen"].column, .ui.grid > [class*="nine wide large screen"].column { width: 56.25% !important; }
  .ui.column.grid > [class*="ten wide large screen"].column, .ui.grid > .column.row > [class*="ten wide large screen"].column, .ui.grid > .row > [class*="ten wide large screen"].column, .ui.grid > [class*="ten wide large screen"].column { width: 62.5% !important; }
  .ui.column.grid > [class*="eleven wide large screen"].column, .ui.grid > .column.row > [class*="eleven wide large screen"].column, .ui.grid > .row > [class*="eleven wide large screen"].column, .ui.grid > [class*="eleven wide large screen"].column { width: 68.75% !important; }
  .ui.column.grid > [class*="twelve wide large screen"].column, .ui.grid > .column.row > [class*="twelve wide large screen"].column, .ui.grid > .row > [class*="twelve wide large screen"].column, .ui.grid > [class*="twelve wide large screen"].column { width: 75% !important; }
  .ui.column.grid > [class*="thirteen wide large screen"].column, .ui.grid > .column.row > [class*="thirteen wide large screen"].column, .ui.grid > .row > [class*="thirteen wide large screen"].column, .ui.grid > [class*="thirteen wide large screen"].column { width: 81.25% !important; }
  .ui.column.grid > [class*="fourteen wide large screen"].column, .ui.grid > .column.row > [class*="fourteen wide large screen"].column, .ui.grid > .row > [class*="fourteen wide large screen"].column, .ui.grid > [class*="fourteen wide large screen"].column { width: 87.5% !important; }
  .ui.column.grid > [class*="fifteen wide large screen"].column, .ui.grid > .column.row > [class*="fifteen wide large screen"].column, .ui.grid > .row > [class*="fifteen wide large screen"].column, .ui.grid > [class*="fifteen wide large screen"].column { width: 93.75% !important; }
  .ui.column.grid > [class*="sixteen wide large screen"].column, .ui.grid > .column.row > [class*="sixteen wide large screen"].column, .ui.grid > .row > [class*="sixteen wide large screen"].column, .ui.grid > [class*="sixteen wide large screen"].column { width: 100% !important; } }
@media only screen and (min-width: 1920px) { .ui.column.grid > [class*="one wide widescreen"].column, .ui.grid > .column.row > [class*="one wide widescreen"].column, .ui.grid > .row > [class*="one wide widescreen"].column, .ui.grid > [class*="one wide widescreen"].column { width: 6.25% !important; }
  .ui.column.grid > [class*="two wide widescreen"].column, .ui.grid > .column.row > [class*="two wide widescreen"].column, .ui.grid > .row > [class*="two wide widescreen"].column, .ui.grid > [class*="two wide widescreen"].column { width: 12.5% !important; }
  .ui.column.grid > [class*="three wide widescreen"].column, .ui.grid > .column.row > [class*="three wide widescreen"].column, .ui.grid > .row > [class*="three wide widescreen"].column, .ui.grid > [class*="three wide widescreen"].column { width: 18.75% !important; }
  .ui.column.grid > [class*="four wide widescreen"].column, .ui.grid > .column.row > [class*="four wide widescreen"].column, .ui.grid > .row > [class*="four wide widescreen"].column, .ui.grid > [class*="four wide widescreen"].column { width: 25% !important; }
  .ui.column.grid > [class*="five wide widescreen"].column, .ui.grid > .column.row > [class*="five wide widescreen"].column, .ui.grid > .row > [class*="five wide widescreen"].column, .ui.grid > [class*="five wide widescreen"].column { width: 31.25% !important; }
  .ui.column.grid > [class*="six wide widescreen"].column, .ui.grid > .column.row > [class*="six wide widescreen"].column, .ui.grid > .row > [class*="six wide widescreen"].column, .ui.grid > [class*="six wide widescreen"].column { width: 37.5% !important; }
  .ui.column.grid > [class*="seven wide widescreen"].column, .ui.grid > .column.row > [class*="seven wide widescreen"].column, .ui.grid > .row > [class*="seven wide widescreen"].column, .ui.grid > [class*="seven wide widescreen"].column { width: 43.75% !important; }
  .ui.column.grid > [class*="eight wide widescreen"].column, .ui.grid > .column.row > [class*="eight wide widescreen"].column, .ui.grid > .row > [class*="eight wide widescreen"].column, .ui.grid > [class*="eight wide widescreen"].column { width: 50% !important; }
  .ui.column.grid > [class*="nine wide widescreen"].column, .ui.grid > .column.row > [class*="nine wide widescreen"].column, .ui.grid > .row > [class*="nine wide widescreen"].column, .ui.grid > [class*="nine wide widescreen"].column { width: 56.25% !important; }
  .ui.column.grid > [class*="ten wide widescreen"].column, .ui.grid > .column.row > [class*="ten wide widescreen"].column, .ui.grid > .row > [class*="ten wide widescreen"].column, .ui.grid > [class*="ten wide widescreen"].column { width: 62.5% !important; }
  .ui.column.grid > [class*="eleven wide widescreen"].column, .ui.grid > .column.row > [class*="eleven wide widescreen"].column, .ui.grid > .row > [class*="eleven wide widescreen"].column, .ui.grid > [class*="eleven wide widescreen"].column { width: 68.75% !important; }
  .ui.column.grid > [class*="twelve wide widescreen"].column, .ui.grid > .column.row > [class*="twelve wide widescreen"].column, .ui.grid > .row > [class*="twelve wide widescreen"].column, .ui.grid > [class*="twelve wide widescreen"].column { width: 75% !important; }
  .ui.column.grid > [class*="thirteen wide widescreen"].column, .ui.grid > .column.row > [class*="thirteen wide widescreen"].column, .ui.grid > .row > [class*="thirteen wide widescreen"].column, .ui.grid > [class*="thirteen wide widescreen"].column { width: 81.25% !important; }
  .ui.column.grid > [class*="fourteen wide widescreen"].column, .ui.grid > .column.row > [class*="fourteen wide widescreen"].column, .ui.grid > .row > [class*="fourteen wide widescreen"].column, .ui.grid > [class*="fourteen wide widescreen"].column { width: 87.5% !important; }
  .ui.column.grid > [class*="fifteen wide widescreen"].column, .ui.grid > .column.row > [class*="fifteen wide widescreen"].column, .ui.grid > .row > [class*="fifteen wide widescreen"].column, .ui.grid > [class*="fifteen wide widescreen"].column { width: 93.75% !important; }
  .ui.column.grid > [class*="sixteen wide widescreen"].column, .ui.grid > .column.row > [class*="sixteen wide widescreen"].column, .ui.grid > .row > [class*="sixteen wide widescreen"].column, .ui.grid > [class*="sixteen wide widescreen"].column { width: 100% !important; } }
.ui.centered.grid, .ui.centered.grid > .row, .ui.grid > .centered.row { text-align: center; -webkit-box-pack: center; -ms-flex-pack: center; justify-content: center; }
.ui.centered.grid > .column:not(.aligned):not(.justified):not(.row), .ui.centered.grid > .row > .column:not(.aligned):not(.justified), .ui.grid .centered.row > .column:not(.aligned):not(.justified) { text-align: left; }
.ui.grid > .centered.column, .ui.grid > .row > .centered.column { display: block; margin-left: auto; margin-right: auto; }
.ui.grid > .relaxed.row > .column, .ui.relaxed.grid > .column:not(.row), .ui.relaxed.grid > .row > .column { padding-left: 1.5rem; padding-right: 1.5rem; }
.ui.grid > [class*="very relaxed"].row > .column, .ui[class*="very relaxed"].grid > .column:not(.row), .ui[class*="very relaxed"].grid > .row > .column { padding-left: 2.5rem; padding-right: 2.5rem; }
.ui.grid .relaxed.row + .ui.divider, .ui.relaxed.grid .row + .ui.divider { margin-left: 1.5rem; margin-right: 1.5rem; }
.ui.grid [class*="very relaxed"].row + .ui.divider, .ui[class*="very relaxed"].grid .row + .ui.divider { margin-left: 2.5rem; margin-right: 2.5rem; }
.ui.padded.grid:not(.vertically):not(.horizontally) { margin: 0 !important; }
[class*="horizontally padded"].ui.grid { margin-left: 0 !important; margin-right: 0 !important; }
[class*="vertically padded"].ui.grid { margin-top: 0 !important; margin-bottom: 0 !important; }
.ui.grid [class*="left floated"].column { margin-right: auto; }
.ui.grid [class*="right floated"].column { margin-left: auto; }
.ui.divided.grid:not([class*="vertically divided"]) > .column:not(.row), .ui.divided.grid:not([class*="vertically divided"]) > .row > .column { -webkit-box-shadow: -1px 0 0 0 rgba(34, 36, 38, 0.15); box-shadow: -1px 0 0 0 rgba(34, 36, 38, 0.15); }
.ui[class*="vertically divided"].grid > .column:not(.row), .ui[class*="vertically divided"].grid > .row > .column { margin-top: 1rem; margin-bottom: 1rem; padding-top: 0; padding-bottom: 0; }
.ui[class*="vertically divided"].grid > .row { margin-top: 0; margin-bottom: 0; }
.ui.divided.grid:not([class*="vertically divided"]) > .column:first-child, .ui.divided.grid:not([class*="vertically divided"]) > .row > .column:first-child { -webkit-box-shadow: none; box-shadow: none; }
.ui[class*="vertically divided"].grid > .row:first-child > .column { margin-top: 0; }
.ui.grid > .divided.row > .column { -webkit-box-shadow: -1px 0 0 0 rgba(34, 36, 38, 0.15); box-shadow: -1px 0 0 0 rgba(34, 36, 38, 0.15); }
.ui.grid > .divided.row > .column:first-child { -webkit-box-shadow: none; box-shadow: none; }
.ui[class*="vertically divided"].grid > .row { position: relative; }
.ui[class*="vertically divided"].grid > .row:before { position: absolute; content: ""; top: 0; left: 0; width: calc(100% - 2rem); height: 1px; margin: 0 1rem; -webkit-box-shadow: 0 -1px 0 0 rgba(34, 36, 38, 0.15); box-shadow: 0 -1px 0 0 rgba(34, 36, 38, 0.15); }
.ui.padded.divided.grid:not(.vertically):not(.horizontally), [class*="horizontally padded"].ui.divided.grid { width: 100%; }
.ui[class*="vertically divided"].grid > .row:first-child:before { -webkit-box-shadow: none; box-shadow: none; }
.ui.inverted.divided.grid:not([class*="vertically divided"]) > .column:not(.row), .ui.inverted.divided.grid:not([class*="vertically divided"]) > .row > .column { -webkit-box-shadow: -1px 0 0 0 rgba(255, 255, 255, 0.1); box-shadow: -1px 0 0 0 rgba(255, 255, 255, 0.1); }
.ui.inverted.divided.grid:not([class*="vertically divided"]) > .column:not(.row):first-child, .ui.inverted.divided.grid:not([class*="vertically divided"]) > .row > .column:first-child { -webkit-box-shadow: none; box-shadow: none; }
.ui.inverted[class*="vertically divided"].grid > .row:before { -webkit-box-shadow: 0 -1px 0 0 rgba(255, 255, 255, 0.1); box-shadow: 0 -1px 0 0 rgba(255, 255, 255, 0.1); }
.ui.relaxed[class*="vertically divided"].grid > .row:before { margin-left: 1.5rem; margin-right: 1.5rem; width: calc(100% - 3rem); }
.ui[class*="very relaxed"][class*="vertically divided"].grid > .row:before { margin-left: 2.5rem; margin-right: 2.5rem; width: calc(100% - 5rem); }
.ui.celled.grid { width: 100%; margin: 1em 0; -webkit-box-shadow: 0 0 0 1px #d4d4d5; box-shadow: 0 0 0 1px #d4d4d5; }
.ui.celled.grid > .row { width: 100% !important; margin: 0; padding: 0; -webkit-box-shadow: 0 -1px 0 0 #d4d4d5; box-shadow: 0 -1px 0 0 #d4d4d5; }
.ui.celled.grid > .column:not(.row), .ui.celled.grid > .row > .column { -webkit-box-shadow: -1px 0 0 0 #d4d4d5; box-shadow: -1px 0 0 0 #d4d4d5; }
.ui.celled.grid > .column:first-child, .ui.celled.grid > .row > .column:first-child { -webkit-box-shadow: none; box-shadow: none; }
.ui.celled.grid > .column:not(.row), .ui.celled.grid > .row > .column { padding: 1em; }
.ui.relaxed.celled.grid > .column:not(.row), .ui.relaxed.celled.grid > .row > .column { padding: 1.5em; }
.ui[class*="very relaxed"].celled.grid > .column:not(.row), .ui[class*="very relaxed"].celled.grid > .row > .column { padding: 2em; }
.ui[class*="internally celled"].grid { -webkit-box-shadow: none; box-shadow: none; margin: 0; }
.ui[class*="internally celled"].grid > .row:first-child { -webkit-box-shadow: none; box-shadow: none; }
.ui[class*="internally celled"].grid > .row > .column:first-child { -webkit-box-shadow: none; box-shadow: none; }
.ui.grid > .row > [class*="top aligned"].column, .ui.grid > [class*="top aligned"].column:not(.row), .ui.grid > [class*="top aligned"].row > .column, .ui[class*="top aligned"].grid > .column:not(.row), .ui[class*="top aligned"].grid > .row > .column { -webkit-box-orient: vertical; -webkit-box-direction: normal; -ms-flex-direction: column; flex-direction: column; vertical-align: top; -ms-flex-item-align: start !important; align-self: flex-start !important; }
.ui.grid > .row > [class*="middle aligned"].column, .ui.grid > [class*="middle aligned"].column:not(.row), .ui.grid > [class*="middle aligned"].row > .column, .ui[class*="middle aligned"].grid > .column:not(.row), .ui[class*="middle aligned"].grid > .row > .column { -webkit-box-orient: vertical; -webkit-box-direction: normal; -ms-flex-direction: column; flex-direction: column; vertical-align: middle; -ms-flex-item-align: center !important; align-self: center !important; }
.ui.grid > .row > [class*="bottom aligned"].column, .ui.grid > [class*="bottom aligned"].column:not(.row), .ui.grid > [class*="bottom aligned"].row > .column, .ui[class*="bottom aligned"].grid > .column:not(.row), .ui[class*="bottom aligned"].grid > .row > .column { -webkit-box-orient: vertical; -webkit-box-direction: normal; -ms-flex-direction: column; flex-direction: column; vertical-align: bottom; -ms-flex-item-align: end !important; align-self: flex-end !important; }
.ui.grid > .row > .stretched.column, .ui.grid > .stretched.column:not(.row), .ui.grid > .stretched.row > .column, .ui.stretched.grid > .column, .ui.stretched.grid > .row > .column { display: -webkit-inline-box !important; display: -ms-inline-flexbox !important; display: inline-flex !important; -ms-flex-item-align: stretch; align-self: stretch; -webkit-box-orient: vertical; -webkit-box-direction: normal; -ms-flex-direction: column; flex-direction: column; }
.ui.grid > .row > .stretched.column > *, .ui.grid > .stretched.column:not(.row) > *, .ui.grid > .stretched.row > .column > *, .ui.stretched.grid > .column > *, .ui.stretched.grid > .row > .column > * { -webkit-box-flex: 1; -ms-flex-positive: 1; flex-grow: 1; }
.ui.grid > .row > [class*="left aligned"].column.column, .ui.grid > [class*="left aligned"].column.column, .ui.grid > [class*="left aligned"].row > .column, .ui[class*="left aligned"].grid > .column, .ui[class*="left aligned"].grid > .row > .column { text-align: left; -ms-flex-item-align: inherit; align-self: inherit; }
.ui.grid > .row > [class*="center aligned"].column.column, .ui.grid > [class*="center aligned"].column.column, .ui.grid > [class*="center aligned"].row > .column, .ui[class*="center aligned"].grid > .column, .ui[class*="center aligned"].grid > .row > .column { text-align: center; -ms-flex-item-align: inherit; align-self: inherit; }
.ui[class*="center aligned"].grid { -webkit-box-pack: center; -ms-flex-pack: center; justify-content: center; }
.ui.grid > .row > [class*="right aligned"].column.column, .ui.grid > [class*="right aligned"].column.column, .ui.grid > [class*="right aligned"].row > .column, .ui[class*="right aligned"].grid > .column, .ui[class*="right aligned"].grid > .row > .column { text-align: right; -ms-flex-item-align: inherit; align-self: inherit; }
.ui.grid > .justified.column.column, .ui.grid > .justified.row > .column, .ui.grid > .row > .justified.column.column, .ui.justified.grid > .column, .ui.justified.grid > .row > .column { text-align: justify; -webkit-hyphens: auto; -ms-hyphens: auto; hyphens: auto; }
.ui.grid > .row > .black.column, .ui.grid > .row > .blue.column, .ui.grid > .row > .brown.column, .ui.grid > .row > .green.column, .ui.grid > .row > .grey.column, .ui.grid > .row > .olive.column, .ui.grid > .row > .orange.column, .ui.grid > .row > .pink.column, .ui.grid > .row > .purple.column, .ui.grid > .row > .red.column, .ui.grid > .row > .teal.column, .ui.grid > .row > .violet.column, .ui.grid > .row > .yellow.column { margin-top: -1rem; margin-bottom: -1rem; padding-top: 1rem; padding-bottom: 1rem; }
.ui.grid > .red.column, .ui.grid > .red.row, .ui.grid > .row > .red.column { background-color: #db2828 !important; color: #fff; }
.ui.grid > .orange.column, .ui.grid > .orange.row, .ui.grid > .row > .orange.column { background-color: #f2711c !important; color: #fff; }
.ui.grid > .row > .yellow.column, .ui.grid > .yellow.column, .ui.grid > .yellow.row { background-color: #fbbd08 !important; color: #fff; }
.ui.grid > .olive.column, .ui.grid > .olive.row, .ui.grid > .row > .olive.column { background-color: #b5cc18 !important; color: #fff; }
.ui.grid > .green.column, .ui.grid > .green.row, .ui.grid > .row > .green.column { background-color: #21ba45 !important; color: #fff; }
.ui.grid > .row > .teal.column, .ui.grid > .teal.column, .ui.grid > .teal.row { background-color: #00b5ad !important; color: #fff; }
.ui.grid > .blue.column, .ui.grid > .blue.row, .ui.grid > .row > .blue.column { background-color: #2185d0 !important; color: #fff; }
.ui.grid > .row > .violet.column, .ui.grid > .violet.column, .ui.grid > .violet.row { background-color: #6435c9 !important; color: #fff; }
.ui.grid > .purple.column, .ui.grid > .purple.row, .ui.grid > .row > .purple.column { background-color: #a333c8 !important; color: #fff; }
.ui.grid > .pink.column, .ui.grid > .pink.row, .ui.grid > .row > .pink.column { background-color: #e03997 !important; color: #fff; }
.ui.grid > .brown.column, .ui.grid > .brown.row, .ui.grid > .row > .brown.column { background-color: #a5673f !important; color: #fff; }
.ui.grid > .grey.column, .ui.grid > .grey.row, .ui.grid > .row > .grey.column { background-color: #767676 !important; color: #fff; }
.ui.grid > .black.column, .ui.grid > .black.row, .ui.grid > .row > .black.column { background-color: #1b1c1d !important; color: #fff; }
.ui.grid > [class*="equal width"].row > .column, .ui[class*="equal width"].grid > .column:not(.row), .ui[class*="equal width"].grid > .row > .column { display: inline-block; -webkit-box-flex: 1; -ms-flex-positive: 1; flex-grow: 1; }
.ui.grid > [class*="equal width"].row > .wide.column, .ui[class*="equal width"].grid > .row > .wide.column, .ui[class*="equal width"].grid > .wide.column { -webkit-box-flex: 0; -ms-flex-positive: 0; flex-grow: 0; }
@media only screen and (max-width: 767px) { .ui.grid > [class*="mobile reversed"].row, .ui[class*="mobile reversed"].grid, .ui[class*="mobile reversed"].grid > .row { -webkit-box-orient: horizontal; -webkit-box-direction: reverse; -ms-flex-direction: row-reverse; flex-direction: row-reverse; }
  .ui.stackable[class*="mobile reversed"], .ui[class*="mobile vertically reversed"].grid { -webkit-box-orient: vertical; -webkit-box-direction: reverse; -ms-flex-direction: column-reverse; flex-direction: column-reverse; }
  .ui[class*="mobile reversed"].divided.grid:not([class*="vertically divided"]) > .column:first-child, .ui[class*="mobile reversed"].divided.grid:not([class*="vertically divided"]) > .row > .column:first-child { -webkit-box-shadow: -1px 0 0 0 rgba(34, 36, 38, 0.15); box-shadow: -1px 0 0 0 rgba(34, 36, 38, 0.15); }
  .ui[class*="mobile reversed"].divided.grid:not([class*="vertically divided"]) > .column:last-child, .ui[class*="mobile reversed"].divided.grid:not([class*="vertically divided"]) > .row > .column:last-child { -webkit-box-shadow: none; box-shadow: none; }
  .ui.grid[class*="vertically divided"][class*="mobile vertically reversed"] > .row:first-child:before { -webkit-box-shadow: 0 -1px 0 0 rgba(34, 36, 38, 0.15); box-shadow: 0 -1px 0 0 rgba(34, 36, 38, 0.15); }
  .ui.grid[class*="vertically divided"][class*="mobile vertically reversed"] > .row:last-child:before { -webkit-box-shadow: none; box-shadow: none; }
  .ui[class*="mobile reversed"].celled.grid > .row > .column:first-child { -webkit-box-shadow: -1px 0 0 0 #d4d4d5; box-shadow: -1px 0 0 0 #d4d4d5; }
  .ui[class*="mobile reversed"].celled.grid > .row > .column:last-child { -webkit-box-shadow: none; box-shadow: none; } }
@media only screen and (min-width: 768px) and (max-width: 991px) { .ui.grid > [class*="tablet reversed"].row, .ui[class*="tablet reversed"].grid, .ui[class*="tablet reversed"].grid > .row { -webkit-box-orient: horizontal; -webkit-box-direction: reverse; -ms-flex-direction: row-reverse; flex-direction: row-reverse; }
  .ui[class*="tablet vertically reversed"].grid { -webkit-box-orient: vertical; -webkit-box-direction: reverse; -ms-flex-direction: column-reverse; flex-direction: column-reverse; }
  .ui[class*="tablet reversed"].divided.grid:not([class*="vertically divided"]) > .column:first-child, .ui[class*="tablet reversed"].divided.grid:not([class*="vertically divided"]) > .row > .column:first-child { -webkit-box-shadow: -1px 0 0 0 rgba(34, 36, 38, 0.15); box-shadow: -1px 0 0 0 rgba(34, 36, 38, 0.15); }
  .ui[class*="tablet reversed"].divided.grid:not([class*="vertically divided"]) > .column:last-child, .ui[class*="tablet reversed"].divided.grid:not([class*="vertically divided"]) > .row > .column:last-child { -webkit-box-shadow: none; box-shadow: none; }
  .ui.grid[class*="vertically divided"][class*="tablet vertically reversed"] > .row:first-child:before { -webkit-box-shadow: 0 -1px 0 0 rgba(34, 36, 38, 0.15); box-shadow: 0 -1px 0 0 rgba(34, 36, 38, 0.15); }
  .ui.grid[class*="vertically divided"][class*="tablet vertically reversed"] > .row:last-child:before { -webkit-box-shadow: none; box-shadow: none; }
  .ui[class*="tablet reversed"].celled.grid > .row > .column:first-child { -webkit-box-shadow: -1px 0 0 0 #d4d4d5; box-shadow: -1px 0 0 0 #d4d4d5; }
  .ui[class*="tablet reversed"].celled.grid > .row > .column:last-child { -webkit-box-shadow: none; box-shadow: none; } }
@media only screen and (min-width: 992px) { .ui.grid > [class*="computer reversed"].row, .ui[class*="computer reversed"].grid, .ui[class*="computer reversed"].grid > .row { -webkit-box-orient: horizontal; -webkit-box-direction: reverse; -ms-flex-direction: row-reverse; flex-direction: row-reverse; }
  .ui[class*="computer vertically reversed"].grid { -webkit-box-orient: vertical; -webkit-box-direction: reverse; -ms-flex-direction: column-reverse; flex-direction: column-reverse; }
  .ui[class*="computer reversed"].divided.grid:not([class*="vertically divided"]) > .column:first-child, .ui[class*="computer reversed"].divided.grid:not([class*="vertically divided"]) > .row > .column:first-child { -webkit-box-shadow: -1px 0 0 0 rgba(34, 36, 38, 0.15); box-shadow: -1px 0 0 0 rgba(34, 36, 38, 0.15); }
  .ui[class*="computer reversed"].divided.grid:not([class*="vertically divided"]) > .column:last-child, .ui[class*="computer reversed"].divided.grid:not([class*="vertically divided"]) > .row > .column:last-child { -webkit-box-shadow: none; box-shadow: none; }
  .ui.grid[class*="vertically divided"][class*="computer vertically reversed"] > .row:first-child:before { -webkit-box-shadow: 0 -1px 0 0 rgba(34, 36, 38, 0.15); box-shadow: 0 -1px 0 0 rgba(34, 36, 38, 0.15); }
  .ui.grid[class*="vertically divided"][class*="computer vertically reversed"] > .row:last-child:before { -webkit-box-shadow: none; box-shadow: none; }
  .ui[class*="computer reversed"].celled.grid > .row > .column:first-child { -webkit-box-shadow: -1px 0 0 0 #d4d4d5; box-shadow: -1px 0 0 0 #d4d4d5; }
  .ui[class*="computer reversed"].celled.grid > .row > .column:last-child { -webkit-box-shadow: none; box-shadow: none; } }
@media only screen and (min-width: 768px) and (max-width: 991px) { .ui.doubling.grid { width: auto; }
  .ui.doubling.grid > .row, .ui.grid > .doubling.row { margin: 0 !important; padding: 0 !important; }
  .ui.doubling.grid > .row > .column, .ui.grid > .doubling.row > .column { display: inline-block !important; padding-top: 1rem !important; padding-bottom: 1rem !important; -webkit-box-shadow: none !important; box-shadow: none !important; margin: 0; }
  .ui.grid > [class*="two column"].doubling.row.row > .column, .ui[class*="two column"].doubling.grid > .column:not(.row), .ui[class*="two column"].doubling.grid > .row > .column { width: 100% !important; }
  .ui.grid > [class*="three column"].doubling.row.row > .column, .ui[class*="three column"].doubling.grid > .column:not(.row), .ui[class*="three column"].doubling.grid > .row > .column { width: 50% !important; }
  .ui.grid > [class*="four column"].doubling.row.row > .column, .ui[class*="four column"].doubling.grid > .column:not(.row), .ui[class*="four column"].doubling.grid > .row > .column { width: 50% !important; }
  .ui.grid > [class*="five column"].doubling.row.row > .column, .ui[class*="five column"].doubling.grid > .column:not(.row), .ui[class*="five column"].doubling.grid > .row > .column { width: 33.33333333% !important; }
  .ui.grid > [class*="six column"].doubling.row.row > .column, .ui[class*="six column"].doubling.grid > .column:not(.row), .ui[class*="six column"].doubling.grid > .row > .column { width: 33.33333333% !important; }
  .ui.grid > [class*="seven column"].doubling.row.row > .column, .ui[class*="seven column"].doubling.grid > .column:not(.row), .ui[class*="seven column"].doubling.grid > .row > .column { width: 33.33333333% !important; }
  .ui.grid > [class*="eight column"].doubling.row.row > .column, .ui[class*="eight column"].doubling.grid > .column:not(.row), .ui[class*="eight column"].doubling.grid > .row > .column { width: 25% !important; }
  .ui.grid > [class*="nine column"].doubling.row.row > .column, .ui[class*="nine column"].doubling.grid > .column:not(.row), .ui[class*="nine column"].doubling.grid > .row > .column { width: 25% !important; }
  .ui.grid > [class*="ten column"].doubling.row.row > .column, .ui[class*="ten column"].doubling.grid > .column:not(.row), .ui[class*="ten column"].doubling.grid > .row > .column { width: 20% !important; }
  .ui.grid > [class*="eleven column"].doubling.row.row > .column, .ui[class*="eleven column"].doubling.grid > .column:not(.row), .ui[class*="eleven column"].doubling.grid > .row > .column { width: 20% !important; }
  .ui.grid > [class*="twelve column"].doubling.row.row > .column, .ui[class*="twelve column"].doubling.grid > .column:not(.row), .ui[class*="twelve column"].doubling.grid > .row > .column { width: 16.66666667% !important; }
  .ui.grid > [class*="thirteen column"].doubling.row.row > .column, .ui[class*="thirteen column"].doubling.grid > .column:not(.row), .ui[class*="thirteen column"].doubling.grid > .row > .column { width: 16.66666667% !important; }
  .ui.grid > [class*="fourteen column"].doubling.row.row > .column, .ui[class*="fourteen column"].doubling.grid > .column:not(.row), .ui[class*="fourteen column"].doubling.grid > .row > .column { width: 14.28571429% !important; }
  .ui.grid > [class*="fifteen column"].doubling.row.row > .column, .ui[class*="fifteen column"].doubling.grid > .column:not(.row), .ui[class*="fifteen column"].doubling.grid > .row > .column { width: 14.28571429% !important; }
  .ui.grid > [class*="sixteen column"].doubling.row.row > .column, .ui[class*="sixteen column"].doubling.grid > .column:not(.row), .ui[class*="sixteen column"].doubling.grid > .row > .column { width: 12.5% !important; } }
@media only screen and (max-width: 767px) { .ui.doubling.grid > .row, .ui.grid > .doubling.row { margin: 0 !important; padding: 0 !important; }
  .ui.doubling.grid > .row > .column, .ui.grid > .doubling.row > .column { padding-top: 1rem !important; padding-bottom: 1rem !important; margin: 0 !important; -webkit-box-shadow: none !important; box-shadow: none !important; }
  .ui.grid > [class*="two column"].doubling:not(.stackable).row.row > .column, .ui[class*="two column"].doubling:not(.stackable).grid > .column:not(.row), .ui[class*="two column"].doubling:not(.stackable).grid > .row > .column { width: 100% !important; }
  .ui.grid > [class*="three column"].doubling:not(.stackable).row.row > .column, .ui[class*="three column"].doubling:not(.stackable).grid > .column:not(.row), .ui[class*="three column"].doubling:not(.stackable).grid > .row > .column { width: 50% !important; }
  .ui.grid > [class*="four column"].doubling:not(.stackable).row.row > .column, .ui[class*="four column"].doubling:not(.stackable).grid > .column:not(.row), .ui[class*="four column"].doubling:not(.stackable).grid > .row > .column { width: 50% !important; }
  .ui.grid > [class*="five column"].doubling:not(.stackable).row.row > .column, .ui[class*="five column"].doubling:not(.stackable).grid > .column:not(.row), .ui[class*="five column"].doubling:not(.stackable).grid > .row > .column { width: 50% !important; }
  .ui.grid > [class*="six column"].doubling:not(.stackable).row.row > .column, .ui[class*="six column"].doubling:not(.stackable).grid > .column:not(.row), .ui[class*="six column"].doubling:not(.stackable).grid > .row > .column { width: 50% !important; }
  .ui.grid > [class*="seven column"].doubling:not(.stackable).row.row > .column, .ui[class*="seven column"].doubling:not(.stackable).grid > .column:not(.row), .ui[class*="seven column"].doubling:not(.stackable).grid > .row > .column { width: 50% !important; }
  .ui.grid > [class*="eight column"].doubling:not(.stackable).row.row > .column, .ui[class*="eight column"].doubling:not(.stackable).grid > .column:not(.row), .ui[class*="eight column"].doubling:not(.stackable).grid > .row > .column { width: 50% !important; }
  .ui.grid > [class*="nine column"].doubling:not(.stackable).row.row > .column, .ui[class*="nine column"].doubling:not(.stackable).grid > .column:not(.row), .ui[class*="nine column"].doubling:not(.stackable).grid > .row > .column { width: 33.33333333% !important; }
  .ui.grid > [class*="ten column"].doubling:not(.stackable).row.row > .column, .ui[class*="ten column"].doubling:not(.stackable).grid > .column:not(.row), .ui[class*="ten column"].doubling:not(.stackable).grid > .row > .column { width: 33.33333333% !important; }
  .ui.grid > [class*="eleven column"].doubling:not(.stackable).row.row > .column, .ui[class*="eleven column"].doubling:not(.stackable).grid > .column:not(.row), .ui[class*="eleven column"].doubling:not(.stackable).grid > .row > .column { width: 33.33333333% !important; }
  .ui.grid > [class*="twelve column"].doubling:not(.stackable).row.row > .column, .ui[class*="twelve column"].doubling:not(.stackable).grid > .column:not(.row), .ui[class*="twelve column"].doubling:not(.stackable).grid > .row > .column { width: 33.33333333% !important; }
  .ui.grid > [class*="thirteen column"].doubling:not(.stackable).row.row > .column, .ui[class*="thirteen column"].doubling:not(.stackable).grid > .column:not(.row), .ui[class*="thirteen column"].doubling:not(.stackable).grid > .row > .column { width: 33.33333333% !important; }
  .ui.grid > [class*="fourteen column"].doubling:not(.stackable).row.row > .column, .ui[class*="fourteen column"].doubling:not(.stackable).grid > .column:not(.row), .ui[class*="fourteen column"].doubling:not(.stackable).grid > .row > .column { width: 25% !important; }
  .ui.grid > [class*="fifteen column"].doubling:not(.stackable).row.row > .column, .ui[class*="fifteen column"].doubling:not(.stackable).grid > .column:not(.row), .ui[class*="fifteen column"].doubling:not(.stackable).grid > .row > .column { width: 25% !important; }
  .ui.grid > [class*="sixteen column"].doubling:not(.stackable).row.row > .column, .ui[class*="sixteen column"].doubling:not(.stackable).grid > .column:not(.row), .ui[class*="sixteen column"].doubling:not(.stackable).grid > .row > .column { width: 25% !important; } }
@media only screen and (max-width: 767px) { .ui.stackable.grid { width: auto; margin-left: 0 !important; margin-right: 0 !important; }
  .ui.grid > .stackable.stackable.row > .column, .ui.stackable.grid > .column.grid > .column, .ui.stackable.grid > .column.row > .column, .ui.stackable.grid > .column:not(.row), .ui.stackable.grid > .row > .column, .ui.stackable.grid > .row > .wide.column, .ui.stackable.grid > .wide.column { width: 100% !important; margin: 0 0 !important; -webkit-box-shadow: none !important; box-shadow: none !important; padding: 1rem 1rem !important; }
  .ui.stackable.grid:not(.vertically) > .row { margin: 0; padding: 0; }
  .ui.container > .ui.stackable.grid > .column, .ui.container > .ui.stackable.grid > .row > .column { padding-left: 0 !important; padding-right: 0 !important; }
  .ui.grid .ui.stackable.grid, .ui.segment:not(.vertical) .ui.stackable.page.grid { margin-left: -1rem !important; margin-right: -1rem !important; }
  .ui.stackable.celled.grid > .column:not(.row):first-child, .ui.stackable.celled.grid > .row:first-child > .column:first-child, .ui.stackable.divided.grid > .column:not(.row):first-child, .ui.stackable.divided.grid > .row:first-child > .column:first-child { border-top: none !important; }
  .ui.inverted.stackable.celled.grid > .column:not(.row), .ui.inverted.stackable.celled.grid > .row > .column, .ui.inverted.stackable.divided.grid > .column:not(.row), .ui.inverted.stackable.divided.grid > .row > .column { border-top: 1px solid rgba(255, 255, 255, 0.1); }
  .ui.stackable.celled.grid > .column:not(.row), .ui.stackable.celled.grid > .row > .column, .ui.stackable.divided:not(.vertically).grid > .column:not(.row), .ui.stackable.divided:not(.vertically).grid > .row > .column { border-top: 1px solid rgba(34, 36, 38, 0.15); -webkit-box-shadow: none !important; box-shadow: none !important; padding-top: 2rem !important; padding-bottom: 2rem !important; }
  .ui.stackable.celled.grid > .row { -webkit-box-shadow: none !important; box-shadow: none !important; }
  .ui.stackable.divided:not(.vertically).grid > .column:not(.row), .ui.stackable.divided:not(.vertically).grid > .row > .column { padding-left: 0 !important; padding-right: 0 !important; } }
@media only screen and (max-width: 767px) { .ui.grid.grid.grid > .row > [class*="tablet only"].column:not(.mobile), .ui.grid.grid.grid > [class*="tablet only"].column:not(.mobile), .ui.grid.grid.grid > [class*="tablet only"].row:not(.mobile), .ui[class*="tablet only"].grid.grid.grid:not(.mobile) { display: none !important; }
  .ui.grid.grid.grid > .row > [class*="computer only"].column:not(.mobile), .ui.grid.grid.grid > [class*="computer only"].column:not(.mobile), .ui.grid.grid.grid > [class*="computer only"].row:not(.mobile), .ui[class*="computer only"].grid.grid.grid:not(.mobile) { display: none !important; }
  .ui.grid.grid.grid > .row > [class*="large screen only"].column:not(.mobile), .ui.grid.grid.grid > [class*="large screen only"].column:not(.mobile), .ui.grid.grid.grid > [class*="large screen only"].row:not(.mobile), .ui[class*="large screen only"].grid.grid.grid:not(.mobile) { display: none !important; }
  .ui.grid.grid.grid > .row > [class*="widescreen only"].column:not(.mobile), .ui.grid.grid.grid > [class*="widescreen only"].column:not(.mobile), .ui.grid.grid.grid > [class*="widescreen only"].row:not(.mobile), .ui[class*="widescreen only"].grid.grid.grid:not(.mobile) { display: none !important; } }
@media only screen and (min-width: 768px) and (max-width: 991px) { .ui.grid.grid.grid > .row > [class*="mobile only"].column:not(.tablet), .ui.grid.grid.grid > [class*="mobile only"].column:not(.tablet), .ui.grid.grid.grid > [class*="mobile only"].row:not(.tablet), .ui[class*="mobile only"].grid.grid.grid:not(.tablet) { display: none !important; }
  .ui.grid.grid.grid > .row > [class*="computer only"].column:not(.tablet), .ui.grid.grid.grid > [class*="computer only"].column:not(.tablet), .ui.grid.grid.grid > [class*="computer only"].row:not(.tablet), .ui[class*="computer only"].grid.grid.grid:not(.tablet) { display: none !important; }
  .ui.grid.grid.grid > .row > [class*="large screen only"].column:not(.mobile), .ui.grid.grid.grid > [class*="large screen only"].column:not(.mobile), .ui.grid.grid.grid > [class*="large screen only"].row:not(.mobile), .ui[class*="large screen only"].grid.grid.grid:not(.mobile) { display: none !important; }
  .ui.grid.grid.grid > .row > [class*="widescreen only"].column:not(.mobile), .ui.grid.grid.grid > [class*="widescreen only"].column:not(.mobile), .ui.grid.grid.grid > [class*="widescreen only"].row:not(.mobile), .ui[class*="widescreen only"].grid.grid.grid:not(.mobile) { display: none !important; } }
@media only screen and (min-width: 992px) and (max-width: 1199px) { .ui.grid.grid.grid > .row > [class*="mobile only"].column:not(.computer), .ui.grid.grid.grid > [class*="mobile only"].column:not(.computer), .ui.grid.grid.grid > [class*="mobile only"].row:not(.computer), .ui[class*="mobile only"].grid.grid.grid:not(.computer) { display: none !important; }
  .ui.grid.grid.grid > .row > [class*="tablet only"].column:not(.computer), .ui.grid.grid.grid > [class*="tablet only"].column:not(.computer), .ui.grid.grid.grid > [class*="tablet only"].row:not(.computer), .ui[class*="tablet only"].grid.grid.grid:not(.computer) { display: none !important; }
  .ui.grid.grid.grid > .row > [class*="large screen only"].column:not(.mobile), .ui.grid.grid.grid > [class*="large screen only"].column:not(.mobile), .ui.grid.grid.grid > [class*="large screen only"].row:not(.mobile), .ui[class*="large screen only"].grid.grid.grid:not(.mobile) { display: none !important; }
  .ui.grid.grid.grid > .row > [class*="widescreen only"].column:not(.mobile), .ui.grid.grid.grid > [class*="widescreen only"].column:not(.mobile), .ui.grid.grid.grid > [class*="widescreen only"].row:not(.mobile), .ui[class*="widescreen only"].grid.grid.grid:not(.mobile) { display: none !important; } }
@media only screen and (min-width: 1200px) and (max-width: 1919px) { .ui.grid.grid.grid > .row > [class*="mobile only"].column:not(.computer), .ui.grid.grid.grid > [class*="mobile only"].column:not(.computer), .ui.grid.grid.grid > [class*="mobile only"].row:not(.computer), .ui[class*="mobile only"].grid.grid.grid:not(.computer) { display: none !important; }
  .ui.grid.grid.grid > .row > [class*="tablet only"].column:not(.computer), .ui.grid.grid.grid > [class*="tablet only"].column:not(.computer), .ui.grid.grid.grid > [class*="tablet only"].row:not(.computer), .ui[class*="tablet only"].grid.grid.grid:not(.computer) { display: none !important; }
  .ui.grid.grid.grid > .row > [class*="widescreen only"].column:not(.mobile), .ui.grid.grid.grid > [class*="widescreen only"].column:not(.mobile), .ui.grid.grid.grid > [class*="widescreen only"].row:not(.mobile), .ui[class*="widescreen only"].grid.grid.grid:not(.mobile) { display: none !important; } }
@media only screen and (min-width: 1920px) { .ui.grid.grid.grid > .row > [class*="mobile only"].column:not(.computer), .ui.grid.grid.grid > [class*="mobile only"].column:not(.computer), .ui.grid.grid.grid > [class*="mobile only"].row:not(.computer), .ui[class*="mobile only"].grid.grid.grid:not(.computer) { display: none !important; }
  .ui.grid.grid.grid > .row > [class*="tablet only"].column:not(.computer), .ui.grid.grid.grid > [class*="tablet only"].column:not(.computer), .ui.grid.grid.grid > [class*="tablet only"].row:not(.computer), .ui[class*="tablet only"].grid.grid.grid:not(.computer) { display: none !important; } }
.ui.header { border: none; margin: calc(2rem - .14285714em) 0 1rem; padding: 0 0; font-family: Raleway,sans-serif; font-weight: 700; line-height: 1.28571429em; text-transform: none; color: rgba(0, 0, 0, 0.87); }
.ui.header:first-child { margin-top: -.14285714em; }
.ui.header:last-child { margin-bottom: 0; }
.ui.header .sub.header { display: block; font-weight: 400; padding: 0; margin: 0; font-size: 1rem; line-height: 1.2em; color: rgba(0, 0, 0, 0.6); }
.ui.header > .icon { display: table-cell; opacity: 1; font-size: 1.5em; padding-top: 0; vertical-align: middle; }
.ui.header .icon:only-child { display: inline-block; padding: 0; margin-right: .75rem; }
.ui.header > .image:not(.icon), .ui.header > img { display: inline-block; margin-top: .14285714em; width: 2.5em; height: auto; vertical-align: middle; }
.ui.header > .image:not(.icon):only-child, .ui.header > img:only-child { margin-right: .75rem; }
.ui.header .content { display: inline-block; vertical-align: top; }
.ui.header > .image + .content, .ui.header > img + .content { padding-left: .75rem; vertical-align: middle; }
.ui.header > .icon + .content { padding-left: .75rem; display: table-cell; vertical-align: middle; }
.ui.header .ui.label { font-size: ''; margin-left: .5rem; vertical-align: middle; }
.ui.header + p { margin-top: 0; }
h1.ui.header { font-size: 2rem; }
h2.ui.header { font-size: 1.71428571rem; }
h3.ui.header { font-size: 1.28571429rem; }
h4.ui.header { font-size: 1.07142857rem; }
h5.ui.header { font-size: 1rem; }
h1.ui.header .sub.header { font-size: 1.125rem; }
h2.ui.header .sub.header { font-size: 1.125rem; }
h3.ui.header .sub.header { font-size: 1rem; }
h4.ui.header .sub.header { font-size: 1rem; }
h5.ui.header .sub.header { font-size: .875rem; }
.ui.huge.header { min-height: 1em; font-size: 2em; }
.ui.large.header { font-size: 1.71428571em; }
.ui.medium.header { font-size: 1.28571429em; }
.ui.small.header { font-size: 1.07142857em; }
.ui.tiny.header { font-size: 1em; }
.ui.huge.header .sub.header { font-size: 1.125rem; }
.ui.large.header .sub.header { font-size: 1.125rem; }
.ui.header .sub.header { font-size: 1rem; }
.ui.small.header .sub.header { font-size: 1rem; }
.ui.tiny.header .sub.header { font-size: .875rem; }
.ui.sub.header { padding: 0; margin-bottom: .125rem; font-weight: 700; font-size: .75em; text-transform: uppercase; color: ''; }
.ui.small.sub.header { font-size: .625em; }
.ui.sub.header { font-size: .75em; }
.ui.large.sub.header { font-size: .875em; }
.ui.huge.sub.header { font-size: 1em; }
.ui.icon.header { display: inline-block; text-align: center; margin: 2rem 0 1rem; }
.ui.icon.header:after { content: ''; display: block; height: 0; clear: both; visibility: hidden; }
.ui.icon.header:first-child { margin-top: 0; }
.ui.icon.header .icon { float: none; display: block; width: auto; height: auto; line-height: 1; padding: 0; font-size: 3em; margin: 0 auto .5rem; opacity: 1; }
.ui.icon.header .content { display: block; padding: 0; }
.ui.icon.header .circular.icon { font-size: 2em; }
.ui.icon.header .square.icon { font-size: 2em; }
.ui.block.icon.header .icon { margin-bottom: 0; }
.ui.icon.header.aligned { margin-left: auto; margin-right: auto; display: block; }
.ui.disabled.header { opacity: .45; }
.ui.inverted.header { color: #fff; }
.ui.inverted.header .sub.header { color: rgba(255, 255, 255, 0.8); }
.ui.inverted.attached.header { background: #545454 -webkit-gradient(linear, left top, left bottom, from(transparent), to(rgba(0, 0, 0, 0.05))); background: #545454 -webkit-linear-gradient(transparent, rgba(0, 0, 0, 0.05)); background: #545454 linear-gradient(transparent, rgba(0, 0, 0, 0.05)); -webkit-box-shadow: none; box-shadow: none; border-color: transparent; }
.ui.inverted.block.header { background: #545454 -webkit-gradient(linear, left top, left bottom, from(transparent), to(rgba(0, 0, 0, 0.05))); background: #545454 -webkit-linear-gradient(transparent, rgba(0, 0, 0, 0.05)); background: #545454 linear-gradient(transparent, rgba(0, 0, 0, 0.05)); -webkit-box-shadow: none; box-shadow: none; }
.ui.inverted.block.header { border-bottom: none; }
.ui.red.header { color: #db2828 !important; }
a.ui.red.header:hover { color: #d01919 !important; }
.ui.red.dividing.header { border-bottom: 2px solid #db2828; }
.ui.inverted.red.header { color: #ff695e !important; }
a.ui.inverted.red.header:hover { color: #ff5144 !important; }
.ui.orange.header { color: #f2711c !important; }
a.ui.orange.header:hover { color: #f26202 !important; }
.ui.orange.dividing.header { border-bottom: 2px solid #f2711c; }
.ui.inverted.orange.header { color: #ff851b !important; }
a.ui.inverted.orange.header:hover { color: #ff7701 !important; }
.ui.olive.header { color: #b5cc18 !important; }
a.ui.olive.header:hover { color: #a7bd0d !important; }
.ui.olive.dividing.header { border-bottom: 2px solid #b5cc18; }
.ui.inverted.olive.header { color: #d9e778 !important; }
a.ui.inverted.olive.header:hover { color: #d8ea5c !important; }
.ui.yellow.header { color: #fbbd08 !important; }
a.ui.yellow.header:hover { color: #eaae00 !important; }
.ui.yellow.dividing.header { border-bottom: 2px solid #fbbd08; }
.ui.inverted.yellow.header { color: #ffe21f !important; }
a.ui.inverted.yellow.header:hover { color: #ffdf05 !important; }
.ui.green.header { color: #21ba45 !important; }
a.ui.green.header:hover { color: #16ab39 !important; }
.ui.green.dividing.header { border-bottom: 2px solid #21ba45; }
.ui.inverted.green.header { color: #2ecc40 !important; }
a.ui.inverted.green.header:hover { color: #22be34 !important; }
.ui.teal.header { color: #00b5ad !important; }
a.ui.teal.header:hover { color: #009c95 !important; }
.ui.teal.dividing.header { border-bottom: 2px solid #00b5ad; }
.ui.inverted.teal.header { color: #6dffff !important; }
a.ui.inverted.teal.header:hover { color: #54ffff !important; }
.ui.blue.header { color: #2185d0 !important; }
a.ui.blue.header:hover { color: #1678c2 !important; }
.ui.blue.dividing.header { border-bottom: 2px solid #2185d0; }
.ui.inverted.blue.header { color: #54c8ff !important; }
a.ui.inverted.blue.header:hover { color: #3ac0ff !important; }
.ui.violet.header { color: #6435c9 !important; }
a.ui.violet.header:hover { color: #5829bb !important; }
.ui.violet.dividing.header { border-bottom: 2px solid #6435c9; }
.ui.inverted.violet.header { color: #a291fb !important; }
a.ui.inverted.violet.header:hover { color: #8a73ff !important; }
.ui.purple.header { color: #a333c8 !important; }
a.ui.purple.header:hover { color: #9627ba !important; }
.ui.purple.dividing.header { border-bottom: 2px solid #a333c8; }
.ui.inverted.purple.header { color: #dc73ff !important; }
a.ui.inverted.purple.header:hover { color: #d65aff !important; }
.ui.pink.header { color: #e03997 !important; }
a.ui.pink.header:hover { color: #e61a8d !important; }
.ui.pink.dividing.header { border-bottom: 2px solid #e03997; }
.ui.inverted.pink.header { color: #ff8edf !important; }
a.ui.inverted.pink.header:hover { color: #ff74d8 !important; }
.ui.brown.header { color: #a5673f !important; }
a.ui.brown.header:hover { color: #975b33 !important; }
.ui.brown.dividing.header { border-bottom: 2px solid #a5673f; }
.ui.inverted.brown.header { color: #d67c1c !important; }
a.ui.inverted.brown.header:hover { color: #c86f11 !important; }
.ui.grey.header { color: #767676 !important; }
a.ui.grey.header:hover { color: #838383 !important; }
.ui.grey.dividing.header { border-bottom: 2px solid #767676; }
.ui.inverted.grey.header { color: #dcddde !important; }
a.ui.inverted.grey.header:hover { color: #cfd0d2 !important; }
.ui.left.aligned.header { text-align: left; }
.ui.right.aligned.header { text-align: right; }
.ui.center.aligned.header, .ui.centered.header { text-align: center; }
.ui.justified.header { text-align: justify; }
.ui.justified.header:after { display: inline-block; content: ''; width: 100%; }
.ui.floated.header, .ui[class*="left floated"].header { float: left; margin-top: 0; margin-right: .5em; }
.ui[class*="right floated"].header { float: right; margin-top: 0; margin-left: .5em; }
.ui.fitted.header { padding: 0; }
.ui.dividing.header { padding-bottom: .1875rem; border-bottom: 1px solid rgba(34, 36, 38, 0.15); }
.ui.dividing.header .sub.header { padding-bottom: .1875rem; }
.ui.dividing.header .icon { margin-bottom: 0; }
.ui.inverted.dividing.header { border-bottom-color: rgba(255, 255, 255, 0.1); }
.ui.block.header { background: #f3f4f5; padding: .625rem 1rem; -webkit-box-shadow: none; box-shadow: none; border: 1px solid #d4d4d5; border-radius: .25rem; }
.ui.tiny.block.header { font-size: .75rem; }
.ui.small.block.header { font-size: .875rem; }
.ui.block.header:not(h1):not(h2):not(h3):not(h4):not(h5):not(h6) { font-size: 1rem; }
.ui.large.block.header { font-size: 1.125rem; }
.ui.huge.block.header { font-size: 1.5rem; }
.ui.attached.header { background: #fff; padding: .625rem 1rem; margin-left: -1px; margin-right: -1px; -webkit-box-shadow: none; box-shadow: none; border: 1px solid #d4d4d5; }
.ui.attached.block.header { background: #f3f4f5; }
.ui.attached:not(.top):not(.bottom).header { margin-top: 0; margin-bottom: 0; border-top: none; border-radius: 0; }
.ui.top.attached.header { margin-bottom: 0; border-radius: .25rem .25rem 0 0; }
.ui.bottom.attached.header { margin-top: 0; border-top: none; border-radius: 0 0 .25rem .25rem; }
.ui.tiny.attached.header { font-size: .75em; }
.ui.small.attached.header { font-size: .875em; }
.ui.attached.header:not(h1):not(h2):not(h3):not(h4):not(h5):not(h6) { font-size: 1em; }
.ui.large.attached.header { font-size: 1.125em; }
.ui.huge.attached.header { font-size: 1.5em; }
.ui.header:not(h1):not(h2):not(h3):not(h4):not(h5):not(h6) { font-size: 1.28571429em; }
.ui.image { position: relative; display: inline-block; vertical-align: middle; max-width: 100%; background-color: transparent; }
img.ui.image { display: block; }
.ui.image img, .ui.image svg { display: block; max-width: 100%; height: auto; }
.ui.hidden.image, .ui.hidden.images { display: none; }
.ui.hidden.transition.image, .ui.hidden.transition.images { display: block; visibility: hidden; }
.ui.images > .hidden.transition { display: inline-block; visibility: hidden; }
.ui.disabled.image, .ui.disabled.images { cursor: default; opacity: .45; }
.ui.inline.image, .ui.inline.image img, .ui.inline.image svg { display: inline-block; }
.ui.top.aligned.image, .ui.top.aligned.image img, .ui.top.aligned.image svg, .ui.top.aligned.images .image { display: inline-block; vertical-align: top; }
.ui.middle.aligned.image, .ui.middle.aligned.image img, .ui.middle.aligned.image svg, .ui.middle.aligned.images .image { display: inline-block; vertical-align: middle; }
.ui.bottom.aligned.image, .ui.bottom.aligned.image img, .ui.bottom.aligned.image svg, .ui.bottom.aligned.images .image { display: inline-block; vertical-align: bottom; }
.ui.rounded.image, .ui.rounded.image > *, .ui.rounded.images .image, .ui.rounded.images .image > * { border-radius: .3125em; }
.ui.bordered.image img, .ui.bordered.image svg, .ui.bordered.images .image, .ui.bordered.images img, .ui.bordered.images svg, img.ui.bordered.image { border: 1px solid rgba(0, 0, 0, 0.1); }
.ui.circular.image, .ui.circular.images { overflow: hidden; }
.ui.circular.image, .ui.circular.image > *, .ui.circular.images .image, .ui.circular.images .image > * { border-radius: 500rem; }
.ui.fluid.image, .ui.fluid.image img, .ui.fluid.image svg, .ui.fluid.images, .ui.fluid.images img, .ui.fluid.images svg { display: block; width: 100%; height: auto; }
.ui.avatar.image, .ui.avatar.image img, .ui.avatar.image svg, .ui.avatar.images .image, .ui.avatar.images img, .ui.avatar.images svg { margin-right: .25em; display: inline-block; width: 2em; height: 2em; border-radius: 500rem; }
.ui.spaced.image { display: inline-block !important; margin-left: .5em; margin-right: .5em; }
.ui[class*="left spaced"].image { margin-left: .5em; margin-right: 0; }
.ui[class*="right spaced"].image { margin-left: 0; margin-right: .5em; }
.ui.floated.image, .ui.floated.images { float: left; margin-right: 1em; margin-bottom: 1em; }
.ui.right.floated.image, .ui.right.floated.images { float: right; margin-right: 0; margin-bottom: 1em; margin-left: 1em; }
.ui.floated.image:last-child, .ui.floated.images:last-child { margin-bottom: 0; }
.ui.centered.image, .ui.centered.images { margin-left: auto; margin-right: auto; }
.ui.mini.image, .ui.mini.images .image, .ui.mini.images img, .ui.mini.images svg { width: 35px; height: auto; font-size: .625rem; }
.ui.tiny.image, .ui.tiny.images .image, .ui.tiny.images img, .ui.tiny.images svg { width: 80px; height: auto; font-size: .75rem; }
.ui.small.image, .ui.small.images .image, .ui.small.images img, .ui.small.images svg { width: 150px; height: auto; font-size: .875rem; }
.ui.medium.image, .ui.medium.images .image, .ui.medium.images img, .ui.medium.images svg { width: 300px; height: auto; font-size: 1rem; }
.ui.large.image, .ui.large.images .image, .ui.large.images img, .ui.large.images svg { width: 450px; height: auto; font-size: 1.125rem; }
.ui.big.image, .ui.big.images .image, .ui.big.images img, .ui.big.images svg { width: 600px; height: auto; font-size: 1.25rem; }
.ui.huge.image, .ui.huge.images .image, .ui.huge.images img, .ui.huge.images svg { width: 800px; height: auto; font-size: 1.5rem; }
.ui.massive.image, .ui.massive.images .image, .ui.massive.images img, .ui.massive.images svg { width: 960px; height: auto; font-size: 2rem; }
.ui.images { font-size: 0; margin: 0 -.25rem 0; }
.ui.images .image, .ui.images > img, .ui.images > svg { display: inline-block; margin: 0 .25rem .5rem; }
.ui.input { position: relative; font-weight: 400; font-style: normal; display: -webkit-inline-box; display: -ms-inline-flexbox; display: inline-flex; color: rgba(0, 0, 0, 0.87); }
.ui.input > input { margin: 0; max-width: 100%; -webkit-box-flex: 1; -ms-flex: 1 0 auto; flex: 1 0 auto; outline: 0; -webkit-tap-highlight-color: rgba(255, 255, 255, 0); text-align: left; line-height: 1.21428571em; font-family: Montserrat,sans-serif; padding: .58035714em .875em; background: #fff; border: 1px solid rgba(34, 36, 38, 0.15); color: rgba(0, 0, 0, 0.87); border-radius: .25rem; -webkit-transition: border-color .1s ease,-webkit-box-shadow .1s ease; transition: border-color .1s ease,-webkit-box-shadow .1s ease; transition: box-shadow .1s ease,border-color .1s ease; transition: box-shadow .1s ease,border-color .1s ease,-webkit-box-shadow .1s ease; -webkit-box-shadow: none; box-shadow: none; }
.ui.input > input::-webkit-input-placeholder { color: rgba(191, 191, 191, 0.87); }
.ui.input > input::-moz-placeholder { color: rgba(191, 191, 191, 0.87); }
.ui.input > input:-ms-input-placeholder { color: rgba(191, 191, 191, 0.87); }
.ui.disabled.input, .ui.input:not(.disabled) input[disabled] { opacity: .45; }
.ui.disabled.input > input, .ui.input:not(.disabled) input[disabled] { pointer-events: none; }
.ui.input.down input, .ui.input > input:active { border-color: rgba(0, 0, 0, 0.3); background: #fafafa; color: rgba(0, 0, 0, 0.87); -webkit-box-shadow: none; box-shadow: none; }
.ui.loading.loading.input > i.icon:before { position: absolute; content: ''; top: 50%; left: 50%; margin: -.625em 0 0 -.625em; width: 1.25em; height: 1.25em; border-radius: 500rem; border: 0.2em solid rgba(0, 0, 0, 0.1); }
.ui.loading.loading.input > i.icon:after { position: absolute; content: ''; top: 50%; left: 50%; margin: -.625em 0 0 -.625em; width: 1.25em; height: 1.25em; -webkit-animation: button-spin .6s linear; animation: button-spin .6s linear; -webkit-animation-iteration-count: infinite; animation-iteration-count: infinite; border-radius: 500rem; border-color: #767676 transparent transparent; border-style: solid; border-width: .2em; -webkit-box-shadow: 0 0 0 1px transparent; box-shadow: 0 0 0 1px transparent; }
.ui.input.focus > input, .ui.input > input:focus { border-color: #85b7d9; background: #fff; color: rgba(0, 0, 0, 0.8); -webkit-box-shadow: none; box-shadow: none; }
.ui.input.focus > input::-webkit-input-placeholder, .ui.input > input:focus::-webkit-input-placeholder { color: rgba(115, 115, 115, 0.87); }
.ui.input.focus > input::-moz-placeholder, .ui.input > input:focus::-moz-placeholder { color: rgba(115, 115, 115, 0.87); }
.ui.input.focus > input:-ms-input-placeholder, .ui.input > input:focus:-ms-input-placeholder { color: rgba(115, 115, 115, 0.87); }
.ui.input.error > input { background-color: #fff6f6; border-color: #e0b4b4; color: #9f3a38; -webkit-box-shadow: none; box-shadow: none; }
.ui.input.error > input::-webkit-input-placeholder { color: #e7bdbc; }
.ui.input.error > input::-moz-placeholder { color: #e7bdbc; }
.ui.input.error > input:-ms-input-placeholder { color: #e7bdbc !important; }
.ui.input.error > input:focus::-webkit-input-placeholder { color: #da9796; }
.ui.input.error > input:focus::-moz-placeholder { color: #da9796; }
.ui.input.error > input:focus:-ms-input-placeholder { color: #da9796 !important; }
.ui.transparent.input > input { border-color: transparent !important; background-color: transparent !important; padding: 0 !important; -webkit-box-shadow: none !important; box-shadow: none !important; border-radius: 0 !important; }
.ui.transparent.icon.input > i.icon { width: 1.1em; }
.ui.transparent.icon.input > input { padding-left: 0 !important; padding-right: 2em !important; }
.ui.transparent[class*="left icon"].input > input { padding-left: 2em !important; padding-right: 0 !important; }
.ui.transparent.inverted.input { color: #fff; }
.ui.transparent.inverted.input > input { color: inherit; }
.ui.transparent.inverted.input > input::-webkit-input-placeholder { color: black; }
.ui.transparent.inverted.input > input::-moz-placeholder { color: black; }
.ui.transparent.inverted.input > input:-ms-input-placeholder { color: black; }
.ui.icon.input > i.icon { cursor: default; position: absolute; line-height: 1; text-align: center; top: 0; right: 0; margin: 0; height: 100%; width: 2.475em; opacity: .5; border-radius: 0 .25rem .25rem 0; -webkit-transition: opacity .3s ease; transition: opacity .3s ease; }
.ui.icon.input > i.icon:not(.link) { pointer-events: none; }
.ui.icon.input > input { padding-right: 2.475em !important; }
.ui.icon.input > i.icon:after, .ui.icon.input > i.icon:before { left: 0; position: absolute; text-align: center; top: 50%; width: 100%; margin-top: -.5em; }
.ui.icon.input > i.link.icon { cursor: pointer; }
.ui.icon.input > i.circular.icon { top: .35em; right: .5em; }
.ui[class*="left icon"].input > i.icon { right: auto; left: 1px; border-radius: .25rem 0 0 .25rem; }
.ui[class*="left icon"].input > i.circular.icon { right: auto; left: .5em; }
.ui[class*="left icon"].input > input { padding-left: 2.475em !important; padding-right: 0.875em !important; }
.ui.icon.input > input:focus ~ i.icon { opacity: 1; }
.ui.labeled.input > .label { -webkit-box-flex: 0; -ms-flex: 0 0 auto; flex: 0 0 auto; margin: 0; font-size: 1em; }
.ui.labeled.input > .label:not(.corner) { padding-top: .6875em; padding-bottom: .6875em; }
.ui.labeled.input:not([class*="corner labeled"]) .label:first-child { border-top-right-radius: 0; border-bottom-right-radius: 0; }
.ui.labeled.input:not([class*="corner labeled"]) .label:first-child + input { border-top-left-radius: 0; border-bottom-left-radius: 0; border-left-color: transparent; }
.ui.labeled.input:not([class*="corner labeled"]) .label:first-child + input:focus { border-left-color: #85b7d9; }
.ui[class*="right labeled"].input > input { border-top-right-radius: 0 !important; border-bottom-right-radius: 0 !important; border-right-color: transparent !important; }
.ui[class*="right labeled"].input > input + .label { border-top-left-radius: 0; border-bottom-left-radius: 0; }
.ui[class*="right labeled"].input > input:focus { border-right-color: #85b7d9 !important; }
.ui.labeled.input .corner.label { top: 1px; right: 1px; font-size: .5625em; border-radius: 0 .25rem 0 0; }
.ui[class*="corner labeled"]:not([class*="left corner labeled"]).labeled.input > input { padding-right: 2.5em !important; }
.ui[class*="corner labeled"].icon.input:not([class*="left corner labeled"]) > input { padding-right: 3.25em !important; }
.ui[class*="corner labeled"].icon.input:not([class*="left corner labeled"]) > .icon { margin-right: 1.25em; }
.ui[class*="left corner labeled"].labeled.input > input { padding-left: 2.5em !important; }
.ui[class*="left corner labeled"].icon.input > input { padding-left: 3.25em !important; }
.ui[class*="left corner labeled"].icon.input > .icon { margin-left: 1.25em; }
.ui.input > .ui.corner.label { top: 1px; right: 1px; }
.ui.input > .ui.left.corner.label { right: auto; left: 1px; }
.ui.action.input > .button, .ui.action.input > .buttons { display: -webkit-box; display: -ms-flexbox; display: flex; -webkit-box-align: center; -ms-flex-align: center; align-items: center; -webkit-box-flex: 0; -ms-flex: 0 0 auto; flex: 0 0 auto; }
.ui.action.input > .button, .ui.action.input > .buttons > .button { padding-top: .6875em; padding-bottom: .6875em; margin: 0; }
.ui.action.input:not([class*="left action"]) > input { border-top-right-radius: 0 !important; border-bottom-right-radius: 0 !important; border-right-color: transparent !important; }
.ui.action.input:not([class*="left action"]) > .button:not(:first-child), .ui.action.input:not([class*="left action"]) > .buttons:not(:first-child) > .button, .ui.action.input:not([class*="left action"]) > .dropdown:not(:first-child) { border-radius: 0; }
.ui.action.input:not([class*="left action"]) > .button:last-child, .ui.action.input:not([class*="left action"]) > .buttons:last-child > .button, .ui.action.input:not([class*="left action"]) > .dropdown:last-child { border-radius: 0 .25rem .25rem 0; }
.ui.action.input:not([class*="left action"]) > input:focus { border-right-color: #85b7d9 !important; }
.ui[class*="left action"].input > input { border-top-left-radius: 0 !important; border-bottom-left-radius: 0 !important; border-left-color: transparent !important; }
.ui[class*="left action"].input > .button, .ui[class*="left action"].input > .buttons > .button, .ui[class*="left action"].input > .dropdown { border-radius: 0; }
.ui[class*="left action"].input > .button:first-child, .ui[class*="left action"].input > .buttons:first-child > .button, .ui[class*="left action"].input > .dropdown:first-child { border-radius: .25rem 0 0 .25rem; }
.ui[class*="left action"].input > input:focus { border-left-color: #85b7d9 !important; }
.ui.inverted.input > input { border: none; }
.ui.fluid.input { display: -webkit-box; display: -ms-flexbox; display: flex; }
.ui.fluid.input > input { width: 0 !important; }
.ui.mini.input { font-size: .625em; }
.ui.small.input { font-size: .875em; }
.ui.input { font-size: 1em; }
.ui.large.input { font-size: 1.125em; }
.ui.big.input { font-size: 1.25em; }
.ui.huge.input { font-size: 1.5em; }
.ui.massive.input { font-size: 2em; }
.ui.items > .item { display: -webkit-box; display: -ms-flexbox; display: flex; margin: 1em 0; width: 100%; min-height: 0; background: 0 0; padding: 0; border: none; border-radius: 0; -webkit-box-shadow: none; box-shadow: none; -webkit-transition: -webkit-box-shadow .1s ease; transition: -webkit-box-shadow .1s ease; transition: box-shadow .1s ease; transition: box-shadow .1s ease,-webkit-box-shadow .1s ease; z-index: ''; }
.ui.items > .item a { cursor: pointer; }
.ui.items { margin: 1.5em 0; }
.ui.items:first-child { margin-top: 0 !important; }
.ui.items:last-child { margin-bottom: 0 !important; }
.ui.items > .item:after { display: block; content: ' '; height: 0; clear: both; overflow: hidden; visibility: hidden; }
.ui.items > .item:first-child { margin-top: 0; }
.ui.items > .item:last-child { margin-bottom: 0; }
.ui.items > .item > .image { position: relative; -webkit-box-flex: 0; -ms-flex: 0 0 auto; flex: 0 0 auto; display: block; float: none; margin: 0; padding: 0; max-height: ''; -ms-flex-item-align: top; align-self: top; }
.ui.items > .item > .image > img { display: block; width: 100%; height: auto; border-radius: .125rem; border: none; }
.ui.items > .item > .image:only-child > img { border-radius: 0; }
.ui.items > .item > .content { display: block; -webkit-box-flex: 1; -ms-flex: 1 1 auto; flex: 1 1 auto; background: 0 0; margin: 0; padding: 0; -webkit-box-shadow: none; box-shadow: none; font-size: 1em; border: none; border-radius: 0; }
.ui.items > .item > .content:after { display: block; content: ' '; height: 0; clear: both; overflow: hidden; visibility: hidden; }
.ui.items > .item > .image + .content { min-width: 0; width: auto; display: block; margin-left: 0; -ms-flex-item-align: top; align-self: top; padding-left: 1.5em; }
.ui.items > .item > .content > .header { display: inline-block; margin: -.21425em 0 0; font-family: Raleway,sans-serif; font-weight: 700; color: rgba(0, 0, 0, 0.85); }
.ui.items > .item > .content > .header:not(.ui) { font-size: 1.25em; }
.ui.items > .item [class*="left floated"] { float: left; }
.ui.items > .item [class*="right floated"] { float: right; }
.ui.items > .item .content img { -ms-flex-item-align: middle; align-self: middle; width: ''; }
.ui.items > .item .avatar img, .ui.items > .item img.avatar { width: ''; height: ''; border-radius: 500rem; }
.ui.items > .item > .content > .description { margin-top: .6em; max-width: auto; font-size: 1em; line-height: 1.4285em; color: rgba(0, 0, 0, 0.87); }
.ui.items > .item > .content p { margin: 0 0 .5em; }
.ui.items > .item > .content p:last-child { margin-bottom: 0; }
.ui.items > .item .meta { margin: .5em 0 .5em; font-size: 1em; line-height: 1em; color: rgba(0, 0, 0, 0.6); }
.ui.items > .item .meta * { margin-right: .3em; }
.ui.items > .item .meta :last-child { margin-right: 0; }
.ui.items > .item .meta [class*="right floated"] { margin-right: 0; margin-left: .3em; }
.ui.items > .item > .content a:not(.ui) { color: ''; -webkit-transition: color .1s ease; transition: color .1s ease; }
.ui.items > .item > .content a:not(.ui):hover { color: ''; }
.ui.items > .item > .content > a.header { color: rgba(0, 0, 0, 0.85); }
.ui.items > .item > .content > a.header:hover { color: #1c63b4; }
.ui.items > .item .meta > a:not(.ui) { color: rgba(0, 0, 0, 0.4); }
.ui.items > .item .meta > a:not(.ui):hover { color: rgba(0, 0, 0, 0.87); }
.ui.items > .item > .content .favorite.icon { cursor: pointer; opacity: .75; -webkit-transition: color .1s ease; transition: color .1s ease; }
.ui.items > .item > .content .favorite.icon:hover { opacity: 1; color: #ffb70a; }
.ui.items > .item > .content .active.favorite.icon { color: #ffe623; }
.ui.items > .item > .content .like.icon { cursor: pointer; opacity: .75; -webkit-transition: color .1s ease; transition: color .1s ease; }
.ui.items > .item > .content .like.icon:hover { opacity: 1; color: #ff2733; }
.ui.items > .item > .content .active.like.icon { color: #ff2733; }
.ui.items > .item .extra { display: block; position: relative; background: 0 0; margin: .5rem 0 0; width: 100%; padding: 0 0 0; top: 0; left: 0; color: rgba(0, 0, 0, 0.4); -webkit-box-shadow: none; box-shadow: none; -webkit-transition: color .1s ease; transition: color .1s ease; border-top: none; }
.ui.items > .item .extra > * { margin: .25rem .5rem .25rem 0; }
.ui.items > .item .extra > [class*="right floated"] { margin: .25rem 0 .25rem .5rem; }
.ui.items > .item .extra:after { display: block; content: ' '; height: 0; clear: both; overflow: hidden; visibility: hidden; }
.ui.items > .item > .image:not(.ui) { width: 175px; }
@media only screen and (min-width: 768px) and (max-width: 991px) { .ui.items > .item { margin: 1em 0; }
  .ui.items > .item > .image:not(.ui) { width: 150px; }
  .ui.items > .item > .image + .content { display: block; padding: 0 0 0 1em; } }
@media only screen and (max-width: 767px) { .ui.items:not(.unstackable) > .item { -webkit-box-orient: vertical; -webkit-box-direction: normal; -ms-flex-direction: column; flex-direction: column; margin: 2em 0; }
  .ui.items:not(.unstackable) > .item > .image { display: block; margin-left: auto; margin-right: auto; }
  .ui.items:not(.unstackable) > .item > .image, .ui.items:not(.unstackable) > .item > .image > img { max-width: 100% !important; width: auto !important; max-height: 250px !important; }
  .ui.items:not(.unstackable) > .item > .image + .content { display: block; padding: 1.5em 0 0; } }
.ui.items > .item > .image + [class*="top aligned"].content { -ms-flex-item-align: start; align-self: flex-start; }
.ui.items > .item > .image + [class*="middle aligned"].content { -ms-flex-item-align: center; align-self: center; }
.ui.items > .item > .image + [class*="bottom aligned"].content { -ms-flex-item-align: end; align-self: flex-end; }
.ui.relaxed.items > .item { margin: 1.5em 0; }
.ui[class*="very relaxed"].items > .item { margin: 2em 0; }
.ui.divided.items > .item { border-top: 1px solid rgba(34, 36, 38, 0.15); margin: 0; padding: 1em 0; }
.ui.divided.items > .item:first-child { border-top: none; margin-top: 0 !important; padding-top: 0 !important; }
.ui.divided.items > .item:last-child { margin-bottom: 0 !important; padding-bottom: 0 !important; }
.ui.relaxed.divided.items > .item { margin: 0; padding: 1.5em 0; }
.ui[class*="very relaxed"].divided.items > .item { margin: 0; padding: 2em 0; }
.ui.items a.item:hover, .ui.link.items > .item:hover { cursor: pointer; }
.ui.items a.item:hover .content .header, .ui.link.items > .item:hover .content .header { color: #1c63b4; }
.ui.items > .item { font-size: 1em; }
@media only screen and (max-width: 767px) { .ui.unstackable.items > .item > .image, .ui.unstackable.items > .item > .image > img { width: 125px !important; } }
.ui.label { display: inline-block; line-height: 1; vertical-align: baseline; margin: 0 .125em; background-color: #e8e8e8; background-image: none; padding: .5833em .833em; color: rgba(0, 0, 0, 0.6); text-transform: none; font-weight: 700; border: 0 solid transparent; border-radius: .25rem; -webkit-transition: background .1s ease; transition: background .1s ease; }
.ui.label:first-child { margin-left: 0; }
.ui.label:last-child { margin-right: 0; }
a.ui.label { cursor: pointer; }
.ui.label > a { cursor: pointer; color: inherit; opacity: .5; -webkit-transition: .1s opacity ease; transition: .1s opacity ease; }
.ui.label > a:hover { opacity: 1; }
.ui.label > img { width: auto !important; vertical-align: middle; height: 2.1666em !important; }
.ui.label > .icon { width: auto; margin: 0 .75em 0 0; }
.ui.label > .detail { display: inline-block; vertical-align: top; font-weight: 700; margin-left: 1em; opacity: .8; }
.ui.label > .detail .icon { margin: 0 .25em 0 0; }
.ui.label > .close.icon, .ui.label > .delete.icon { cursor: pointer; margin-right: 0; margin-left: .5em; font-size: .875em; opacity: .5; -webkit-transition: background .1s ease; transition: background .1s ease; }
.ui.label > .delete.icon:hover { opacity: 1; }
.ui.labels > .label { margin: 0 .5em .5em 0; }
.ui.header > .ui.label { margin-top: -.29165em; }
.ui.attached.segment > .ui.top.left.attached.label, .ui.bottom.attached.segment > .ui.top.left.attached.label { border-top-left-radius: 0; }
.ui.attached.segment > .ui.top.right.attached.label, .ui.bottom.attached.segment > .ui.top.right.attached.label { border-top-right-radius: 0; }
.ui.top.attached.segment > .ui.bottom.left.attached.label { border-bottom-left-radius: 0; }
.ui.top.attached.segment > .ui.bottom.right.attached.label { border-bottom-right-radius: 0; }
.ui.top.attached.label + [class*="right floated"] + *, .ui.top.attached.label:first-child + :not(.attached) { margin-top: 2rem !important; }
.ui.bottom.attached.label:first-child ~ :last-child:not(.attached) { margin-top: 0; margin-bottom: 2rem !important; }
.ui.image.label { width: auto !important; margin-top: 0; margin-bottom: 0; max-width: 9999px; vertical-align: baseline; text-transform: none; background: #e8e8e8; padding: .5833em .833em .5833em .5em; border-radius: .25rem; -webkit-box-shadow: none; box-shadow: none; }
.ui.image.label img { display: inline-block; vertical-align: top; height: 2.1666em; margin: -.5833em .5em -.5833em -.5em; border-radius: .25rem 0 0 .25rem; }
.ui.image.label .detail { background: rgba(0, 0, 0, 0.1); margin: -.5833em -.833em -.5833em .5em; padding: .5833em .833em; border-radius: 0 .25rem .25rem 0; }
.ui.tag.label, .ui.tag.labels .label { margin-left: 1em; position: relative; padding-left: 1.5em; padding-right: 1.5em; border-radius: 0 .25rem .25rem 0; -webkit-transition: none; transition: none; }
.ui.tag.label:before, .ui.tag.labels .label:before { position: absolute; -webkit-transform: translateY(-50%) translateX(50%) rotate(-45deg); transform: translateY(-50%) translateX(50%) rotate(-45deg); top: 50%; right: 100%; content: ''; background-color: inherit; background-image: none; width: 1.56em; height: 1.56em; -webkit-transition: none; transition: none; }
.ui.tag.label:after, .ui.tag.labels .label:after { position: absolute; content: ''; top: 50%; left: -.25em; margin-top: -.25em; background-color: #fff !important; width: .5em; height: .5em; -webkit-box-shadow: 0 -1px 1px 0 rgba(0, 0, 0, 0.3); box-shadow: 0 -1px 1px 0 rgba(0, 0, 0, 0.3); border-radius: 500rem; }
.ui.corner.label { position: absolute; top: 0; right: 0; margin: 0; padding: 0; text-align: center; border-color: #e8e8e8; width: 4em; height: 4em; z-index: 1; -webkit-transition: border-color .1s ease; transition: border-color .1s ease; }
.ui.corner.label { background-color: transparent !important; }
.ui.corner.label:after { position: absolute; content: ""; right: 0; top: 0; z-index: -1; width: 0; height: 0; background-color: transparent !important; border-top: 0 solid transparent; border-right: 4em solid transparent; border-bottom: 4em solid transparent; border-left: 0 solid transparent; border-right-color: inherit; -webkit-transition: border-color .1s ease; transition: border-color .1s ease; }
.ui.corner.label .icon { cursor: default; position: relative; top: .5625em; left: .6875em; font-size: 1.125em; margin: 0; }
.ui.left.corner.label, .ui.left.corner.label:after { right: auto; left: 0; }
.ui.left.corner.label:after { border-top: 4em solid transparent; border-right: 4em solid transparent; border-bottom: 0 solid transparent; border-left: 0 solid transparent; border-top-color: inherit; }
.ui.left.corner.label .icon { left: -.6875em; }
.ui.segment > .ui.corner.label { top: -1px; right: -1px; }
.ui.segment > .ui.left.corner.label { right: auto; left: -1px; }
.ui.ribbon.label { position: relative; margin: 0; min-width: -webkit-max-content; min-width: -moz-max-content; min-width: max-content; border-radius: 0 .25rem .25rem 0; border-color: rgba(0, 0, 0, 0.15); }
.ui.ribbon.label:after { position: absolute; content: ''; top: 100%; left: 0; background-color: transparent !important; border-style: solid; border-width: 0 1.2em 1.2em 0; border-color: transparent; border-right-color: inherit; width: 0; height: 0; }
.ui.ribbon.label { left: calc(-1rem - 1.2em); margin-right: -1.2em; padding-left: calc(1rem + 1.2em); padding-right: 1.2em; }
.ui[class*="right ribbon"].label { left: calc(100% + 1rem + 1.2em); padding-left: 1.2em; padding-right: calc(1rem + 1.2em); }
.ui[class*="right ribbon"].label { text-align: left; -webkit-transform: translateX(-100%); transform: translateX(-100%); border-radius: .25rem 0 0 .25rem; }
.ui[class*="right ribbon"].label:after { left: auto; right: 0; border-style: solid; border-width: 1.2em 1.2em 0 0; border-color: transparent; border-top-color: inherit; }
.ui.card .image > .ribbon.label, .ui.image > .ribbon.label { position: absolute; top: 1rem; }
.ui.card .image > .ui.ribbon.label, .ui.image > .ui.ribbon.label { left: calc(--.05rem - 1.2em); }
.ui.card .image > .ui[class*="right ribbon"].label, .ui.image > .ui[class*="right ribbon"].label { left: calc(100% + -.05rem + 1.2em); padding-left: .833em; }
.ui.table td > .ui.ribbon.label { left: calc(-.625em - 1.2em); }
.ui.table td > .ui[class*="right ribbon"].label { left: calc(100% + .625em + 1.2em); padding-left: .833em; }
.ui.attached.label, .ui[class*="top attached"].label { width: 100%; position: absolute; margin: 0; top: 0; left: 0; padding: .75em 1em; border-radius: .1875rem .1875rem 0 0; }
.ui[class*="bottom attached"].label { top: auto; bottom: 0; border-radius: 0 0 .1875rem .1875rem; }
.ui[class*="top left attached"].label { width: auto; margin-top: 0 !important; border-radius: .1875rem 0 .25rem 0; }
.ui[class*="top right attached"].label { width: auto; left: auto; right: 0; border-radius: 0 .1875rem 0 .25rem; }
.ui[class*="bottom left attached"].label { width: auto; top: auto; bottom: 0; border-radius: 0 .25rem 0 .1875rem; }
.ui[class*="bottom right attached"].label { top: auto; bottom: 0; left: auto; right: 0; width: auto; border-radius: .25rem 0 .1875rem 0; }
.ui.label.disabled { opacity: .5; }
a.ui.label:hover, a.ui.labels .label:hover { background-color: #e0e0e0; border-color: #e0e0e0; background-image: none; color: rgba(0, 0, 0, 0.8); }
.ui.labels a.label:hover:before, a.ui.label:hover:before { color: rgba(0, 0, 0, 0.8); }
.ui.active.label { background-color: #d0d0d0; border-color: #d0d0d0; background-image: none; color: rgba(0, 0, 0, 0.95); }
.ui.active.label:before { background-color: #d0d0d0; background-image: none; color: rgba(0, 0, 0, 0.95); }
a.ui.active.label:hover, a.ui.labels .active.label:hover { background-color: #c8c8c8; border-color: #c8c8c8; background-image: none; color: rgba(0, 0, 0, 0.95); }
.ui.labels a.active.label:ActiveHover:before, a.ui.active.label:ActiveHover:before { background-color: #c8c8c8; background-image: none; color: rgba(0, 0, 0, 0.95); }
.ui.label.visible:not(.dropdown), .ui.labels.visible .label { display: inline-block !important; }
.ui.label.hidden, .ui.labels.hidden .label { display: none !important; }
.ui.red.label, .ui.red.labels .label { background-color: #db2828 !important; border-color: #db2828 !important; color: #fff !important; }
.ui.red.labels .label:hover, a.ui.red.label:hover { background-color: #d01919 !important; border-color: #d01919 !important; color: #fff !important; }
.ui.red.corner.label, .ui.red.corner.label:hover { background-color: transparent !important; }
.ui.red.ribbon.label { border-color: #b21e1e !important; }
.ui.basic.red.label { background: none #fff !important; color: #db2828 !important; border-color: #db2828 !important; }
.ui.basic.red.labels a.label:hover, a.ui.basic.red.label:hover { background-color: #fff !important; color: #d01919 !important; border-color: #d01919 !important; }
.ui.orange.label, .ui.orange.labels .label { background-color: #f2711c !important; border-color: #f2711c !important; color: #fff !important; }
.ui.orange.labels .label:hover, a.ui.orange.label:hover { background-color: #f26202 !important; border-color: #f26202 !important; color: #fff !important; }
.ui.orange.corner.label, .ui.orange.corner.label:hover { background-color: transparent !important; }
.ui.orange.ribbon.label { border-color: #cf590c !important; }
.ui.basic.orange.label { background: none #fff !important; color: #f2711c !important; border-color: #f2711c !important; }
.ui.basic.orange.labels a.label:hover, a.ui.basic.orange.label:hover { background-color: #fff !important; color: #f26202 !important; border-color: #f26202 !important; }
.ui.yellow.label, .ui.yellow.labels .label { background-color: #fbbd08 !important; border-color: #fbbd08 !important; color: #fff !important; }
.ui.yellow.labels .label:hover, a.ui.yellow.label:hover { background-color: #eaae00 !important; border-color: #eaae00 !important; color: #fff !important; }
.ui.yellow.corner.label, .ui.yellow.corner.label:hover { background-color: transparent !important; }
.ui.yellow.ribbon.label { border-color: #cd9903 !important; }
.ui.basic.yellow.label { background: none #fff !important; color: #fbbd08 !important; border-color: #fbbd08 !important; }
.ui.basic.yellow.labels a.label:hover, a.ui.basic.yellow.label:hover { background-color: #fff !important; color: #eaae00 !important; border-color: #eaae00 !important; }
.ui.olive.label, .ui.olive.labels .label { background-color: #b5cc18 !important; border-color: #b5cc18 !important; color: #fff !important; }
.ui.olive.labels .label:hover, a.ui.olive.label:hover { background-color: #a7bd0d !important; border-color: #a7bd0d !important; color: #fff !important; }
.ui.olive.corner.label, .ui.olive.corner.label:hover { background-color: transparent !important; }
.ui.olive.ribbon.label { border-color: #198f35 !important; }
.ui.basic.olive.label { background: none #fff !important; color: #b5cc18 !important; border-color: #b5cc18 !important; }
.ui.basic.olive.labels a.label:hover, a.ui.basic.olive.label:hover { background-color: #fff !important; color: #a7bd0d !important; border-color: #a7bd0d !important; }
.ui.green.label, .ui.green.labels .label { background-color: #21ba45 !important; border-color: #21ba45 !important; color: #fff !important; }
.ui.green.labels .label:hover, a.ui.green.label:hover { background-color: #16ab39 !important; border-color: #16ab39 !important; color: #fff !important; }
.ui.green.corner.label, .ui.green.corner.label:hover { background-color: transparent !important; }
.ui.green.ribbon.label { border-color: #198f35 !important; }
.ui.basic.green.label { background: none #fff !important; color: #21ba45 !important; border-color: #21ba45 !important; }
.ui.basic.green.labels a.label:hover, a.ui.basic.green.label:hover { background-color: #fff !important; color: #16ab39 !important; border-color: #16ab39 !important; }
.ui.teal.label, .ui.teal.labels .label { background-color: #00b5ad !important; border-color: #00b5ad !important; color: #fff !important; }
.ui.teal.labels .label:hover, a.ui.teal.label:hover { background-color: #009c95 !important; border-color: #009c95 !important; color: #fff !important; }
.ui.teal.corner.label, .ui.teal.corner.label:hover { background-color: transparent !important; }
.ui.teal.ribbon.label { border-color: #00827c !important; }
.ui.basic.teal.label { background: none #fff !important; color: #00b5ad !important; border-color: #00b5ad !important; }
.ui.basic.teal.labels a.label:hover, a.ui.basic.teal.label:hover { background-color: #fff !important; color: #009c95 !important; border-color: #009c95 !important; }
.ui.blue.label, .ui.blue.labels .label { background-color: #2185d0 !important; border-color: #2185d0 !important; color: #fff !important; }
.ui.blue.labels .label:hover, a.ui.blue.label:hover { background-color: #1678c2 !important; border-color: #1678c2 !important; color: #fff !important; }
.ui.blue.corner.label, .ui.blue.corner.label:hover { background-color: transparent !important; }
.ui.blue.ribbon.label { border-color: #1a69a4 !important; }
.ui.basic.blue.label { background: none #fff !important; color: #2185d0 !important; border-color: #2185d0 !important; }
.ui.basic.blue.labels a.label:hover, a.ui.basic.blue.label:hover { background-color: #fff !important; color: #1678c2 !important; border-color: #1678c2 !important; }
.ui.violet.label, .ui.violet.labels .label { background-color: #6435c9 !important; border-color: #6435c9 !important; color: #fff !important; }
.ui.violet.labels .label:hover, a.ui.violet.label:hover { background-color: #5829bb !important; border-color: #5829bb !important; color: #fff !important; }
.ui.violet.corner.label, .ui.violet.corner.label:hover { background-color: transparent !important; }
.ui.violet.ribbon.label { border-color: #502aa1 !important; }
.ui.basic.violet.label { background: none #fff !important; color: #6435c9 !important; border-color: #6435c9 !important; }
.ui.basic.violet.labels a.label:hover, a.ui.basic.violet.label:hover { background-color: #fff !important; color: #5829bb !important; border-color: #5829bb !important; }
.ui.purple.label, .ui.purple.labels .label { background-color: #a333c8 !important; border-color: #a333c8 !important; color: #fff !important; }
.ui.purple.labels .label:hover, a.ui.purple.label:hover { background-color: #9627ba !important; border-color: #9627ba !important; color: #fff !important; }
.ui.purple.corner.label, .ui.purple.corner.label:hover { background-color: transparent !important; }
.ui.purple.ribbon.label { border-color: #82299f !important; }
.ui.basic.purple.label { background: none #fff !important; color: #a333c8 !important; border-color: #a333c8 !important; }
.ui.basic.purple.labels a.label:hover, a.ui.basic.purple.label:hover { background-color: #fff !important; color: #9627ba !important; border-color: #9627ba !important; }
.ui.pink.label, .ui.pink.labels .label { background-color: #e03997 !important; border-color: #e03997 !important; color: #fff !important; }
.ui.pink.labels .label:hover, a.ui.pink.label:hover { background-color: #e61a8d !important; border-color: #e61a8d !important; color: #fff !important; }
.ui.pink.corner.label, .ui.pink.corner.label:hover { background-color: transparent !important; }
.ui.pink.ribbon.label { border-color: #c71f7e !important; }
.ui.basic.pink.label { background: none #fff !important; color: #e03997 !important; border-color: #e03997 !important; }
.ui.basic.pink.labels a.label:hover, a.ui.basic.pink.label:hover { background-color: #fff !important; color: #e61a8d !important; border-color: #e61a8d !important; }
.ui.brown.label, .ui.brown.labels .label { background-color: #a5673f !important; border-color: #a5673f !important; color: #fff !important; }
.ui.brown.labels .label:hover, a.ui.brown.label:hover { background-color: #975b33 !important; border-color: #975b33 !important; color: #fff !important; }
.ui.brown.corner.label, .ui.brown.corner.label:hover { background-color: transparent !important; }
.ui.brown.ribbon.label { border-color: #805031 !important; }
.ui.basic.brown.label { background: none #fff !important; color: #a5673f !important; border-color: #a5673f !important; }
.ui.basic.brown.labels a.label:hover, a.ui.basic.brown.label:hover { background-color: #fff !important; color: #975b33 !important; border-color: #975b33 !important; }
.ui.grey.label, .ui.grey.labels .label { background-color: #767676 !important; border-color: #767676 !important; color: #fff !important; }
.ui.grey.labels .label:hover, a.ui.grey.label:hover { background-color: #838383 !important; border-color: #838383 !important; color: #fff !important; }
.ui.grey.corner.label, .ui.grey.corner.label:hover { background-color: transparent !important; }
.ui.grey.ribbon.label { border-color: #805031 !important; }
.ui.basic.grey.label { background: none #fff !important; color: #767676 !important; border-color: #767676 !important; }
.ui.basic.grey.labels a.label:hover, a.ui.basic.grey.label:hover { background-color: #fff !important; color: #838383 !important; border-color: #838383 !important; }
.ui.black.label, .ui.black.labels .label { background-color: #1b1c1d !important; border-color: #1b1c1d !important; color: #fff !important; }
.ui.black.labels .label:hover, a.ui.black.label:hover { background-color: #27292a !important; border-color: #27292a !important; color: #fff !important; }
.ui.black.corner.label, .ui.black.corner.label:hover { background-color: transparent !important; }
.ui.black.ribbon.label { border-color: #805031 !important; }
.ui.basic.black.label { background: none #fff !important; color: #1b1c1d !important; border-color: #1b1c1d !important; }
.ui.basic.black.labels a.label:hover, a.ui.basic.black.label:hover { background-color: #fff !important; color: #27292a !important; border-color: #27292a !important; }
.ui.basic.label { background: none #fff; border: 1px solid rgba(34, 36, 38, 0.15); color: rgba(0, 0, 0, 0.87); -webkit-box-shadow: none; box-shadow: none; }
a.ui.basic.label:hover { text-decoration: none; background: none #fff; color: #1c63b4; -webkit-box-shadow: 1px solid rgba(34, 36, 38, 0.15); box-shadow: 1px solid rgba(34, 36, 38, 0.15); -webkit-box-shadow: none; box-shadow: none; }
.ui.basic.pointing.label:before { border-color: inherit; }
.ui.fluid.labels > .label, .ui.label.fluid { width: 100%; -webkit-box-sizing: border-box; box-sizing: border-box; }
.ui.inverted.label, .ui.inverted.labels .label { color: rgba(255, 255, 255, 0.9) !important; }
.ui.horizontal.label, .ui.horizontal.labels .label { margin: 0 .5em 0 0; padding: .4em .833em; min-width: 3em; text-align: center; }
.ui.circular.label, .ui.circular.labels .label { min-width: 2em; min-height: 2em; padding: 0.5em !important; line-height: 1em; text-align: center; border-radius: 500rem; }
.ui.empty.circular.label, .ui.empty.circular.labels .label { min-width: 0; min-height: 0; overflow: hidden; width: .5em; height: .5em; vertical-align: baseline; }
.ui.pointing.label { position: relative; }
.ui.attached.pointing.label { position: absolute; }
.ui.pointing.label:before { background-color: inherit; background-image: inherit; border-width: none; border-style: solid; border-color: inherit; }
.ui.pointing.label:before { position: absolute; content: ''; -webkit-transform: rotate(45deg); transform: rotate(45deg); background-image: none; z-index: 2; width: .6666em; height: .6666em; -webkit-transition: background .1s ease; transition: background .1s ease; }
.ui.pointing.label, .ui[class*="pointing above"].label { margin-top: 1em; }
.ui.pointing.label:before, .ui[class*="pointing above"].label:before { border-width: 1px 0 0 1px; -webkit-transform: translateX(-50%) translateY(-50%) rotate(45deg); transform: translateX(-50%) translateY(-50%) rotate(45deg); top: 0; left: 50%; }
.ui[class*="bottom pointing"].label, .ui[class*="pointing below"].label { margin-top: 0; margin-bottom: 1em; }
.ui[class*="bottom pointing"].label:before, .ui[class*="pointing below"].label:before { border-width: 0 1px 1px 0; top: auto; right: auto; -webkit-transform: translateX(-50%) translateY(-50%) rotate(45deg); transform: translateX(-50%) translateY(-50%) rotate(45deg); top: 100%; left: 50%; }
.ui[class*="left pointing"].label { margin-top: 0; margin-left: .6666em; }
.ui[class*="left pointing"].label:before { border-width: 0 0 1px 1px; -webkit-transform: translateX(-50%) translateY(-50%) rotate(45deg); transform: translateX(-50%) translateY(-50%) rotate(45deg); bottom: auto; right: auto; top: 50%; left: 0; }
.ui[class*="right pointing"].label { margin-top: 0; margin-right: .6666em; }
.ui[class*="right pointing"].label:before { border-width: 1px 1px 0 0; -webkit-transform: translateX(50%) translateY(-50%) rotate(45deg); transform: translateX(50%) translateY(-50%) rotate(45deg); top: 50%; right: 0; bottom: auto; left: auto; }
.ui.basic.pointing.label:before, .ui.basic[class*="pointing above"].label:before { margin-top: -1px; }
.ui.basic[class*="bottom pointing"].label:before, .ui.basic[class*="pointing below"].label:before { bottom: auto; top: 100%; margin-top: 1px; }
.ui.basic[class*="left pointing"].label:before { top: 50%; left: -1px; }
.ui.basic[class*="right pointing"].label:before { top: 50%; right: -1px; }
.ui.floating.label { position: absolute; z-index: 100; top: -1em; left: 100%; margin: 0 0 0 -1.5em !important; }
.ui.mini.label, .ui.mini.labels .label { font-size: .5625rem; }
.ui.tiny.label, .ui.tiny.labels .label { font-size: .625rem; }
.ui.small.label, .ui.small.labels .label { font-size: .6875rem; }
.ui.label, .ui.labels .label { font-size: .75rem; }
.ui.large.label, .ui.large.labels .label { font-size: 1rem; }
.ui.big.label, .ui.big.labels .label { font-size: 1.25rem; }
.ui.huge.label, .ui.huge.labels .label { font-size: 1.5rem; }
.ui.massive.label, .ui.massive.labels .label { font-size: 2rem; }
.ui.list, ol.ui.list, ul.ui.list { list-style-type: none; margin: 1em 0; padding: 0 0; }
.ui.list:first-child, ol.ui.list:first-child, ul.ui.list:first-child { margin-top: 0; padding-top: 0; }
.ui.list:last-child, ol.ui.list:last-child, ul.ui.list:last-child { margin-bottom: 0; padding-bottom: 0; }
.ui.list .list > .item, .ui.list > .item, ol.ui.list li, ul.ui.list li { display: list-item; table-layout: fixed; list-style-type: none; list-style-position: outside; padding: .1875em 0; line-height: 1.125em; }
.ui.list > .item:after, .ui.list > .list > .item, ol.ui.list > li:first-child:after, ul.ui.list > li:first-child:after { content: ''; display: block; height: 0; clear: both; visibility: hidden; }
.ui.list .list > .item:first-child, .ui.list > .item:first-child, ol.ui.list li:first-child, ul.ui.list li:first-child { padding-top: 0; }
.ui.list .list > .item:last-child, .ui.list > .item:last-child, ol.ui.list li:last-child, ul.ui.list li:last-child { padding-bottom: 0; }
.ui.list .list, ol.ui.list ol, ul.ui.list ul { clear: both; margin: 0; padding: .75em 0 .25em .5em; }
.ui.list .list > .item, ol.ui.list ol li, ul.ui.list ul li { padding: .125em 0; line-height: inherit; }
.ui.list .list > .item > i.icon, .ui.list > .item > i.icon { display: table-cell; margin: 0; padding-top: 0; padding-right: .25em; vertical-align: top; -webkit-transition: color .1s ease; transition: color .1s ease; }
.ui.list .list > .item > i.icon:only-child, .ui.list > .item > i.icon:only-child { display: inline-block; vertical-align: top; }
.ui.list .list > .item > .image, .ui.list > .item > .image { display: table-cell; background-color: transparent; margin: 0; vertical-align: top; }
.ui.list .list > .item > .image:not(:only-child):not(img), .ui.list > .item > .image:not(:only-child):not(img) { padding-right: .5em; }
.ui.list .list > .item > .image img, .ui.list > .item > .image img { vertical-align: top; }
.ui.list .list > .item > .image:only-child, .ui.list .list > .item > img.image, .ui.list > .item > .image:only-child, .ui.list > .item > img.image { display: inline-block; }
.ui.list .list > .item > .content, .ui.list > .item > .content { line-height: 1.125em; }
.ui.list .list > .item > .icon + .content, .ui.list .list > .item > .image + .content, .ui.list > .item > .icon + .content, .ui.list > .item > .image + .content { display: table-cell; width: 100%; padding: 0 0 0 .5em; vertical-align: top; }
.ui.list .list > .item > img.image + .content, .ui.list > .item > img.image + .content { display: inline-block; width: auto; }
.ui.list .list > .item > .content > .list, .ui.list > .item > .content > .list { margin-left: 0; padding-left: 0; }
.ui.list .list > .item .header, .ui.list > .item .header { display: block; margin: 0; font-family: Raleway,sans-serif; font-weight: 700; color: rgba(0, 0, 0, 0.87); }
.ui.list .list > .item .description, .ui.list > .item .description { display: block; color: rgba(0, 0, 0, 0.7); }
.ui.list .list > .item a, .ui.list > .item a { cursor: pointer; }
.ui.list .list > a.item, .ui.list > a.item { cursor: pointer; color: #3a76bb; }
.ui.list .list > a.item:hover, .ui.list > a.item:hover { color: #1c63b4; }
.ui.list .list > a.item i.icon, .ui.list > a.item i.icon { color: rgba(0, 0, 0, 0.4); }
.ui.list .list > .item a.header, .ui.list > .item a.header { cursor: pointer; color: #3a76bb !important; }
.ui.list .list > .item a.header:hover, .ui.list > .item a.header:hover { color: #1c63b4 !important; }
.ui[class*="left floated"].list { float: left; }
.ui[class*="right floated"].list { float: right; }
.ui.list .list > .item [class*="left floated"], .ui.list > .item [class*="left floated"] { float: left; margin: 0 1em 0 0; }
.ui.list .list > .item [class*="right floated"], .ui.list > .item [class*="right floated"] { float: right; margin: 0 0 0 1em; }
.ui.menu .ui.list .list > .item, .ui.menu .ui.list > .item { display: list-item; table-layout: fixed; background-color: transparent; list-style-type: none; list-style-position: outside; padding: .1875em 0; line-height: 1.125em; }
.ui.menu .ui.list .list > .item:before, .ui.menu .ui.list > .item:before { border: none; background: 0 0; }
.ui.menu .ui.list .list > .item:first-child, .ui.menu .ui.list > .item:first-child { padding-top: 0; }
.ui.menu .ui.list .list > .item:last-child, .ui.menu .ui.list > .item:last-child { padding-bottom: 0; }
.ui.horizontal.list { display: inline-block; font-size: 0; }
.ui.horizontal.list > .item { display: inline-block; margin-left: 1em; font-size: 1rem; }
.ui.horizontal.list:not(.celled) > .item:first-child { margin-left: 0 !important; padding-left: 0 !important; }
.ui.horizontal.list .list { padding-left: 0; padding-bottom: 0; }
.ui.horizontal.list .list > .item > .content, .ui.horizontal.list .list > .item > .icon, .ui.horizontal.list .list > .item > .image, .ui.horizontal.list > .item > .content, .ui.horizontal.list > .item > .icon, .ui.horizontal.list > .item > .image { vertical-align: middle; }
.ui.horizontal.list > .item:first-child, .ui.horizontal.list > .item:last-child { padding-top: .1875em; padding-bottom: .1875em; }
.ui.horizontal.list > .item > i.icon { margin: 0; padding: 0 .25em 0 0; }
.ui.horizontal.list > .item > .icon, .ui.horizontal.list > .item > .icon + .content { float: none; display: inline-block; }
.ui.list .list > .disabled.item, .ui.list > .disabled.item { pointer-events: none; color: rgba(40, 40, 40, 0.3) !important; }
.ui.inverted.list .list > .disabled.item, .ui.inverted.list > .disabled.item { color: rgba(225, 225, 225, 0.3) !important; }
.ui.list .list > a.item:hover .icon, .ui.list > a.item:hover .icon { color: rgba(0, 0, 0, 0.87); }
.ui.inverted.list .list > a.item > .icon, .ui.inverted.list > a.item > .icon { color: rgba(255, 255, 255, 0.7); }
.ui.inverted.list .list > .item .header, .ui.inverted.list > .item .header { color: rgba(255, 255, 255, 0.9); }
.ui.inverted.list .list > .item .description, .ui.inverted.list > .item .description { color: rgba(255, 255, 255, 0.7); }
.ui.inverted.list .list > a.item, .ui.inverted.list > a.item { cursor: pointer; color: rgba(255, 255, 255, 0.9); }
.ui.inverted.list .list > a.item:hover, .ui.inverted.list > a.item:hover { color: #1c63b4; }
.ui.inverted.list .item a:not(.ui) { color: rgba(255, 255, 255, 0.9) !important; }
.ui.inverted.list .item a:not(.ui):hover { color: #1c63b4 !important; }
.ui.list [class*="top aligned"], .ui.list[class*="top aligned"] .content, .ui.list[class*="top aligned"] .image { vertical-align: top !important; }
.ui.list [class*="middle aligned"], .ui.list[class*="middle aligned"] .content, .ui.list[class*="middle aligned"] .image { vertical-align: middle !important; }
.ui.list [class*="bottom aligned"], .ui.list[class*="bottom aligned"] .content, .ui.list[class*="bottom aligned"] .image { vertical-align: bottom !important; }
.ui.link.list .item, .ui.link.list .item a:not(.ui), .ui.link.list a.item { color: rgba(0, 0, 0, 0.4); -webkit-transition: .1s color ease; transition: .1s color ease; }
.ui.link.list.list .item a:not(.ui):hover, .ui.link.list.list a.item:hover { color: rgba(0, 0, 0, 0.8); }
.ui.link.list.list .item a:not(.ui):active, .ui.link.list.list a.item:active { color: rgba(0, 0, 0, 0.9); }
.ui.link.list.list .active.item, .ui.link.list.list .active.item a:not(.ui) { color: rgba(0, 0, 0, 0.95); }
.ui.inverted.link.list .item, .ui.inverted.link.list .item a:not(.ui), .ui.inverted.link.list a.item { color: black; }
.ui.inverted.link.list.list .item a:not(.ui):hover, .ui.inverted.link.list.list a.item:hover { color: green; }
.ui.inverted.link.list.list .item a:not(.ui):active, .ui.inverted.link.list.list a.item:active { color: #fff; }
.ui.inverted.link.list.list .active.item a:not(.ui), .ui.inverted.link.list.list a.active.item { color: #fff; }
.ui.selection.list .list > .item, .ui.selection.list > .item { cursor: pointer; background: 0 0; padding: .5em .5em; margin: 0; color: rgba(0, 0, 0, 0.4); border-radius: .5em; -webkit-transition: .1s color ease,.1s padding-left ease,.1s background-color ease; transition: .1s color ease,.1s padding-left ease,.1s background-color ease; }
.ui.selection.list .list > .item:last-child, .ui.selection.list > .item:last-child { margin-bottom: 0; }
.ui.selection.list.list > .item:hover, .ui.selection.list > .item:hover { background: rgba(0, 0, 0, 0.03); color: rgba(0, 0, 0, 0.8); }
.ui.selection.list .list > .item:active, .ui.selection.list > .item:active { background: rgba(0, 0, 0, 0.05); color: rgba(0, 0, 0, 0.9); }
.ui.selection.list .list > .item.active, .ui.selection.list > .item.active { background: rgba(0, 0, 0, 0.05); color: rgba(0, 0, 0, 0.95); }
.ui.inverted.selection.list > .item { background: 0 0; color: rgba(255, 255, 255, 0.5); }
.ui.inverted.selection.list > .item:hover { background: rgba(255, 255, 255, 0.02); color: #fff; }
.ui.inverted.selection.list > .item:active { background: rgba(255, 255, 255, 0.08); color: #fff; }
.ui.inverted.selection.list > .item.active { background: rgba(255, 255, 255, 0.08); color: #fff; }
.ui.celled.selection.list .list > .item, .ui.celled.selection.list > .item, .ui.divided.selection.list .list > .item, .ui.divided.selection.list > .item { border-radius: 0; }
.ui.animated.list > .item { -webkit-transition: .25s color ease .1s,.25s padding-left ease .1s,.25s background-color ease .1s; transition: .25s color ease .1s,.25s padding-left ease .1s,.25s background-color ease .1s; }
.ui.animated.list:not(.horizontal) > .item:hover { padding-left: 1em; }
.ui.fitted.list:not(.selection) .list > .item, .ui.fitted.list:not(.selection) > .item { padding-left: 0; padding-right: 0; }
.ui.fitted.selection.list .list > .item, .ui.fitted.selection.list > .item { margin-left: -.5em; margin-right: -.5em; }
.ui.bulleted.list, ul.ui.list { margin-left: 1.25rem; }
.ui.bulleted.list .list > .item, .ui.bulleted.list > .item, ul.ui.list li { position: relative; }
.ui.bulleted.list .list > .item:before, .ui.bulleted.list > .item:before, ul.ui.list li:before { -webkit-user-select: none; -moz-user-select: none; -ms-user-select: none; user-select: none; pointer-events: none; position: absolute; top: auto; left: auto; font-weight: 400; margin-left: -1.25rem; content: '•'; opacity: 1; color: inherit; vertical-align: top; }
.ui.bulleted.list .list > a.item:before, .ui.bulleted.list > a.item:before, ul.ui.list li:before { color: rgba(0, 0, 0, 0.87); }
.ui.bulleted.list .list, ul.ui.list ul { padding-left: 1.25rem; }
.ui.horizontal.bulleted.list, ul.ui.horizontal.bulleted.list { margin-left: 0; }
.ui.horizontal.bulleted.list > .item, ul.ui.horizontal.bulleted.list li { margin-left: 1.75rem; }
.ui.horizontal.bulleted.list > .item:first-child, ul.ui.horizontal.bulleted.list li:first-child { margin-left: 0; }
.ui.horizontal.bulleted.list > .item::before, ul.ui.horizontal.bulleted.list li::before { color: rgba(0, 0, 0, 0.87); }
.ui.horizontal.bulleted.list > .item:first-child::before, ul.ui.horizontal.bulleted.list li:first-child::before { display: none; }
.ui.ordered.list, .ui.ordered.list .list, ol.ui.list, ol.ui.list ol { counter-reset: ordered; margin-left: 1.25rem; list-style-type: none; }
.ui.ordered.list .list > .item, .ui.ordered.list > .item, ol.ui.list li { list-style-type: none; position: relative; }
.ui.ordered.list .list > .item:before, .ui.ordered.list > .item:before, ol.ui.list li:before { position: absolute; top: auto; left: auto; -webkit-user-select: none; -moz-user-select: none; -ms-user-select: none; user-select: none; pointer-events: none; margin-left: -1.25rem; counter-increment: ordered; content: counters(ordered,".") " "; text-align: right; color: rgba(0, 0, 0, 0.87); vertical-align: middle; opacity: .8; }
.ui.ordered.inverted.list .list > .item:before, .ui.ordered.inverted.list > .item:before, ol.ui.inverted.list li:before { color: rgba(255, 255, 255, 0.7); }
.ui.ordered.list > .item[data-value], .ui.ordered.list > .list > .item[data-value] { content: attr(data-value); }
ol.ui.list li[value]:before { content: attr(value); }
.ui.ordered.list .list, ol.ui.list ol { margin-left: 1em; }
.ui.ordered.list .list > .item:before, ol.ui.list ol li:before { margin-left: -2em; }
.ui.ordered.horizontal.list, ol.ui.horizontal.list { margin-left: 0; }
.ui.ordered.horizontal.list .list > .item:before, .ui.ordered.horizontal.list > .item:before, ol.ui.horizontal.list li:before { position: static; margin: 0 .5em 0 0; }
.ui.divided.list > .item { border-top: 1px solid rgba(34, 36, 38, 0.15); }
.ui.divided.list .list > .item { border-top: none; }
.ui.divided.list .item .list > .item { border-top: none; }
.ui.divided.list .list > .item:first-child, .ui.divided.list > .item:first-child { border-top: none; }
.ui.divided.list:not(.horizontal) .list > .item:first-child { border-top-width: 1px; }
.ui.divided.bulleted.list .list, .ui.divided.bulleted.list:not(.horizontal) { margin-left: 0; padding-left: 0; }
.ui.divided.bulleted.list > .item:not(.horizontal) { padding-left: 1.25rem; }
.ui.divided.ordered.list { margin-left: 0; }
.ui.divided.ordered.list .list > .item, .ui.divided.ordered.list > .item { padding-left: 1.25rem; }
.ui.divided.ordered.list .item .list { margin-left: 0; margin-right: 0; padding-bottom: .1875em; }
.ui.divided.ordered.list .item .list > .item { padding-left: 1em; }
.ui.divided.selection.list .list > .item, .ui.divided.selection.list > .item { margin: 0; border-radius: 0; }
.ui.divided.horizontal.list { margin-left: 0; }
.ui.divided.horizontal.list > .item:not(:first-child) { padding-left: .5em; }
.ui.divided.horizontal.list > .item:not(:last-child) { padding-right: .5em; }
.ui.divided.horizontal.list > .item { border-top: none; border-left: 1px solid rgba(34, 36, 38, 0.15); margin: 0; line-height: .6; }
.ui.horizontal.divided.list > .item:first-child { border-left: none; }
.ui.divided.inverted.horizontal.list > .item, .ui.divided.inverted.list > .item, .ui.divided.inverted.list > .list { border-color: rgba(255, 255, 255, 0.1); }
.ui.celled.list > .item, .ui.celled.list > .list { border-top: 1px solid rgba(34, 36, 38, 0.15); padding-left: .5em; padding-right: .5em; }
.ui.celled.list > .item:last-child { border-bottom: 1px solid rgba(34, 36, 38, 0.15); }
.ui.celled.list > .item:first-child, .ui.celled.list > .item:last-child { padding-top: .1875em; padding-bottom: .1875em; }
.ui.celled.list .item .list > .item { border-width: 0; }
.ui.celled.list .list > .item:first-child { border-top-width: 0; }
.ui.celled.bulleted.list { margin-left: 0; }
.ui.celled.bulleted.list .list > .item, .ui.celled.bulleted.list > .item { padding-left: 1.25rem; }
.ui.celled.bulleted.list .item .list { margin-left: -1.25rem; margin-right: -1.25rem; padding-bottom: .1875em; }
.ui.celled.ordered.list { margin-left: 0; }
.ui.celled.ordered.list .list > .item, .ui.celled.ordered.list > .item { padding-left: 1.25rem; }
.ui.celled.ordered.list .item .list { margin-left: 0; margin-right: 0; padding-bottom: .1875em; }
.ui.celled.ordered.list .list > .item { padding-left: 1em; }
.ui.horizontal.celled.list { margin-left: 0; }
.ui.horizontal.celled.list .list > .item, .ui.horizontal.celled.list > .item { border-top: none; border-left: 1px solid rgba(34, 36, 38, 0.15); margin: 0; padding-left: .5em; padding-right: .5em; line-height: .6; }
.ui.horizontal.celled.list .list > .item:last-child, .ui.horizontal.celled.list > .item:last-child { border-bottom: none; border-right: 1px solid rgba(34, 36, 38, 0.15); }
.ui.celled.inverted.list > .item, .ui.celled.inverted.list > .list { border-color: 1px solid rgba(255, 255, 255, 0.1); }
.ui.celled.inverted.horizontal.list .list > .item, .ui.celled.inverted.horizontal.list > .item { border-color: 1px solid rgba(255, 255, 255, 0.1); }
.ui.relaxed.list:not(.horizontal) > .item:not(:first-child) { padding-top: .375em; }
.ui.relaxed.list:not(.horizontal) > .item:not(:last-child) { padding-bottom: .375em; }
.ui.horizontal.relaxed.list .list > .item:not(:first-child), .ui.horizontal.relaxed.list > .item:not(:first-child) { padding-left: 1rem; }
.ui.horizontal.relaxed.list .list > .item:not(:last-child), .ui.horizontal.relaxed.list > .item:not(:last-child) { padding-right: 1rem; }
.ui[class*="very relaxed"].list:not(.horizontal) > .item:not(:first-child) { padding-top: .75em; }
.ui[class*="very relaxed"].list:not(.horizontal) > .item:not(:last-child) { padding-bottom: .75em; }
.ui.horizontal[class*="very relaxed"].list .list > .item:not(:first-child), .ui.horizontal[class*="very relaxed"].list > .item:not(:first-child) { padding-left: 1.5rem; }
.ui.horizontal[class*="very relaxed"].list .list > .item:not(:last-child), .ui.horizontal[class*="very relaxed"].list > .item:not(:last-child) { padding-right: 1.5rem; }
.ui.mini.list { font-size: .625em; }
.ui.tiny.list { font-size: .75em; }
.ui.small.list { font-size: .875em; }
.ui.list { font-size: 1em; }
.ui.large.list { font-size: 1.125em; }
.ui.big.list { font-size: 1.25em; }
.ui.huge.list { font-size: 1.5em; }
.ui.massive.list { font-size: 2em; }
.ui.mini.horizontal.list .list > .item, .ui.mini.horizontal.list > .item { font-size: .625rem; }
.ui.tiny.horizontal.list .list > .item, .ui.tiny.horizontal.list > .item { font-size: .75rem; }
.ui.small.horizontal.list .list > .item, .ui.small.horizontal.list > .item { font-size: .875rem; }
.ui.horizontal.list .list > .item, .ui.horizontal.list > .item { font-size: 1rem; }
.ui.large.horizontal.list .list > .item, .ui.large.horizontal.list > .item { font-size: 1.125rem; }
.ui.big.horizontal.list .list > .item, .ui.big.horizontal.list > .item { font-size: 1.25rem; }
.ui.huge.horizontal.list .list > .item, .ui.huge.horizontal.list > .item { font-size: 1.5rem; }
.ui.massive.horizontal.list .list > .item, .ui.massive.horizontal.list > .item { font-size: 2rem; }
.ui.menu { display: -webkit-box; display: -ms-flexbox; display: flex; margin: 1rem 0; font-family: Montserrat,sans-serif; background: #fff; font-weight: 400; border: 1px solid rgba(34, 36, 38, 0.15); -webkit-box-shadow: 0 1px 2px 0 rgba(34, 36, 38, 0.15); box-shadow: 0 1px 2px 0 rgba(34, 36, 38, 0.15); min-height: 2.75em; /*overflow-y: scroll*/
.ui.menu:after { content: ''; display: block; height: 0; clear: both; visibility: hidden; }
.ui.menu:first-child { margin-top: 0; }
.ui.menu:last-child { margin-bottom: 0; }
.ui.menu .menu { margin: 0; }
.ui.menu:not(.vertical) > .menu { display: -webkit-box; display: -ms-flexbox; display: flex; }
.ui.menu:not(.vertical) .item { display: -webkit-box; display: -ms-flexbox; display: flex; -webkit-box-align: center; -ms-flex-align: center; align-items: center; }
.ui.menu .item { position: relative; vertical-align: middle; line-height: 1; text-decoration: none; -webkit-tap-highlight-color: transparent; -webkit-box-flex: 0; -ms-flex: 0 0 auto; flex: 0 0 auto; -webkit-user-select: none; -moz-user-select: none; -ms-user-select: none; user-select: none; background: 0 0; padding: .875em 1.125em; text-transform: none; color: rgba(0, 0, 0, 0.87); font-weight: 400; -webkit-transition: background .1s ease,color .1s ease,-webkit-box-shadow .1s ease; transition: background .1s ease,color .1s ease,-webkit-box-shadow .1s ease; transition: background .1s ease,box-shadow .1s ease,color .1s ease; transition: background .1s ease,box-shadow .1s ease,color .1s ease,-webkit-box-shadow .1s ease; }
.ui.menu > .item:first-child { border-radius: .25rem 0 0 .25rem; }
.ui.menu .item:before { position: absolute; content: ''; top: 0; right: 0; height: 100%; width: 1px; background: rgba(34, 36, 38, 0.1); }
.ui.menu .item > a:not(.ui), .ui.menu .item > p:only-child, .ui.menu .text.item > * { -webkit-user-select: text; -moz-user-select: text; -ms-user-select: text; user-select: text; line-height: 1.3; }
.ui.menu .item > p:first-child { margin-top: 0; }
.ui.menu .item > p:last-child { margin-bottom: 0; }
.ui.menu .item > i.icon { opacity: .9; float: none; margin: 0 .3125em 0 0; }
.ui.menu:not(.vertical) .item > .button { position: relative; top: 0; margin: -.5em 0; padding-bottom: .625em; padding-top: .625em; font-size: 1em; }
.ui.menu > .container, .ui.menu > .grid { display: -webkit-box; display: -ms-flexbox; display: flex; -webkit-box-align: inherit; -ms-flex-align: inherit; align-items: inherit; -webkit-box-orient: inherit; -webkit-box-direction: inherit; -ms-flex-direction: inherit; flex-direction: inherit; }
.ui.menu .item > .input { width: 100%; }
.ui.menu:not(.vertical) .item > .input { position: relative; top: 0; margin: -.5em 0; }
.ui.menu .item > .input input { font-size: 1em; padding-top: .5em; padding-bottom: .5em; }
.ui.menu .header.item, .ui.vertical.menu .header.item { margin: 0; background: ''; text-transform: normal; font-weight: 700; }
.ui.vertical.menu .item > .header:not(.ui) { margin: 0 0 .5em; font-size: 1em; font-weight: 700; }
.ui.menu .item > i.dropdown.icon { padding: 0; float: right; margin: 0 0 0 1em; }
.ui.menu .dropdown.item .menu { min-width: calc(100% - 1px); border-radius: 0 0 .25rem .25rem; background: #fff; margin: 0 0 0; -webkit-box-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.08); box-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.08); -webkit-box-orient: vertical !important; -webkit-box-direction: normal !important; -ms-flex-direction: column !important; flex-direction: column !important; }
.ui.menu .ui.dropdown .menu > .item { margin: 0; text-align: left; font-size: 1em !important; padding: 0.625em 1.125em !important; background: 0 0 !important; color: rgba(0, 0, 0, 0.87) !important; text-transform: none !important; font-weight: 400 !important; -webkit-box-shadow: none !important; box-shadow: none !important; -webkit-transition: none !important; transition: none !important; }
.ui.menu .ui.dropdown .menu > .item:hover { background: rgba(0, 0, 0, 0.05) !important; color: rgba(0, 0, 0, 0.95) !important; }
.ui.menu .ui.dropdown .menu > .selected.item { background: rgba(0, 0, 0, 0.05) !important; color: rgba(0, 0, 0, 0.95) !important; }
.ui.menu .ui.dropdown .menu > .active.item { background: rgba(0, 0, 0, 0.03) !important; font-weight: 700 !important; color: rgba(0, 0, 0, 0.95) !important; }
.ui.menu .ui.dropdown.item .menu .item:not(.filtered) { display: block; }
.ui.menu .ui.dropdown .menu > .item .icon:not(.dropdown) { display: inline-block; font-size: 1em !important; float: none; margin: 0 0.75em 0 0 !important; }
.ui.secondary.menu .dropdown.item > .menu, .ui.text.menu .dropdown.item > .menu { border-radius: .25rem; margin-top: .3125em; }
.ui.menu .pointing.dropdown.item .menu { margin-top: .75em; }
.ui.inverted.menu .search.dropdown.item > .search, .ui.inverted.menu .search.dropdown.item > .text { color: rgba(255, 255, 255, 0.9); }
.ui.vertical.menu .dropdown.item > .icon { float: right; content: "\f0da"; margin-left: 1em; }
.ui.vertical.menu .dropdown.item .menu { left: 100%; min-width: 0; margin: 0; -webkit-box-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.08); box-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.08); border-radius: 0 .25rem .25rem .25rem; }
.ui.vertical.menu .dropdown.item.upward .menu { bottom: 0; }
.ui.vertical.menu .dropdown.item:not(.upward) .menu { top: 0; }
.ui.vertical.menu .active.dropdown.item { border-top-right-radius: 0; border-bottom-right-radius: 0; }
.ui.vertical.menu .dropdown.active.item { -webkit-box-shadow: none; box-shadow: none; }
.ui.item.menu .dropdown .menu .item { width: 100%; }
.ui.menu .item > .label { background: #999; color: #fff; margin-left: 1em; padding: .3em .625em; }
.ui.vertical.menu .item > .label { background: #999; color: #fff; margin-top: -.15em; margin-bottom: -.15em; padding: .3em .625em; }
.ui.menu .item > .floating.label { padding: .3em .625em; }
.ui.menu .item > img:not(.ui) { display: inline-block; vertical-align: middle; margin: -.3em 0; width: 2.5em; }
.ui.vertical.menu .item > img:not(.ui):only-child { display: block; max-width: 100%; width: auto; }
.ui.menu .list .item:before { background: 0 0 !important; }
.ui.vertical.sidebar.menu > .item:first-child:before { display: block !important; }
.ui.vertical.sidebar.menu > .item::before { top: auto; bottom: 0; }
@media only screen and (max-width: 767px) { .ui.menu > .ui.container { width: 100% !important; margin-left: 0 !important; margin-right: 0 !important; } }
@media only screen and (min-width: 768px) { .ui.menu:not(.secondary):not(.text):not(.tabular):not(.borderless) > .container > .item:not(.right):not(.borderless):first-child { border-left: 1px solid rgba(34, 36, 38, 0.1); } }
.ui.link.menu .item:hover, .ui.menu .dropdown.item:hover, .ui.menu .link.item:hover, .ui.menu a.item:hover { cursor: pointer; background: rgba(0, 0, 0, 0.03); color: rgba(0, 0, 0, 0.95); }
.ui.link.menu .item:active, .ui.menu .link.item:active, .ui.menu a.item:active { background: rgba(0, 0, 0, 0.03); color: rgba(0, 0, 0, 0.95); }
.ui.menu .active.item { background: rgba(0, 0, 0, 0.05); color: rgba(0, 0, 0, 0.95); font-weight: 400; -webkit-box-shadow: none; box-shadow: none; }
.ui.menu .active.item > i.icon { opacity: 1; }
.ui.menu .active.item:hover, .ui.vertical.menu .active.item:hover { background-color: rgba(0, 0, 0, 0.05); color: rgba(0, 0, 0, 0.95); }
.ui.menu .item.disabled, .ui.menu .item.disabled:hover { cursor: default !important; background-color: transparent !important; color: rgba(40, 40, 40, 0.3) !important; }
.ui.menu:not(.vertical) .left.item, .ui.menu:not(.vertical) :not(.dropdown) > .left.menu { display: -webkit-box; display: -ms-flexbox; display: flex; margin-right: auto !important; }
.ui.menu:not(.vertical) .right.item, .ui.menu:not(.vertical) .right.menu { display: -webkit-box; display: -ms-flexbox; display: flex; margin-left: auto !important; }
.ui.menu .right.item::before, .ui.menu .right.menu > .item::before { right: auto; left: 0; }
.ui.vertical.menu { display: block; -webkit-box-orient: vertical; -webkit-box-direction: normal; -ms-flex-direction: column; flex-direction: column; background: #fff; -webkit-box-shadow: 0 1px 2px 0 rgba(34, 36, 38, 0.15); box-shadow: 0 1px 2px 0 rgba(34, 36, 38, 0.15); }
.ui.vertical.menu .item { display: block; background: 0 0; border-top: none; border-right: none; }
.ui.vertical.menu > .item:first-child { border-radius: .25rem .25rem 0 0; }
.ui.vertical.menu > .item:last-child { border-radius: 0 0 .25rem .25rem; }
.ui.vertical.menu .item > .label { float: right; text-align: center; }
.ui.vertical.menu .item > i.icon { width: 1.18em; float: right; margin: 0 0 0 .5em; }
.ui.vertical.menu .item > .label + i.icon { float: none; margin: 0 .5em 0 0; }
.ui.vertical.menu .item:before { position: absolute; content: ''; top: 0; left: 0; width: 100%; height: 1px; background: rgba(34, 36, 38, 0.1); }
.ui.vertical.menu .item:first-child:before { display: none !important; }
.ui.vertical.menu .item > .menu { margin: .5em -1.125em 0; }
.ui.vertical.menu .menu .item { background: 0 0; padding: .5em 1.5em; font-size: .75em; color: rgba(0, 0, 0, 0.5); }
.ui.vertical.menu .item .menu .link.item:hover, .ui.vertical.menu .item .menu a.item:hover { color: rgba(0, 0, 0, 0.85); }
.ui.vertical.menu .menu .item:before { display: none; }
.ui.vertical.menu .active.item { background: rgba(0, 0, 0, 0.05); border-radius: 0; -webkit-box-shadow: none; box-shadow: none; }
.ui.vertical.menu > .active.item:first-child { border-radius: .25rem .25rem 0 0; }
.ui.vertical.menu > .active.item:last-child { border-radius: 0 0 .25rem .25rem; }
.ui.vertical.menu > .active.item:only-child { border-radius: .25rem; }
.ui.vertical.menu .active.item .menu .active.item { border-left: none; }
.ui.vertical.menu .item .menu .active.item { background-color: transparent; font-weight: 700; color: rgba(0, 0, 0, 0.95); }
.ui.tabular.menu { border-radius: 0; -webkit-box-shadow: none !important; box-shadow: none !important; border: none; background: none transparent; border-bottom: 1px solid #d4d4d5; }
.ui.tabular.fluid.menu { width: calc(100% + (1px * 2)) !important; }
.ui.tabular.menu .item { background: 0 0; border-bottom: none; border-left: 1px solid transparent; border-right: 1px solid transparent; border-top: 2px solid transparent; padding: .875em 1.5em; color: rgba(0, 0, 0, 0.87); }
.ui.tabular.menu .item:before { display: none; }
.ui.tabular.menu .item:hover { background-color: transparent; color: rgba(0, 0, 0, 0.8); }
.ui.tabular.menu .active.item { background: none #fff; color: rgba(0, 0, 0, 0.95); border-top-width: 1px; border-color: #d4d4d5; font-weight: 700; margin-bottom: -1px; -webkit-box-shadow: none; box-shadow: none; border-radius: 0.25rem 0.25rem 0 0 !important; }
.ui.tabular.menu + .attached:not(.top).segment, .ui.tabular.menu + .attached:not(.top).segment + .attached:not(.top).segment { border-top: none; margin-left: 0; margin-top: 0; margin-right: 0; width: 100%; }
.top.attached.segment + .ui.bottom.tabular.menu { position: relative; width: calc(100% + (1px * 2)); left: -1px; }
.ui.bottom.tabular.menu { background: none transparent; border-radius: 0; -webkit-box-shadow: none !important; box-shadow: none !important; border-bottom: none; border-top: 1px solid #d4d4d5; }
.ui.bottom.tabular.menu .item { background: 0 0; border-left: 1px solid transparent; border-right: 1px solid transparent; border-bottom: 1px solid transparent; border-top: none; }
.ui.bottom.tabular.menu .active.item { background: none #fff; color: rgba(0, 0, 0, 0.95); border-color: #d4d4d5; margin: -1px 0 0 0; border-radius: 0 0 0.25rem 0.25rem !important; }
.ui.vertical.tabular.menu { background: none transparent; border-radius: 0; -webkit-box-shadow: none !important; box-shadow: none !important; border-bottom: none; border-right: 1px solid #d4d4d5; }
.ui.vertical.tabular.menu .item { background: 0 0; border-left: 1px solid transparent; border-bottom: 1px solid transparent; border-top: 1px solid transparent; border-right: none; }
.ui.vertical.tabular.menu .active.item { background: none #fff; color: rgba(0, 0, 0, 0.95); border-color: #d4d4d5; margin: 0 -1px 0 0; border-radius: 0.25rem 0 0 0.25rem !important; }
.ui.vertical.right.tabular.menu { background: none transparent; border-radius: 0; -webkit-box-shadow: none !important; box-shadow: none !important; border-bottom: none; border-right: none; border-left: 1px solid #d4d4d5; }
.ui.vertical.right.tabular.menu .item { background: 0 0; border-right: 1px solid transparent; border-bottom: 1px solid transparent; border-top: 1px solid transparent; border-left: none; }
.ui.vertical.right.tabular.menu .active.item { background: none #fff; color: rgba(0, 0, 0, 0.95); border-color: #d4d4d5; margin: 0 0 0 -1px; border-radius: 0 0.25rem 0.25rem 0 !important; }
.ui.tabular.menu .active.dropdown.item { margin-bottom: 0; border-left: 1px solid transparent; border-right: 1px solid transparent; border-top: 2px solid transparent; border-bottom: none; }
.ui.pagination.menu { margin: 0; display: -webkit-inline-box; display: -ms-inline-flexbox; display: inline-flex; vertical-align: middle; }
.ui.pagination.menu .item:last-child { border-radius: 0 .25rem .25rem 0; }
.ui.compact.menu .item:last-child { border-radius: 0 .25rem .25rem 0; }
.ui.pagination.menu .item:last-child:before { display: none; }
.ui.pagination.menu .item { min-width: 3em; text-align: center; }
.ui.pagination.menu .icon.item i.icon { vertical-align: top; }
.ui.pagination.menu .active.item { border-top: none; padding-top: .875em; background-color: rgba(0, 0, 0, 0.05); color: rgba(0, 0, 0, 0.95); -webkit-box-shadow: none; box-shadow: none; }
.ui.secondary.menu { background: 0 0; margin-left: -.3125em; margin-right: -.3125em; border-radius: 0; border: none; -webkit-box-shadow: none; box-shadow: none; }
.ui.secondary.menu .item { -ms-flex-item-align: center; align-self: center; -webkit-box-shadow: none; box-shadow: none; border: none; padding: .625em .875em; margin: 0 .3125em; background: 0 0; -webkit-transition: color .1s ease; transition: color .1s ease; border-radius: .25rem; }
.ui.secondary.menu .item:before { display: none !important; }
.ui.secondary.menu .header.item { border-radius: 0; border-right: none; background: none transparent; }
.ui.secondary.menu .item > img:not(.ui) { margin: 0; }
.ui.secondary.menu .dropdown.item:hover, .ui.secondary.menu .link.item:hover, .ui.secondary.menu a.item:hover { background: rgba(0, 0, 0, 0.05); color: rgba(0, 0, 0, 0.95); }
.ui.secondary.menu .active.item { -webkit-box-shadow: none; box-shadow: none; background: rgba(0, 0, 0, 0.05); color: rgba(0, 0, 0, 0.95); border-radius: .25rem; }
.ui.secondary.menu .active.item:hover { -webkit-box-shadow: none; box-shadow: none; background: rgba(0, 0, 0, 0.05); color: rgba(0, 0, 0, 0.95); }
.ui.secondary.inverted.menu .link.item, .ui.secondary.inverted.menu a.item { color: rgba(255, 255, 255, 0.7) !important; }
.ui.secondary.inverted.menu .dropdown.item:hover, .ui.secondary.inverted.menu .link.item:hover, .ui.secondary.inverted.menu a.item:hover { background: rgba(255, 255, 255, 0.08); color: #fff !important; }
.ui.secondary.inverted.menu .active.item { background: rgba(255, 255, 255, 0.15); color: #fff !important; }
.ui.secondary.item.menu { margin-left: 0; margin-right: 0; }
.ui.secondary.item.menu .item:last-child { margin-right: 0; }
.ui.secondary.attached.menu { -webkit-box-shadow: none; box-shadow: none; }
.ui.vertical.secondary.menu .item:not(.dropdown) > .menu { margin: 0 -.875em; }
.ui.vertical.secondary.menu .item:not(.dropdown) > .menu > .item { margin: 0; padding: .4375em 1.5em; }
.ui.secondary.vertical.menu > .item { border: none; margin: 0 0 .3125em; border-radius: 0.25rem !important; }
.ui.secondary.vertical.menu > .header.item { border-radius: 0; }
.ui.vertical.secondary.menu .item > .menu .item { background-color: transparent; }
.ui.secondary.inverted.menu { background-color: transparent; }
.ui.secondary.pointing.menu { margin-left: 0; margin-right: 0; border-bottom: 2px solid rgba(34, 36, 38, 0.15); }
.ui.secondary.pointing.menu .item { border-bottom-color: transparent; border-bottom-style: solid; border-radius: 0; -ms-flex-item-align: end; align-self: flex-end; margin: 0 0 -2px; padding: .75em 1.125em; border-bottom-width: 2px; -webkit-transition: color .1s ease; transition: color .1s ease; }
.ui.secondary.pointing.menu .header.item { color: rgba(0, 0, 0, 0.85) !important; }
.ui.secondary.pointing.menu .text.item { -webkit-box-shadow: none !important; box-shadow: none !important; }
.ui.secondary.pointing.menu .item:after { display: none; }
.ui.secondary.pointing.menu .dropdown.item:hover, .ui.secondary.pointing.menu .link.item:hover, .ui.secondary.pointing.menu a.item:hover { background-color: transparent; color: rgba(0, 0, 0, 0.87); }
.ui.secondary.pointing.menu .dropdown.item:active, .ui.secondary.pointing.menu .link.item:active, .ui.secondary.pointing.menu a.item:active { background-color: transparent; border-color: rgba(34, 36, 38, 0.15); }
.ui.secondary.pointing.menu .active.item { background-color: transparent; -webkit-box-shadow: none; box-shadow: none; border-color: #1b1c1d; font-weight: 700; color: rgba(0, 0, 0, 0.95); }
.ui.secondary.pointing.menu .active.item:hover { border-color: #1b1c1d; color: rgba(0, 0, 0, 0.95); }
.ui.secondary.pointing.menu .active.dropdown.item { border-color: transparent; }
.ui.secondary.vertical.pointing.menu { border-bottom-width: 0; border-right-width: 2px; border-right-style: solid; border-right-color: rgba(34, 36, 38, 0.15); }
.ui.secondary.vertical.pointing.menu .item { border-bottom: none; border-right-style: solid; border-right-color: transparent; border-radius: 0 !important; margin: 0 -2px 0 0; border-right-width: 2px; }
.ui.secondary.vertical.pointing.menu .active.item { border-color: #1b1c1d; }
.ui.secondary.inverted.pointing.menu { border-color: rgba(255, 255, 255, 0.1); }
.ui.secondary.inverted.pointing.menu .item { color: rgba(255, 255, 255, 0.9); }
.ui.secondary.inverted.pointing.menu .header.item { color: #fff !important; }
.ui.secondary.inverted.pointing.menu .link.item:hover, .ui.secondary.inverted.pointing.menu a.item:hover { color: rgba(0, 0, 0, 0.95); }
.ui.secondary.inverted.pointing.menu .active.item { border-color: #fff; color: #fff; }
.ui.text.menu { background: none transparent; border-radius: 0; -webkit-box-shadow: none; box-shadow: none; border: none; margin: 1em -.4375em; }
.ui.text.menu .item { border-radius: 0; -webkit-box-shadow: none; box-shadow: none; -ms-flex-item-align: center; align-self: center; margin: 0 0; padding: .3125em .4375em; font-weight: 400; color: rgba(0, 0, 0, 0.6); -webkit-transition: opacity .1s ease; transition: opacity .1s ease; }
.ui.text.menu .item:before, .ui.text.menu .menu .item:before { display: none !important; }
.ui.text.menu .header.item { background-color: transparent; opacity: 1; color: rgba(0, 0, 0, 0.85); font-size: .875em; text-transform: uppercase; font-weight: 700; }
.ui.text.menu .item > img:not(.ui) { margin: 0; }
.ui.text.item.menu .item { margin: 0; }
.ui.vertical.text.menu { margin: 1em 0; }
.ui.vertical.text.menu:first-child { margin-top: 0; }
.ui.vertical.text.menu:last-child { margin-bottom: 0; }
.ui.vertical.text.menu .item { margin: .5em 0; padding-left: 0; padding-right: 0; }
.ui.vertical.text.menu .item > i.icon { float: none; margin: 0 .3125em 0 0; }
.ui.vertical.text.menu .header.item { margin: .5em 0 .625em; }
.ui.vertical.text.menu .item:not(.dropdown) > .menu { margin: 0; }
.ui.vertical.text.menu .item:not(.dropdown) > .menu > .item { margin: 0; padding: .4375em 0; }
.ui.text.menu .item:hover { opacity: 1; background-color: transparent; }
.ui.text.menu .active.item { background-color: transparent; border: none; -webkit-box-shadow: none; box-shadow: none; font-weight: 400; color: rgba(0, 0, 0, 0.95); }
.ui.text.menu .active.item:hover { background-color: transparent; }
.ui.text.pointing.menu .active.item:after { -webkit-box-shadow: none; box-shadow: none; }
.ui.text.attached.menu { -webkit-box-shadow: none; box-shadow: none; }
.ui.inverted.text.menu, .ui.inverted.text.menu .active.item, .ui.inverted.text.menu .item, .ui.inverted.text.menu .item:hover { background-color: transparent !important; }
.ui.fluid.text.menu { margin-left: 0; margin-right: 0; }
.ui.vertical.icon.menu { display: inline-block; width: auto; }
.ui.icon.menu .item { height: auto; text-align: center; color: #1b1c1d; }
.ui.icon.menu .item > .icon:not(.dropdown) { margin: 0; opacity: 1; }
.ui.icon.menu .icon:before { opacity: 1; }
.ui.menu .icon.item > .icon { width: auto; margin: 0 auto; }
.ui.vertical.icon.menu .item > .icon:not(.dropdown) { display: block; opacity: 1; margin: 0 auto; float: none; }
.ui.inverted.icon.menu .item { color: #fff; }
.ui.labeled.icon.menu { text-align: center; }
.ui.labeled.icon.menu .item { min-width: 6em; -webkit-box-orient: vertical; -webkit-box-direction: normal; -ms-flex-direction: column; flex-direction: column; }
.ui.labeled.icon.menu .item > .icon:not(.dropdown) { height: 1em; display: block; font-size: 2em !important; margin: 0 auto 0.5rem !important; }
.ui.fluid.labeled.icon.menu > .item { min-width: 0; }
@media only screen and (max-width: 767px) { .ui.stackable.menu { -webkit-box-orient: vertical; -webkit-box-direction: normal; -ms-flex-direction: column; flex-direction: column; }
  .ui.stackable.menu .item { width: 100% !important; }
  .ui.stackable.menu .item:before { position: absolute; content: ''; top: auto; bottom: 0; left: 0; width: 100%; height: 1px; background: rgba(34, 36, 38, 0.1); }
  .ui.stackable.menu .left.item, .ui.stackable.menu .left.menu { margin-right: 0 !important; }
  .ui.stackable.menu .right.item, .ui.stackable.menu .right.menu { margin-left: 0 !important; }
  .ui.stackable.menu .left.menu, .ui.stackable.menu .right.menu { -webkit-box-orient: vertical; -webkit-box-direction: normal; -ms-flex-direction: column; flex-direction: column; } }
.ui.menu .red.active.item, .ui.red.menu .active.item { border-color: #db2828 !important; color: #db2828 !important; }
.ui.menu .orange.active.item, .ui.orange.menu .active.item { border-color: #f2711c !important; color: #f2711c !important; }
.ui.menu .yellow.active.item, .ui.yellow.menu .active.item { border-color: #fbbd08 !important; color: #fbbd08 !important; }
.ui.menu .olive.active.item, .ui.olive.menu .active.item { border-color: #b5cc18 !important; color: #b5cc18 !important; }
.ui.green.menu .active.item, .ui.menu .green.active.item { border-color: #21ba45 !important; color: #21ba45 !important; }
.ui.menu .teal.active.item, .ui.teal.menu .active.item { border-color: #00b5ad !important; color: #00b5ad !important; }
.ui.blue.menu .active.item, .ui.menu .blue.active.item { border-color: #2185d0 !important; color: #2185d0 !important; }
.ui.menu .violet.active.item, .ui.violet.menu .active.item { border-color: #6435c9 !important; color: #6435c9 !important; }
.ui.menu .purple.active.item, .ui.purple.menu .active.item { border-color: #a333c8 !important; color: #a333c8 !important; }
.ui.menu .pink.active.item, .ui.pink.menu .active.item { border-color: #e03997 !important; color: #e03997 !important; }
.ui.brown.menu .active.item, .ui.menu .brown.active.item { border-color: #a5673f !important; color: #a5673f !important; }
.ui.grey.menu .active.item, .ui.menu .grey.active.item { border-color: #767676 !important; color: #767676 !important; }
.ui.inverted.menu { border: 0 solid transparent; background: white; -webkit-box-shadow: none; box-shadow: none; }
.ui.inverted.menu .item, .ui.inverted.menu .item > a:not(.ui) { background: 0 0; color: rgba(255, 255, 255, 0.9); }
.ui.inverted.menu .item.menu { background: 0 0; }
.ui.inverted.menu .item:before { background: rgba(255, 255, 255, 0.08); }
.ui.vertical.inverted.menu .item:before { background: rgba(255, 255, 255, 0.08); }
.ui.vertical.inverted.menu .menu .item, .ui.vertical.inverted.menu .menu .item a:not(.ui) { color: rgba(255, 255, 255, 0.5); }
.ui.inverted.menu .header.item { margin: 0; background: 0 0; -webkit-box-shadow: none; box-shadow: none; }
.ui.inverted.menu .item.disabled, .ui.inverted.menu .item.disabled:hover { color: rgba(225, 225, 225, 0.3); }
.ui.inverted.menu .dropdown.item:hover, .ui.inverted.menu .link.item:hover, .ui.inverted.menu a.item:hover, .ui.link.inverted.menu .item:hover { background: rgba(255, 255, 255, 0.08); color: #fff; }
.ui.vertical.inverted.menu .item .menu .link.item:hover, .ui.vertical.inverted.menu .item .menu a.item:hover { background: 0 0; color: #fff; }
.ui.inverted.menu .link.item:active, .ui.inverted.menu a.item:active { background: rgba(255, 255, 255, 0.08); color: green !important; }
.ui.inverted.menu .active.item { background: rgba(255, 255, 255, 0.15); color: black !important; }
.ui.inverted.vertical.menu .item .menu .active.item { background: 0 0; color: #fff; }
.ui.inverted.pointing.menu .active.item:after { background: #3d3e3f !important; margin: 0 !important; -webkit-box-shadow: none !important; box-shadow: none !important; border: none !important; }
.ui.inverted.menu .active.item:hover { background: rgba(255, 255, 255, 0.15); color: green !important; font-weight: 500 !important; }
.ui.inverted.pointing.menu .active.item:hover:after { background: #3d3e3f !important; }
.ui.floated.menu { float: left; margin: 0 .5rem 0 0; }
.ui.floated.menu .item:last-child:before { display: none; }
.ui.right.floated.menu { float: right; margin: 0 0 0 .5rem; }
.ui.inverted.menu .red.active.item, .ui.inverted.red.menu { background-color: #db2828; }
.ui.inverted.red.menu .item:before { background-color: rgba(34, 36, 38, 0.1); }
.ui.inverted.red.menu .active.item { background-color: rgba(0, 0, 0, 0.1) !important; }
.ui.inverted.menu .orange.active.item, .ui.inverted.orange.menu { background-color: #f2711c; }
.ui.inverted.orange.menu .item:before { background-color: rgba(34, 36, 38, 0.1); }
.ui.inverted.orange.menu .active.item { background-color: rgba(0, 0, 0, 0.1) !important; }
.ui.inverted.menu .yellow.active.item, .ui.inverted.yellow.menu { background-color: #fbbd08; }
.ui.inverted.yellow.menu .item:before { background-color: rgba(34, 36, 38, 0.1); }
.ui.inverted.yellow.menu .active.item { background-color: rgba(0, 0, 0, 0.1) !important; }
.ui.inverted.menu .olive.active.item, .ui.inverted.olive.menu { background-color: #b5cc18; }
.ui.inverted.olive.menu .item:before { background-color: rgba(34, 36, 38, 0.1); }
.ui.inverted.olive.menu .active.item { background-color: rgba(0, 0, 0, 0.1) !important; }
.ui.inverted.green.menu, .ui.inverted.menu .green.active.item { background-color: #21ba45; }
.ui.inverted.green.menu .item:before { background-color: rgba(34, 36, 38, 0.1); }
.ui.inverted.green.menu .active.item { background-color: rgba(0, 0, 0, 0.1) !important; }
.ui.inverted.menu .teal.active.item, .ui.inverted.teal.menu { background-color: #00b5ad; }
.ui.inverted.teal.menu .item:before { background-color: rgba(34, 36, 38, 0.1); }
.ui.inverted.teal.menu .active.item { background-color: rgba(0, 0, 0, 0.1) !important; }
.ui.inverted.blue.menu, .ui.inverted.menu .blue.active.item { background-color: #2185d0; }
.ui.inverted.blue.menu .item:before { background-color: rgba(34, 36, 38, 0.1); }
.ui.inverted.blue.menu .active.item { background-color: rgba(0, 0, 0, 0.1) !important; }
.ui.inverted.menu .violet.active.item, .ui.inverted.violet.menu { background-color: #6435c9; }
.ui.inverted.violet.menu .item:before { background-color: rgba(34, 36, 38, 0.1); }
.ui.inverted.violet.menu .active.item { background-color: rgba(0, 0, 0, 0.1) !important; }
.ui.inverted.menu .purple.active.item, .ui.inverted.purple.menu { background-color: #a333c8; }
.ui.inverted.purple.menu .item:before { background-color: rgba(34, 36, 38, 0.1); }
.ui.inverted.purple.menu .active.item { background-color: rgba(0, 0, 0, 0.1) !important; }
.ui.inverted.menu .pink.active.item, .ui.inverted.pink.menu { background-color: #e03997; }
.ui.inverted.pink.menu .item:before { background-color: rgba(34, 36, 38, 0.1); }
.ui.inverted.pink.menu .active.item { background-color: rgba(0, 0, 0, 0.1) !important; }
.ui.inverted.brown.menu, .ui.inverted.menu .brown.active.item { background-color: #a5673f; }
.ui.inverted.brown.menu .item:before { background-color: rgba(34, 36, 38, 0.1); }
.ui.inverted.brown.menu .active.item { background-color: rgba(0, 0, 0, 0.1) !important; }
.ui.inverted.grey.menu, .ui.inverted.menu .grey.active.item { background-color: #767676; }
.ui.inverted.grey.menu .item:before { background-color: rgba(34, 36, 38, 0.1); }
.ui.inverted.grey.menu .active.item { background-color: rgba(0, 0, 0, 0.1) !important; }
.ui.fitted.menu .item, .ui.fitted.menu .item .menu .item, .ui.menu .fitted.item { padding: 0; }
.ui.horizontally.fitted.menu .item, .ui.horizontally.fitted.menu .item .menu .item, .ui.menu .horizontally.fitted.item { padding-top: .875em; padding-bottom: .875em; }
.ui.menu .vertically.fitted.item, .ui.vertically.fitted.menu .item, .ui.vertically.fitted.menu .item .menu .item { padding-left: 1.125em; padding-right: 1.125em; }
.ui.borderless.menu .item .menu .item:before, .ui.borderless.menu .item:before, .ui.menu .borderless.item:before { background: 0 0 !important; }
.ui.compact.menu { display: -webkit-inline-box; display: -ms-inline-flexbox; display: inline-flex; margin: 0; vertical-align: middle; }
.ui.compact.vertical.menu { display: inline-block; }
.ui.compact.menu .item:last-child { border-radius: 0 .25rem .25rem 0; }
.ui.compact.menu .item:last-child:before { display: none; }
.ui.compact.vertical.menu { width: auto !important; }
.ui.compact.vertical.menu .item:last-child::before { display: block; }
.ui.menu.fluid, .ui.vertical.menu.fluid { width: 100% !important; }
.ui.item.menu, .ui.item.menu .item { width: 100%; padding-left: 0 !important; padding-right: 0 !important; margin-left: 0 !important; margin-right: 0 !important; text-align: center; -webkit-box-pack: center; -ms-flex-pack: center; justify-content: center; }
.ui.attached.item.menu { margin: 0 -1px !important; }
.ui.item.menu .item:last-child:before { display: none; }
.ui.menu.two.item .item { width: 50%; }
.ui.menu.three.item .item { width: 33.333%; }
.ui.menu.four.item .item { width: 25%; }
.ui.menu.five.item .item { width: 20%; }
.ui.menu.six.item .item { width: 16.666%; }
.ui.menu.seven.item .item { width: 14.285%; }
.ui.menu.eight.item .item { width: 12.5%; }
.ui.menu.nine.item .item { width: 11.11%; }
.ui.menu.ten.item .item { width: 10%; }
.ui.menu.eleven.item .item { width: 9.09%; }
.ui.menu.twelve.item .item { width: 8.333%; }
.ui.menu.fixed { position: fixed; z-index: 101; margin: 0; width: 100%; }
.ui.menu.fixed, .ui.menu.fixed .item:first-child, .ui.menu.fixed .item:last-child { border-radius: 0 !important; }
.ui.fixed.menu, .ui[class*="top fixed"].menu { top: 0; left: 0; right: auto; bottom: auto; }
.ui[class*="top fixed"].menu { border-top: none; border-left: none; border-right: none; }
.ui[class*="right fixed"].menu { border-top: none; border-bottom: none; border-right: none; top: 0; right: 0; left: auto; bottom: auto; width: auto; height: 100%; }
.ui[class*="bottom fixed"].menu { border-bottom: none; border-left: none; border-right: none; bottom: 0; left: 0; top: auto; right: auto; }
.ui[class*="left fixed"].menu { border-top: none; border-bottom: none; border-left: none; top: 0; left: 0; right: auto; bottom: auto; width: auto; height: 100%; }
.ui.fixed.menu + .ui.grid { padding-top: 2.75rem; }
.ui.pointing.menu .item:after { visibility: hidden; position: absolute; content: ''; top: 100%; left: 50%; -webkit-transform: translateX(-50%) translateY(-50%) rotate(45deg); transform: translateX(-50%) translateY(-50%) rotate(45deg); background: 0 0; margin: .5px 0 0; width: .5em; height: .5em; border: none; border-bottom: 1px solid #d4d4d5; border-right: 1px solid #d4d4d5; z-index: 2; -webkit-transition: background .1s ease; transition: background .1s ease; }
.ui.vertical.pointing.menu .item:after { position: absolute; top: 50%; right: 0; bottom: auto; left: auto; -webkit-transform: translateX(50%) translateY(-50%) rotate(45deg); transform: translateX(50%) translateY(-50%) rotate(45deg); margin: 0 -.5px 0 0; border: none; border-top: 1px solid #d4d4d5; border-right: 1px solid #d4d4d5; }
.ui.pointing.menu .active.item:after { visibility: visible; }
.ui.pointing.menu .active.dropdown.item:after { visibility: hidden; }
.ui.pointing.menu .active.item .menu .active.item:after, .ui.pointing.menu .dropdown.active.item:after { display: none; }
.ui.pointing.menu .active.item:hover:after { background-color: #f2f2f2; }
.ui.pointing.menu .active.item:after { background-color: #f2f2f2; }
.ui.pointing.menu .active.item:hover:after { background-color: #f2f2f2; }
.ui.vertical.pointing.menu .active.item:hover:after { background-color: #f2f2f2; }
.ui.vertical.pointing.menu .active.item:after { background-color: #f2f2f2; }
.ui.vertical.pointing.menu .menu .active.item:after { background-color: #fff; }
.ui.attached.menu { top: 0; bottom: 0; border-radius: 0; margin: 0 -1px; width: calc(100% - (-1px * 2)); max-width: calc(100% - (-1px * 2)); -webkit-box-shadow: none; box-shadow: none; }
.ui.attached + .ui.attached.menu:not(.top) { border-top: none; }
.ui[class*="top attached"].menu { bottom: 0; margin-bottom: 0; top: 0; margin-top: 1rem; border-radius: .25rem .25rem 0 0; }
.ui.menu[class*="top attached"]:first-child { margin-top: 0; }
.ui[class*="bottom attached"].menu { bottom: 0; margin-top: 0; top: 0; margin-bottom: 1rem; -webkit-box-shadow: 0 1px 2px 0 rgba(34, 36, 38, 0.15), none; box-shadow: 0 1px 2px 0 rgba(34, 36, 38, 0.15), none; border-radius: 0 0 .25rem .25rem; }
.ui[class*="bottom attached"].menu:last-child { margin-bottom: 0; }
.ui.top.attached.menu > .item:first-child { border-radius: .25rem 0 0 0; }
.ui.bottom.attached.menu > .item:first-child { border-radius: 0 0 0 .25rem; }
.ui.attached.menu:not(.tabular) { border: 1px solid #d4d4d5; }
.ui.attached.inverted.menu { border: none; }
.ui.attached.tabular.menu { margin-left: 0; margin-right: 0; width: 100%; }
.ui.mini.menu { font-size: .6875rem; }
.ui.mini.vertical.menu { width: 9rem; }
.ui.tiny.menu { font-size: .75rem; }
.ui.tiny.vertical.menu { width: 11rem; }
.ui.small.menu { font-size: .8125rem; }
.ui.small.vertical.menu { width: 13rem; }
.ui.menu { font-size: 1rem; }
.ui.vertical.menu { width: 15rem; }
.ui.large.menu { font-size: .9375rem; }
.ui.large.vertical.menu { width: 18rem; }
.ui.huge.menu { font-size: 1.0625rem; }
.ui.huge.vertical.menu { width: 22rem; }
.ui.big.menu { font-size: 1rem; }
.ui.big.vertical.menu { width: 20rem; }
.ui.massive.menu { font-size: 1.125rem; }
.ui.massive.vertical.menu { width: 25rem; }
.ui.message { position: relative; min-height: 1em; margin: 1em 0; background: #f8f8f9; padding: 1em 1.5em; line-height: 1.4285em; color: rgba(0, 0, 0, 0.87); -webkit-transition: opacity .1s ease,color .1s ease,background .1s ease,-webkit-box-shadow .1s ease; transition: opacity .1s ease,color .1s ease,background .1s ease,-webkit-box-shadow .1s ease; transition: opacity .1s ease,color .1s ease,background .1s ease,box-shadow .1s ease; transition: opacity .1s ease,color .1s ease,background .1s ease,box-shadow .1s ease,-webkit-box-shadow .1s ease; border-radius: .25rem; -webkit-box-shadow: 0 0 0 1px rgba(34, 36, 38, 0.22) inset, 0 0 0 0 transparent; box-shadow: 0 0 0 1px rgba(34, 36, 38, 0.22) inset, 0 0 0 0 transparent; }
.ui.message:first-child { margin-top: 0; }
.ui.message:last-child { margin-bottom: 0; }
.ui.message .header { display: block; font-family: Raleway,sans-serif; font-weight: 700; margin: -.14285714em 0 0 0; }
.ui.message .header:not(.ui) { font-size: 1.125em; }
.ui.message p { opacity: .85; margin: .75em 0; }
.ui.message p:first-child { margin-top: 0; }
.ui.message p:last-child { margin-bottom: 0; }
.ui.message .header + p { margin-top: .25em; }
.ui.message .list:not(.ui) { text-align: left; padding: 0; opacity: .85; list-style-position: inside; margin: .5em 0 0; }
.ui.message .list:not(.ui):first-child { margin-top: 0; }
.ui.message .list:not(.ui):last-child { margin-bottom: 0; }
.ui.message .list:not(.ui) li { position: relative; list-style-type: none; margin: 0 0 .3em 1em; padding: 0; }
.ui.message .list:not(.ui) li:before { position: absolute; content: '•'; left: -1em; height: 100%; vertical-align: baseline; }
.ui.message .list:not(.ui) li:last-child { margin-bottom: 0; }
.ui.message > .icon { margin-right: .6em; }
.ui.message > .close.icon { cursor: pointer; position: absolute; margin: 0; top: .78575em; right: .5em; opacity: .7; -webkit-transition: opacity .1s ease; transition: opacity .1s ease; }
.ui.message > .close.icon:hover { opacity: 1; }
.ui.message > :first-child { margin-top: 0; }
.ui.message > :last-child { margin-bottom: 0; }
.ui.dropdown .menu > .message { margin: 0 -1px; }
.ui.visible.visible.visible.visible.message { display: block; }
.ui.icon.visible.visible.visible.visible.message { display: -webkit-box; display: -ms-flexbox; display: flex; }
.ui.hidden.hidden.hidden.hidden.message { display: none; }
.ui.compact.message { display: inline-block; }
.ui.compact.icon.message { display: -webkit-inline-box; display: -ms-inline-flexbox; display: inline-flex; }
.ui.attached.message { margin-bottom: -1px; border-radius: .25rem .25rem 0 0; -webkit-box-shadow: 0 0 0 1px rgba(34, 36, 38, 0.15) inset; box-shadow: 0 0 0 1px rgba(34, 36, 38, 0.15) inset; margin-left: -1px; margin-right: -1px; }
.ui.attached + .ui.attached.message:not(.top):not(.bottom) { margin-top: -1px; border-radius: 0; }
.ui.bottom.attached.message { margin-top: -1px; border-radius: 0 0 .25rem .25rem; -webkit-box-shadow: 0 0 0 1px rgba(34, 36, 38, 0.15) inset, 0 1px 2px 0 rgba(34, 36, 38, 0.15); box-shadow: 0 0 0 1px rgba(34, 36, 38, 0.15) inset, 0 1px 2px 0 rgba(34, 36, 38, 0.15); }
.ui.bottom.attached.message:not(:last-child) { margin-bottom: 1em; }
.ui.attached.icon.message { width: auto; }
.ui.icon.message { display: -webkit-box; display: -ms-flexbox; display: flex; width: 100%; -webkit-box-align: center; -ms-flex-align: center; align-items: center; }
.ui.icon.message > .icon:not(.close) { display: block; -webkit-box-flex: 0; -ms-flex: 0 0 auto; flex: 0 0 auto; width: auto; line-height: 1; vertical-align: middle; font-size: 3em; opacity: .8; }
.ui.icon.message > .content { display: block; -webkit-box-flex: 1; -ms-flex: 1 1 auto; flex: 1 1 auto; vertical-align: middle; }
.ui.icon.message .icon:not(.close) + .content { padding-left: 0; }
.ui.icon.message .circular.icon { width: 1em; }
.ui.floating.message { -webkit-box-shadow: 0 0 0 1px rgba(34, 36, 38, 0.22) inset, 0 2px 4px 0 rgba(34, 36, 38, 0.12), 0 2px 10px 0 rgba(34, 36, 38, 0.15); box-shadow: 0 0 0 1px rgba(34, 36, 38, 0.22) inset, 0 2px 4px 0 rgba(34, 36, 38, 0.12), 0 2px 10px 0 rgba(34, 36, 38, 0.15); }
.ui.black.message { background-color: #1b1c1d; color: rgba(255, 255, 255, 0.9); }
.ui.positive.message { background-color: #fcfff5; color: #2c662d; }
.ui.attached.positive.message, .ui.positive.message { -webkit-box-shadow: 0 0 0 1px #a3c293 inset,0 0 0 0 transparent; box-shadow: 0 0 0 1px #a3c293 inset,0 0 0 0 transparent; }
.ui.positive.message .header { color: #1a531b; }
.ui.negative.message { background-color: #fff6f6; color: #9f3a38; }
.ui.attached.negative.message, .ui.negative.message { -webkit-box-shadow: 0 0 0 1px #e0b4b4 inset,0 0 0 0 transparent; box-shadow: 0 0 0 1px #e0b4b4 inset,0 0 0 0 transparent; }
.ui.negative.message .header { color: #912d2b; }
.ui.info.message { background-color: #f8ffff; color: #276f86; }
.ui.attached.info.message, .ui.info.message { -webkit-box-shadow: 0 0 0 1px #a9d5de inset,0 0 0 0 transparent; box-shadow: 0 0 0 1px #a9d5de inset,0 0 0 0 transparent; }
.ui.info.message .header { color: #0e566c; }
.ui.warning.message { background-color: #fffaf3; color: #d67e08; }
.ui.attached.warning.message, .ui.warning.message { -webkit-box-shadow: 0 0 0 1px #d6b46e inset,0 0 0 0 transparent; box-shadow: 0 0 0 1px #d6b46e inset,0 0 0 0 transparent; }
.ui.warning.message .header { color: #794b02; }
.ui.error.message { background-color: #fff6f6; color: #9f3a38; }
.ui.attached.error.message, .ui.error.message { -webkit-box-shadow: 0 0 0 1px #e0b4b4 inset,0 0 0 0 transparent; box-shadow: 0 0 0 1px #e0b4b4 inset,0 0 0 0 transparent; }
.ui.error.message .header { color: #912d2b; }
.ui.success.message { background-color: #fcfff5; color: #2c662d; }
.ui.attached.success.message, .ui.success.message { -webkit-box-shadow: 0 0 0 1px #a3c293 inset,0 0 0 0 transparent; box-shadow: 0 0 0 1px #a3c293 inset,0 0 0 0 transparent; }
.ui.success.message .header { color: #1a531b; }
.ui.black.message, .ui.inverted.message { background-color: #1b1c1d; color: rgba(255, 255, 255, 0.9); }
.ui.red.message { background-color: #ffe8e6; color: #db2828; -webkit-box-shadow: 0 0 0 1px #db2828 inset,0 0 0 0 transparent; box-shadow: 0 0 0 1px #db2828 inset,0 0 0 0 transparent; }
.ui.red.message .header { color: #c82121; }
.ui.orange.message { background-color: #ffedde; color: #f2711c; -webkit-box-shadow: 0 0 0 1px #f2711c inset,0 0 0 0 transparent; box-shadow: 0 0 0 1px #f2711c inset,0 0 0 0 transparent; }
.ui.orange.message .header { color: #e7640d; }
.ui.yellow.message { background-color: #fff8db; color: #b58105; -webkit-box-shadow: 0 0 0 1px #b58105 inset,0 0 0 0 transparent; box-shadow: 0 0 0 1px #b58105 inset,0 0 0 0 transparent; }
.ui.yellow.message .header { color: #9c6f04; }
.ui.olive.message { background-color: #fbfdef; color: #8abc1e; -webkit-box-shadow: 0 0 0 1px #8abc1e inset,0 0 0 0 transparent; box-shadow: 0 0 0 1px #8abc1e inset,0 0 0 0 transparent; }
.ui.olive.message .header { color: #7aa61a; }
.ui.green.message { background-color: #e5f9e7; color: #1ebc30; -webkit-box-shadow: 0 0 0 1px #1ebc30 inset,0 0 0 0 transparent; box-shadow: 0 0 0 1px #1ebc30 inset,0 0 0 0 transparent; }
.ui.green.message .header { color: #1aa62a; }
.ui.teal.message { background-color: #e1f7f7; color: #10a3a3; -webkit-box-shadow: 0 0 0 1px #10a3a3 inset,0 0 0 0 transparent; box-shadow: 0 0 0 1px #10a3a3 inset,0 0 0 0 transparent; }
.ui.teal.message .header { color: #0e8c8c; }
.ui.blue.message { background-color: #dff0ff; color: #2185d0; -webkit-box-shadow: 0 0 0 1px #2185d0 inset,0 0 0 0 transparent; box-shadow: 0 0 0 1px #2185d0 inset,0 0 0 0 transparent; }
.ui.blue.message .header { color: #1e77ba; }
.ui.violet.message { background-color: #eae7ff; color: #6435c9; -webkit-box-shadow: 0 0 0 1px #6435c9 inset,0 0 0 0 transparent; box-shadow: 0 0 0 1px #6435c9 inset,0 0 0 0 transparent; }
.ui.violet.message .header { color: #5a30b5; }
.ui.purple.message { background-color: #f6e7ff; color: #a333c8; -webkit-box-shadow: 0 0 0 1px #a333c8 inset,0 0 0 0 transparent; box-shadow: 0 0 0 1px #a333c8 inset,0 0 0 0 transparent; }
.ui.purple.message .header { color: #922eb4; }
.ui.pink.message { background-color: #ffe3fb; color: #e03997; -webkit-box-shadow: 0 0 0 1px #e03997 inset,0 0 0 0 transparent; box-shadow: 0 0 0 1px #e03997 inset,0 0 0 0 transparent; }
.ui.pink.message .header { color: #dd238b; }
.ui.brown.message { background-color: #f1e2d3; color: #a5673f; -webkit-box-shadow: 0 0 0 1px #a5673f inset,0 0 0 0 transparent; box-shadow: 0 0 0 1px #a5673f inset,0 0 0 0 transparent; }
.ui.brown.message .header { color: #935b38; }
.ui.mini.message { font-size: .625em; }
.ui.tiny.message { font-size: .75em; }
.ui.small.message { font-size: .875em; }
.ui.message { font-size: 1em; }
.ui.large.message { font-size: 1.125em; }
.ui.big.message { font-size: 1.25em; }
.ui.huge.message { font-size: 1.5em; }
.ui.massive.message { font-size: 2em; }
.ui.modal { position: absolute; display: none; z-index: 1001; text-align: left; background: #fff; border: none; -webkit-box-shadow: 1px 3px 3px 0 rgba(0, 0, 0, 0.2), 1px 3px 15px 2px rgba(0, 0, 0, 0.2); box-shadow: 1px 3px 3px 0 rgba(0, 0, 0, 0.2), 1px 3px 15px 2px rgba(0, 0, 0, 0.2); -webkit-transform-origin: 50% 25%; transform-origin: 50% 25%; -webkit-box-flex: 0; -ms-flex: 0 0 auto; flex: 0 0 auto; border-radius: .25rem; -webkit-user-select: text; -moz-user-select: text; -ms-user-select: text; user-select: text; will-change: top,left,margin,transform,opacity; }
.ui.modal > .icon:first-child + *, .ui.modal > :first-child:not(.icon) { border-top-left-radius: .25rem; border-top-right-radius: .25rem; }
.ui.modal > :last-child { border-bottom-left-radius: .25rem; border-bottom-right-radius: .25rem; }
.ui.modal > .close { cursor: pointer; position: absolute; top: -2.5rem; right: -2.5rem; z-index: 1; opacity: .8; font-size: 1.25em; color: #fff; width: 2.25rem; height: 2.25rem; padding: .625rem 0 0 0; }
.ui.modal > .close:hover { opacity: 1; }
.ui.modal > .header { display: block; font-family: Raleway,sans-serif; background: #fff; margin: 0; padding: 1.25rem 1.5rem; -webkit-box-shadow: none; box-shadow: none; color: rgba(0, 0, 0, 0.85); border-bottom: 1px solid rgba(34, 36, 38, 0.15); }
.ui.modal > .header:not(.ui) { font-size: 1.5rem; line-height: 1.28571429em; font-weight: 700; }
.ui.modal > .content { display: block; width: 100%; font-size: 1em; line-height: 1.4; padding: 1.5rem; background: #fff; }
.ui.modal > .image.content { display: -webkit-box; display: -ms-flexbox; display: flex; -webkit-box-orient: horizontal; -webkit-box-direction: normal; -ms-flex-direction: row; flex-direction: row; }
.ui.modal > .content > .image { display: block; -webkit-box-flex: 0; -ms-flex: 0 1 auto; flex: 0 1 auto; width: ''; -ms-flex-item-align: top; align-self: top; }
.ui.modal > [class*="top aligned"] { -ms-flex-item-align: top; align-self: top; }
.ui.modal > [class*="middle aligned"] { -ms-flex-item-align: middle; align-self: middle; }
.ui.modal > [class*=stretched] { -ms-flex-item-align: stretch; align-self: stretch; }
.ui.modal > .content > .description { display: block; -webkit-box-flex: 1; -ms-flex: 1 0 auto; flex: 1 0 auto; min-width: 0; -ms-flex-item-align: top; align-self: top; }
.ui.modal > .content > .icon + .description, .ui.modal > .content > .image + .description { -webkit-box-flex: 0; -ms-flex: 0 1 auto; flex: 0 1 auto; min-width: ''; width: auto; padding-left: 2em; }
.ui.modal > .content > .image > i.icon { margin: 0; opacity: 1; width: auto; line-height: 1; font-size: 8rem; }
.ui.modal > .actions { background: #f9fafb; padding: 1rem 1rem; border-top: 1px solid rgba(34, 36, 38, 0.15); text-align: right; }
.ui.modal .actions > .button { margin-left: .75em; }
@media only screen and (max-width: 767px) { .ui.modal { width: 95%; margin: 0; } }
@media only screen and (min-width: 768px) { .ui.modal { width: 88%; margin: 0; } }
@media only screen and (min-width: 992px) { .ui.modal { width: 850px; margin: 0; } }
@media only screen and (min-width: 1200px) { .ui.modal { width: 900px; margin: 0; } }
@media only screen and (min-width: 1920px) { .ui.modal { width: 950px; margin: 0; } }
@media only screen and (max-width: 991px) { .ui.modal > .header { padding-right: 2.25rem; }
  .ui.modal > .close { top: 1.0535rem; right: 1rem; color: rgba(0, 0, 0, 0.87); } }
@media only screen and (max-width: 767px) { .ui.modal > .header { padding: 0.75rem 1rem !important; padding-right: 2.25rem !important; }
  .ui.modal > .content { display: block; padding: 1rem !important; }
  .ui.modal > .close { top: 0.5rem !important; right: 0.5rem !important; }
  .ui.modal .image.content { -webkit-box-orient: vertical; -webkit-box-direction: normal; -ms-flex-direction: column; flex-direction: column; }
  .ui.modal .content > .image { display: block; max-width: 100%; margin: 0 auto !important; text-align: center; padding: 0 0 1rem !important; }
  .ui.modal > .content > .image > i.icon { font-size: 5rem; text-align: center; }
  .ui.modal .content > .description { display: block; width: 100% !important; margin: 0 !important; padding: 1rem 0 !important; -webkit-box-shadow: none; box-shadow: none; }
  .ui.modal > .actions { padding: 1rem 1rem 0 !important; }
  .ui.modal .actions > .button, .ui.modal .actions > .buttons { margin-bottom: 1rem; } }
.ui.inverted.dimmer > .ui.modal { -webkit-box-shadow: 1px 3px 10px 2px rgba(0, 0, 0, 0.2); box-shadow: 1px 3px 10px 2px rgba(0, 0, 0, 0.2); }
.ui.basic.modal { background-color: transparent; border: none; border-radius: 0; -webkit-box-shadow: none !important; box-shadow: none !important; color: #fff; }
.ui.basic.modal > .actions, .ui.basic.modal > .content, .ui.basic.modal > .header { background-color: transparent; }
.ui.basic.modal > .header { color: #fff; }
.ui.basic.modal > .close { top: 1rem; right: 1.5rem; }
.ui.inverted.dimmer > .basic.modal { color: rgba(0, 0, 0, 0.87); }
.ui.inverted.dimmer > .ui.basic.modal > .header { color: rgba(0, 0, 0, 0.85); }
.ui.legacy.modal, .ui.legacy.page.dimmer > .ui.modal { top: 50%; left: 50%; }
.ui.legacy.page.dimmer > .ui.scrolling.modal, .ui.page.dimmer > .ui.scrolling.legacy.modal, .ui.top.aligned.dimmer > .ui.legacy.modal, .ui.top.aligned.legacy.page.dimmer > .ui.modal { top: auto; }
@media only screen and (max-width: 991px) { .ui.basic.modal > .close { color: #fff; } }
.ui.loading.modal { display: block; visibility: hidden; z-index: -1; }
.ui.active.modal { display: block; }
.modals.dimmer[class*="top aligned"] .modal { margin: 5vh auto; }
@media only screen and (max-width: 767px) { .modals.dimmer[class*="top aligned"] .modal { margin: 1rem auto; } }
.legacy.modals.dimmer[class*="top aligned"] { padding-top: 5vh; }
@media only screen and (max-width: 767px) { .legacy.modals.dimmer[class*="top aligned"] { padding-top: 1rem; } }
.scrolling.dimmable.dimmed { overflow: hidden; }
.scrolling.dimmable > .dimmer { -webkit-box-pack: start; -ms-flex-pack: start; justify-content: flex-start; }
.scrolling.dimmable.dimmed > .dimmer { overflow: auto; -webkit-overflow-scrolling: touch; }
.scrolling.dimmable > .dimmer { position: fixed; }
.modals.dimmer .ui.scrolling.modal { margin: 1rem auto; }
.scrolling.undetached.dimmable.dimmed { overflow: auto; -webkit-overflow-scrolling: touch; }
.scrolling.undetached.dimmable.dimmed > .dimmer { overflow: hidden; }
.scrolling.undetached.dimmable .ui.scrolling.modal { position: absolute; left: 50%; margin-top: 1rem !important; }
.ui.modal .scrolling.content { max-height: calc(80vh - 10em); overflow: auto; }
.ui.fullscreen.modal { width: 95% !important; margin: 1em auto; }
.ui.fullscreen.modal > .header { padding-right: 2.25rem; }
.ui.fullscreen.modal > .close { top: 1.0535rem; right: 1rem; color: rgba(0, 0, 0, 0.87); }
.ui.modal { font-size: 1rem; }
.ui.mini.modal > .header:not(.ui) { font-size: 1.3em; }
@media only screen and (max-width: 767px) { .ui.mini.modal { width: 95%; margin: 0; } }
@media only screen and (min-width: 768px) { .ui.mini.modal { width: 35.2%; margin: 0; } }
@media only screen and (min-width: 992px) { .ui.mini.modal { width: 340px; margin: 0; } }
@media only screen and (min-width: 1200px) { .ui.mini.modal { width: 360px; margin: 0; } }
@media only screen and (min-width: 1920px) { .ui.mini.modal { width: 380px; margin: 0; } }
.ui.small.modal > .header:not(.ui) { font-size: 1.3em; }
@media only screen and (max-width: 767px) { .ui.tiny.modal { width: 95%; margin: 0; } }
@media only screen and (min-width: 768px) { .ui.tiny.modal { width: 52.8%; margin: 0; } }
@media only screen and (min-width: 992px) { .ui.tiny.modal { width: 510px; margin: 0; } }
@media only screen and (min-width: 1200px) { .ui.tiny.modal { width: 540px; margin: 0; } }
@media only screen and (min-width: 1920px) { .ui.tiny.modal { width: 570px; margin: 0; } }
.ui.small.modal > .header:not(.ui) { font-size: 1.3em; }
@media only screen and (max-width: 767px) { .ui.small.modal { width: 95%; margin: 0; } }
@media only screen and (min-width: 768px) { .ui.small.modal { width: 70.4%; margin: 0; } }
@media only screen and (min-width: 992px) { .ui.small.modal { width: 680px; margin: 0; } }
@media only screen and (min-width: 1200px) { .ui.small.modal { width: 720px; margin: 0; } }
@media only screen and (min-width: 1920px) { .ui.small.modal { width: 760px; margin: 0; } }
.ui.large.modal > .header { font-size: 1.6em; }
@media only screen and (max-width: 767px) { .ui.large.modal { width: 95%; margin: 0; } }
@media only screen and (min-width: 768px) { .ui.large.modal { width: 88%; margin: 0; } }
@media only screen and (min-width: 992px) { .ui.large.modal { width: 1020px; margin: 0; } }
@media only screen and (min-width: 1200px) { .ui.large.modal { width: 1080px; margin: 0; } }
@media only screen and (min-width: 1920px) { .ui.large.modal { width: 1140px; margin: 0; } }
.ui.rail { position: absolute; top: 0; width: 300px; height: 100%; }
.ui.left.rail { left: auto; right: 100%; padding: 0 2rem 0 0; margin: 0 2rem 0 0; }
.ui.right.rail { left: 100%; right: auto; padding: 0 0 0 2rem; margin: 0 0 0 2rem; }
.ui.left.internal.rail { left: 0; right: auto; padding: 0 0 0 2rem; margin: 0 0 0 2rem; }
.ui.right.internal.rail { left: auto; right: 0; padding: 0 2rem 0 0; margin: 0 2rem 0 0; }
.ui.dividing.rail { width: 302.5px; }
.ui.left.dividing.rail { padding: 0 2.5rem 0 0; margin: 0 2.5rem 0 0; border-right: 1px solid rgba(34, 36, 38, 0.15); }
.ui.right.dividing.rail { border-left: 1px solid rgba(34, 36, 38, 0.15); padding: 0 0 0 2.5rem; margin: 0 0 0 2.5rem; }
.ui.close.rail { width: calc(300px + 1em); }
.ui.close.left.rail { padding: 0 1em 0 0; margin: 0 1em 0 0; }
.ui.close.right.rail { padding: 0 0 0 1em; margin: 0 0 0 1em; }
.ui.very.close.rail { width: calc(300px + .5em); }
.ui.very.close.left.rail { padding: 0 .5em 0 0; margin: 0 .5em 0 0; }
.ui.very.close.right.rail { padding: 0 0 0 .5em; margin: 0 0 0 .5em; }
.ui.attached.left.rail, .ui.attached.right.rail { padding: 0; margin: 0; }
.ui.mini.rail { font-size: .625rem; }
.ui.tiny.rail { font-size: .75rem; }
.ui.small.rail { font-size: .875rem; }
.ui.rail { font-size: 1rem; }
.ui.large.rail { font-size: 1.125rem; }
.ui.big.rail { font-size: 1.25rem; }
.ui.huge.rail { font-size: 1.5rem; }
.ui.massive.rail { font-size: 2rem; }
.ui.search { position: relative; }
.ui.search > .prompt { margin: 0; outline: 0; -webkit-appearance: none; -webkit-tap-highlight-color: rgba(255, 255, 255, 0); text-shadow: none; font-style: normal; font-weight: 400; line-height: 1.21428571em; padding: .58035714em .875em; font-size: 1em; background: #fff; border: 1px solid rgba(34, 36, 38, 0.15); color: rgba(0, 0, 0, 0.87); -webkit-box-shadow: 0 0 0 0 transparent inset; box-shadow: 0 0 0 0 transparent inset; -webkit-transition: background-color .1s ease,color .1s ease,border-color .1s ease,-webkit-box-shadow .1s ease; transition: background-color .1s ease,color .1s ease,border-color .1s ease,-webkit-box-shadow .1s ease; transition: background-color .1s ease,color .1s ease,box-shadow .1s ease,border-color .1s ease; transition: background-color .1s ease,color .1s ease,box-shadow .1s ease,border-color .1s ease,-webkit-box-shadow .1s ease; }
.ui.search .prompt { border-radius: 500rem; }
.ui.search .prompt ~ .search.icon { cursor: pointer; }
.ui.search > .results { display: none; position: absolute; top: 100%; left: 0; -webkit-transform-origin: center top; transform-origin: center top; white-space: normal; text-align: left; text-transform: none; background: #fff; margin-top: .5em; width: 18em; border-radius: .25rem; -webkit-box-shadow: 0 2px 4px 0 rgba(34, 36, 38, 0.12), 0 2px 10px 0 rgba(34, 36, 38, 0.15); box-shadow: 0 2px 4px 0 rgba(34, 36, 38, 0.12), 0 2px 10px 0 rgba(34, 36, 38, 0.15); border: 1px solid #d4d4d5; z-index: 998; }
.ui.search > .results > :first-child { border-radius: .25rem .25rem 0 0; }
.ui.search > .results > :last-child { border-radius: 0 0 .25rem .25rem; }
.ui.search > .results .result { cursor: pointer; display: block; overflow: hidden; font-size: 1em; padding: .75em 1.125em; color: rgba(0, 0, 0, 0.87); line-height: 1.33; border-bottom: 1px solid rgba(34, 36, 38, 0.1); }
.ui.search > .results .result:last-child { border-bottom: none !important; }
.ui.search > .results .result .image { float: right; overflow: hidden; background: 0 0; width: 5em; height: 3em; border-radius: .25em; }
.ui.search > .results .result .image img { display: block; width: auto; height: 100%; }
.ui.search > .results .result .image + .content { margin: 0 6em 0 0; }
.ui.search > .results .result .title { margin: -.14285714em 0 0; font-family: Raleway,sans-serif; font-weight: 700; font-size: 1em; color: rgba(0, 0, 0, 0.85); }
.ui.search > .results .result .description { margin-top: 0; font-size: .875em; color: rgba(0, 0, 0, 0.4); }
.ui.search > .results .result .price { float: right; color: #21ba45; }
.ui.search > .results > .message { padding: 1em 1em; }
.ui.search > .results > .message .header { font-family: Raleway,sans-serif; font-size: 1rem; font-weight: 700; color: rgba(0, 0, 0, 0.87); }
.ui.search > .results > .message .description { margin-top: .25rem; font-size: 1em; color: rgba(0, 0, 0, 0.87); }
.ui.search > .results > .action { display: block; border-top: none; background: #f3f4f5; padding: .875em 1em; color: rgba(0, 0, 0, 0.87); font-weight: 700; text-align: center; }
.ui.search > .prompt:focus { border-color: rgba(34, 36, 38, 0.35); background: #fff; color: rgba(0, 0, 0, 0.95); }
.ui.loading.search .input > i.icon:before { position: absolute; content: ''; top: 50%; left: 50%; margin: -.625em 0 0 -.625em; width: 1.25em; height: 1.25em; border-radius: 500rem; border: 0.2em solid rgba(0, 0, 0, 0.1); }
.ui.loading.search .input > i.icon:after { position: absolute; content: ''; top: 50%; left: 50%; margin: -.625em 0 0 -.625em; width: 1.25em; height: 1.25em; -webkit-animation: button-spin .6s linear; animation: button-spin .6s linear; -webkit-animation-iteration-count: infinite; animation-iteration-count: infinite; border-radius: 500rem; border-color: #767676 transparent transparent; border-style: solid; border-width: .2em; -webkit-box-shadow: 0 0 0 1px transparent; box-shadow: 0 0 0 1px transparent; }
.ui.category.search > .results .category .result:hover, .ui.search > .results .result:hover { background: #f9fafb; }
.ui.search .action:hover { background: #e0e0e0; }
.ui.category.search > .results .category.active { background: #f3f4f5; }
.ui.category.search > .results .category.active > .name { color: rgba(0, 0, 0, 0.87); }
.ui.category.search > .results .category .result.active, .ui.search > .results .result.active { position: relative; border-left-color: rgba(34, 36, 38, 0.1); background: #f3f4f5; -webkit-box-shadow: none; box-shadow: none; }
.ui.search > .results .result.active .title { color: rgba(0, 0, 0, 0.85); }
.ui.search > .results .result.active .description { color: rgba(0, 0, 0, 0.85); }
.ui.disabled.search { cursor: default; pointer-events: none; opacity: .45; }
.ui.search.selection .prompt { border-radius: .25rem; }
.ui.search.selection > .icon.input > .remove.icon { pointer-events: none; position: absolute; left: auto; opacity: 0; color: ''; top: 0; right: 0; -webkit-transition: color .1s ease,opacity .1s ease; transition: color .1s ease,opacity .1s ease; }
.ui.search.selection > .icon.input > .active.remove.icon { cursor: pointer; opacity: .8; pointer-events: auto; }
.ui.search.selection > .icon.input:not([class*="left icon"]) > .icon ~ .remove.icon { right: 1.85714em; }
.ui.search.selection > .icon.input > .remove.icon:hover { opacity: 1; color: #db2828; }
.ui.category.search .results { width: 28em; }
.ui.category.search .results.animating, .ui.category.search .results.visible { display: table; }
.ui.category.search > .results .category { display: table-row; background: #f3f4f5; -webkit-box-shadow: none; box-shadow: none; -webkit-transition: background .1s ease,border-color .1s ease; transition: background .1s ease,border-color .1s ease; }
.ui.category.search > .results .category:last-child { border-bottom: none; }
.ui.category.search > .results .category:first-child .name + .result { border-radius: 0 .25rem 0 0; }
.ui.category.search > .results .category:last-child .result:last-child { border-radius: 0 0 .25rem 0; }
.ui.category.search > .results .category > .name { display: table-cell; text-overflow: ellipsis; width: 100px; white-space: nowrap; background: 0 0; font-family: Montserrat,sans-serif; font-size: 1em; padding: .4em 1em; font-weight: 700; color: rgba(0, 0, 0, 0.4); border-bottom: 1px solid rgba(34, 36, 38, 0.1); }
.ui.category.search > .results .category .results { display: table-cell; background: #fff; border-left: 1px solid rgba(34, 36, 38, 0.15); border-bottom: 1px solid rgba(34, 36, 38, 0.1); }
.ui.category.search > .results .category .result { border-bottom: 1px solid rgba(34, 36, 38, 0.1); -webkit-transition: background .1s ease,border-color .1s ease; transition: background .1s ease,border-color .1s ease; padding: .75em 1.125em; }
.ui[class*="left aligned"].search > .results { right: auto; left: 0; }
.ui[class*="right aligned"].search > .results { right: 0; left: auto; }
.ui.fluid.search .results { width: 100%; }
.ui.mini.search { font-size: .625em; }
.ui.small.search { font-size: .875em; }
.ui.search { font-size: 1em; }
.ui.large.search { font-size: 1.125em; }
.ui.big.search { font-size: 1.25em; }
.ui.huge.search { font-size: 1.5em; }
.ui.massive.search { font-size: 2em; }
@media only screen and (max-width: 767px) { .ui.search .results { max-width: calc(100vw - 2rem); } }
.ui.segment { position: relative; background: #fff; -webkit-box-shadow: 0 1px 2px 0 rgba(34, 36, 38, 0.15); box-shadow: 0 1px 2px 0 rgba(34, 36, 38, 0.15); margin: 3rem 0; padding: 3em 2em; border-radius: .25rem; border: 1px solid rgba(34, 36, 38, 0.15); }
.ui.segment:first-child { margin-top: 0; }
.ui.segment:last-child { margin-bottom: 0; }
.ui.vertical.segment { margin: 0; padding-left: 0; padding-right: 0; background: none transparent; border-radius: 0; -webkit-box-shadow: none; box-shadow: none; border: none; border-bottom: 1px solid rgba(34, 36, 38, 0.15); }
.ui.vertical.segment:last-child { border-bottom: none; }
.ui.inverted.segment > .ui.header { color: #fff; }
.ui[class*="bottom attached"].segment > [class*="top attached"].label { border-top-left-radius: 0; border-top-right-radius: 0; }
.ui[class*="top attached"].segment > [class*="bottom attached"].label { border-bottom-left-radius: 0; border-bottom-right-radius: 0; }
.ui.attached.segment:not(.top):not(.bottom) > [class*="top attached"].label { border-top-left-radius: 0; border-top-right-radius: 0; }
.ui.attached.segment:not(.top):not(.bottom) > [class*="bottom attached"].label { border-bottom-left-radius: 0; border-bottom-right-radius: 0; }
.ui.grid > .row > .ui.segment.column, .ui.grid > .ui.segment.column, .ui.page.grid.segment { padding-top: 2em; padding-bottom: 2em; }
.ui.grid.segment { margin: 1rem 0; border-radius: .25rem; }
.ui.basic.table.segment { background: #fff; border: 1px solid rgba(34, 36, 38, 0.15); -webkit-box-shadow: 0 1px 2px 0 rgba(34, 36, 38, 0.15); box-shadow: 0 1px 2px 0 rgba(34, 36, 38, 0.15); }
.ui[class*="very basic"].table.segment { padding: 1em 1em; }
.ui.placeholder.segment { display: -webkit-box; display: -ms-flexbox; display: flex; -webkit-box-orient: vertical; -webkit-box-direction: normal; -ms-flex-direction: column; flex-direction: column; -webkit-box-pack: center; -ms-flex-pack: center; justify-content: center; -webkit-box-align: stretch; -ms-flex-align: stretch; align-items: stretch; max-width: initial; -webkit-animation: none; animation: none; overflow: visible; padding: 1em 1em; min-height: 18rem; background: #f9fafb; border-color: rgba(34, 36, 38, 0.15); -webkit-box-shadow: 0 2px 25px 0 rgba(34, 36, 38, 0.05) inset; box-shadow: 0 2px 25px 0 rgba(34, 36, 38, 0.05) inset; }
.ui.placeholder.segment .button, .ui.placeholder.segment textarea { display: block; }
.ui.placeholder.segment .button, .ui.placeholder.segment .field, .ui.placeholder.segment textarea, .ui.placeholder.segment > .ui.input { max-width: 15rem; margin-left: auto; margin-right: auto; }
.ui.placeholder.segment .column .button, .ui.placeholder.segment .column .field, .ui.placeholder.segment .column textarea, .ui.placeholder.segment .column > .ui.input { max-width: 15rem; margin-left: auto; margin-right: auto; }
.ui.placeholder.segment > .inline { -ms-flex-item-align: center; align-self: center; }
.ui.placeholder.segment > .inline > .button { display: inline-block; width: auto; margin: 0 .3125rem 0 0; }
.ui.placeholder.segment > .inline > .button:last-child { margin-right: 0; }
.ui.piled.segment, .ui.piled.segments { margin: 3em 0; -webkit-box-shadow: ''; box-shadow: ''; z-index: auto; }
.ui.piled.segment:first-child { margin-top: 0; }
.ui.piled.segment:last-child { margin-bottom: 0; }
.ui.piled.segment:after, .ui.piled.segment:before, .ui.piled.segments:after, .ui.piled.segments:before { background-color: #fff; visibility: visible; content: ''; display: block; height: 100%; left: 0; position: absolute; width: 100%; border: 1px solid rgba(34, 36, 38, 0.15); -webkit-box-shadow: ''; box-shadow: ''; }
.ui.piled.segment:before, .ui.piled.segments:before { -webkit-transform: rotate(-1.2deg); transform: rotate(-1.2deg); top: 0; z-index: -2; }
.ui.piled.segment:after, .ui.piled.segments:after { -webkit-transform: rotate(1.2deg); transform: rotate(1.2deg); top: 0; z-index: -1; }
.ui[class*="top attached"].piled.segment { margin-top: 3em; margin-bottom: 0; }
.ui.piled.segment[class*="top attached"]:first-child { margin-top: 0; }
.ui.piled.segment[class*="bottom attached"] { margin-top: 0; margin-bottom: 3em; }
.ui.piled.segment[class*="bottom attached"]:last-child { margin-bottom: 0; }
.ui.stacked.segment { padding-bottom: 1.4em; }
.ui.stacked.segment:after, .ui.stacked.segment:before, .ui.stacked.segments:after, .ui.stacked.segments:before { content: ''; position: absolute; bottom: -3px; left: 0; border-top: 1px solid rgba(34, 36, 38, 0.15); background: rgba(0, 0, 0, 0.03); width: 100%; height: 6px; visibility: visible; }
.ui.stacked.segment:before, .ui.stacked.segments:before { display: none; }
.ui.tall.stacked.segment:before, .ui.tall.stacked.segments:before { display: block; bottom: 0; }
.ui.stacked.inverted.segment:after, .ui.stacked.inverted.segment:before, .ui.stacked.inverted.segments:after, .ui.stacked.inverted.segments:before { background-color: rgba(0, 0, 0, 0.03); border-top: 1px solid rgba(34, 36, 38, 0.35); }
.ui.padded.segment { padding: 1.5em; }
.ui[class*="very padded"].segment { padding: 3em; }
.ui.padded.segment.vertical.segment, .ui[class*="very padded"].vertical.segment { padding-left: 0; padding-right: 0; }
.ui.compact.segment { display: table; }
.ui.compact.segments { display: -webkit-inline-box; display: -ms-inline-flexbox; display: inline-flex; }
.ui.compact.segments .segment, .ui.segments .compact.segment { display: block; -webkit-box-flex: 0; -ms-flex: 0 1 auto; flex: 0 1 auto; }
.ui.circular.segment { display: table-cell; padding: 2em; text-align: center; vertical-align: middle; border-radius: 500em; }
.ui.raised.segment, .ui.raised.segments { -webkit-box-shadow: 0 2px 4px 0 rgba(34, 36, 38, 0.12), 0 2px 10px 0 rgba(34, 36, 38, 0.15); box-shadow: 0 2px 4px 0 rgba(34, 36, 38, 0.12), 0 2px 10px 0 rgba(34, 36, 38, 0.15); }
.ui.segments { -webkit-box-orient: vertical; -webkit-box-direction: normal; -ms-flex-direction: column; flex-direction: column; position: relative; margin: 1rem 0; border: 1px solid rgba(34, 36, 38, 0.15); -webkit-box-shadow: 0 1px 2px 0 rgba(34, 36, 38, 0.15); box-shadow: 0 1px 2px 0 rgba(34, 36, 38, 0.15); border-radius: .25rem; }
.ui.segments:first-child { margin-top: 0; }
.ui.segments:last-child { margin-bottom: 0; }
.ui.segments > .segment { top: 0; bottom: 0; border-radius: 0; margin: 0; width: auto; -webkit-box-shadow: none; box-shadow: none; border: none; border-top: 1px solid rgba(34, 36, 38, 0.15); }
.ui.segments:not(.horizontal) > .segment:first-child { border-top: none; margin-top: 0; bottom: 0; margin-bottom: 0; top: 0; border-radius: .25rem .25rem 0 0; }
.ui.segments:not(.horizontal) > .segment:last-child { top: 0; bottom: 0; margin-top: 0; margin-bottom: 0; -webkit-box-shadow: 0 1px 2px 0 rgba(34, 36, 38, 0.15), none; box-shadow: 0 1px 2px 0 rgba(34, 36, 38, 0.15), none; border-radius: 0 0 .25rem .25rem; }
.ui.segments:not(.horizontal) > .segment:only-child { border-radius: .25rem; }
.ui.segments > .ui.segments { border-top: 1px solid rgba(34, 36, 38, 0.15); margin: 1rem 1rem; }
.ui.segments > .segments:first-child { border-top: none; }
.ui.segments > .segment + .segments:not(.horizontal) { margin-top: 0; }
.ui.horizontal.segments { display: -webkit-box; display: -ms-flexbox; display: flex; -webkit-box-orient: horizontal; -webkit-box-direction: normal; -ms-flex-direction: row; flex-direction: row; background-color: transparent; border-radius: 0; padding: 0; background-color: #fff; -webkit-box-shadow: 0 1px 2px 0 rgba(34, 36, 38, 0.15); box-shadow: 0 1px 2px 0 rgba(34, 36, 38, 0.15); margin: 1rem 0; border-radius: .25rem; border: 1px solid rgba(34, 36, 38, 0.15); }
.ui.segments > .horizontal.segments { margin: 0; background-color: transparent; border-radius: 0; border: none; -webkit-box-shadow: none; box-shadow: none; border-top: 1px solid rgba(34, 36, 38, 0.15); }
.ui.horizontal.segments > .segment { -webkit-box-flex: 1; flex: 1 1 auto; -ms-flex: 1 1 0px; margin: 0; min-width: 0; background-color: transparent; border-radius: 0; border: none; -webkit-box-shadow: none; box-shadow: none; border-left: 1px solid rgba(34, 36, 38, 0.15); }
.ui.segments > .horizontal.segments:first-child { border-top: none; }
.ui.horizontal.segments > .segment:first-child { border-left: none; }
.ui.disabled.segment { opacity: .45; color: rgba(40, 40, 40, 0.3); }
.ui.loading.segment { position: relative; cursor: default; pointer-events: none; text-shadow: none !important; color: transparent !important; -webkit-transition: all 0s linear; transition: all 0s linear; }
.ui.loading.segment:before { position: absolute; content: ''; top: 0; left: 0; background: rgba(255, 255, 255, 0.8); width: 100%; height: 100%; border-radius: .25rem; z-index: 100; }
.ui.loading.segment:after { position: absolute; content: ''; top: 50%; left: 50%; margin: -1.5em 0 0 -1.5em; width: 3em; height: 3em; -webkit-animation: segment-spin .6s linear; animation: segment-spin .6s linear; -webkit-animation-iteration-count: infinite; animation-iteration-count: infinite; border-radius: 500rem; border-color: #767676 rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1); border-style: solid; border-width: .2em; -webkit-box-shadow: 0 0 0 1px transparent; box-shadow: 0 0 0 1px transparent; visibility: visible; z-index: 101; }
@-webkit-keyframes segment-spin { from { -webkit-transform: rotate(0); transform: rotate(0); }
  to { -webkit-transform: rotate(360deg); transform: rotate(360deg); } }
@keyframes segment-spin { from { -webkit-transform: rotate(0); transform: rotate(0); }
  to { -webkit-transform: rotate(360deg); transform: rotate(360deg); } }
.ui.basic.segment { background: none transparent; -webkit-box-shadow: none; box-shadow: none; border: none; border-radius: 0; }
.ui.clearing.segment:after { content: "."; display: block; height: 0; clear: both; visibility: hidden; }
.ui.red.segment:not(.inverted) { border-top: 2px solid #db2828 !important; }
.ui.inverted.red.segment { background-color: #db2828 !important; color: #fff !important; }
.ui.orange.segment:not(.inverted) { border-top: 2px solid #f2711c !important; }
.ui.inverted.orange.segment { background-color: #f2711c !important; color: #fff !important; }
.ui.yellow.segment:not(.inverted) { border-top: 2px solid #fbbd08 !important; }
.ui.inverted.yellow.segment { background-color: #fbbd08 !important; color: #fff !important; }
.ui.olive.segment:not(.inverted) { border-top: 2px solid #b5cc18 !important; }
.ui.inverted.olive.segment { background-color: #b5cc18 !important; color: #fff !important; }
.ui.green.segment:not(.inverted) { border-top: 2px solid #21ba45 !important; }
.ui.inverted.green.segment { background-color: #21ba45 !important; color: #fff !important; }
.ui.teal.segment:not(.inverted) { border-top: 2px solid #00b5ad !important; }
.ui.inverted.teal.segment { background-color: #00b5ad !important; color: #fff !important; }
.ui.blue.segment:not(.inverted) { border-top: 2px solid #2185d0 !important; }
.ui.inverted.blue.segment { background-color: #2185d0 !important; color: #fff !important; }
.ui.violet.segment:not(.inverted) { border-top: 2px solid #6435c9 !important; }
.ui.inverted.violet.segment { background-color: #6435c9 !important; color: #fff !important; }
.ui.purple.segment:not(.inverted) { border-top: 2px solid #a333c8 !important; }
.ui.inverted.purple.segment { background-color: #a333c8 !important; color: #fff !important; }
.ui.pink.segment:not(.inverted) { border-top: 2px solid #e03997 !important; }
.ui.inverted.pink.segment { background-color: #e03997 !important; color: #fff !important; }
.ui.brown.segment:not(.inverted) { border-top: 2px solid #a5673f !important; }
.ui.inverted.brown.segment { background-color: #a5673f !important; color: #fff !important; }
.ui.grey.segment:not(.inverted) { border-top: 2px solid #767676 !important; }
.ui.inverted.grey.segment { background-color: #767676 !important; color: #fff !important; }
.ui.black.segment:not(.inverted) { border-top: 2px solid #1b1c1d !important; }
.ui.inverted.black.segment { background-color: #1b1c1d !important; color: #fff !important; }
.ui[class*="left aligned"].segment { text-align: left; }
.ui[class*="right aligned"].segment { text-align: right; }
.ui[class*="center aligned"].segment { text-align: center; }
.ui.floated.segment, .ui[class*="left floated"].segment { float: left; margin-right: 1em; }
.ui[class*="right floated"].segment { float: right; margin-left: 1em; }
.ui.inverted.segment { border: none; -webkit-box-shadow: none; box-shadow: none; }
.ui.inverted.segment, .ui.primary.inverted.segment { background: #F7F7F7; color: rgba(255, 255, 255, 0.9); }
.ui.inverted.segment .segment { color: rgba(0, 0, 0, 0.87); }
.ui.inverted.segment .inverted.segment { color: rgba(255, 255, 255, 0.9); }
.ui.inverted.attached.segment { border-color: #555; }
.ui.secondary.segment { background: #f3f4f5; color: rgba(0, 0, 0, 0.6); }
.ui.secondary.inverted.segment { background: #4c4f52 -webkit-gradient(linear, left top, left bottom, from(rgba(255, 255, 255, 0.2)), to(rgba(255, 255, 255, 0.2))); background: #4c4f52 -webkit-linear-gradient(rgba(255, 255, 255, 0.2) 0, rgba(255, 255, 255, 0.2) 100%); background: #4c4f52 linear-gradient(rgba(255, 255, 255, 0.2) 0, rgba(255, 255, 255, 0.2) 100%); color: rgba(255, 255, 255, 0.8); }
.ui.tertiary.segment { background: #dcddde; color: rgba(0, 0, 0, 0.6); }
.ui.tertiary.inverted.segment { background: #717579 -webkit-gradient(linear, left top, left bottom, from(rgba(255, 255, 255, 0.35)), to(rgba(255, 255, 255, 0.35))); background: #717579 -webkit-linear-gradient(rgba(255, 255, 255, 0.35) 0, rgba(255, 255, 255, 0.35) 100%); background: #717579 linear-gradient(rgba(255, 255, 255, 0.35) 0, rgba(255, 255, 255, 0.35) 100%); color: rgba(255, 255, 255, 0.8); }
.ui.attached.segment { top: 0; bottom: 0; border-radius: 0; margin: 0 -1px; width: calc(100% - (-1px * 2)); max-width: calc(100% - (-1px * 2)); -webkit-box-shadow: none; box-shadow: none; border: 1px solid #d4d4d5; }
.ui.attached:not(.message) + .ui.attached.segment:not(.top) { border-top: none; }
.ui[class*="top attached"].segment { bottom: 0; margin-bottom: 0; top: 0; margin-top: 1rem; border-radius: .25rem .25rem 0 0; }
.ui.segment[class*="top attached"]:first-child { margin-top: 0; }
.ui.segment[class*="bottom attached"] { bottom: 0; margin-top: 0; top: 0; margin-bottom: 1rem; -webkit-box-shadow: 0 1px 2px 0 rgba(34, 36, 38, 0.15), none; box-shadow: 0 1px 2px 0 rgba(34, 36, 38, 0.15), none; border-radius: 0 0 .25rem .25rem; }
.ui.segment[class*="bottom attached"]:last-child { margin-bottom: 0; }
.ui.mini.segment, .ui.mini.segments .segment { font-size: .625rem; }
.ui.tiny.segment, .ui.tiny.segments .segment { font-size: .75rem; }
.ui.small.segment, .ui.small.segments .segment { font-size: .875rem; }
.ui.segment, .ui.segments .segment { font-size: 1rem; }
.ui.large.segment, .ui.large.segments .segment { font-size: 1.125rem; }
.ui.big.segment, .ui.big.segments .segment { font-size: 1.25rem; }
.ui.huge.segment, .ui.huge.segments .segment { font-size: 1.5rem; }
.ui.massive.segment, .ui.massive.segments .segment { font-size: 2rem; }
.ui.sidebar { position: fixed; top: 0; left: 0; -webkit-backface-visibility: hidden; backface-visibility: hidden; -webkit-transition: none; transition: none; will-change: transform; -webkit-transform: translate3d(0, 0, 0); transform: translate3d(0, 0, 0); visibility: hidden; -webkit-overflow-scrolling: touch; height: 100% !important; max-height: 100%; border-radius: 0 !important; margin: 0 !important; overflow-y: auto !important; z-index: 102; }
.ui.sidebar > * { -webkit-backface-visibility: hidden; backface-visibility: hidden; }
.ui.left.sidebar { right: auto; left: 0; -webkit-transform: translate3d(-100%, 0, 0); transform: translate3d(-100%, 0, 0); }
.ui.right.sidebar { right: 0 !important; left: auto !important; -webkit-transform: translate3d(100%, 0, 0); transform: translate3d(100%, 0, 0); }
.ui.bottom.sidebar, .ui.top.sidebar { width: 100% !important; height: auto !important; }
.ui.top.sidebar { top: 0 !important; bottom: auto !important; -webkit-transform: translate3d(0, -100%, 0); transform: translate3d(0, -100%, 0); }
.ui.bottom.sidebar { top: auto !important; bottom: 0 !important; -webkit-transform: translate3d(0, 100%, 0); transform: translate3d(0, 100%, 0); }
.pushable { height: 100%; overflow-x: hidden; padding: 0 !important; }
body.pushable { background: #545454 !important; }
.pushable:not(body) { -webkit-transform: translate3d(0, 0, 0); transform: translate3d(0, 0, 0); }
.pushable:not(body) > .fixed, .pushable:not(body) > .pusher:after, .pushable:not(body) > .ui.sidebar { position: absolute; }
.pushable > .fixed { position: fixed; -webkit-backface-visibility: hidden; backface-visibility: hidden; -webkit-transition: -webkit-transform .5s ease; transition: -webkit-transform .5s ease; transition: transform .5s ease; transition: transform .5s ease,-webkit-transform .5s ease; will-change: transform; z-index: 101; }
.pushable > .pusher { position: relative; -webkit-backface-visibility: hidden; backface-visibility: hidden; overflow: hidden; min-height: 100%; -webkit-transition: -webkit-transform .5s ease; transition: -webkit-transform .5s ease; transition: transform .5s ease; transition: transform .5s ease,-webkit-transform .5s ease; z-index: 2; }
body.pushable > .pusher { background: #fff; }
.pushable > .pusher { background: inherit; }
.pushable > .pusher:after { position: fixed; top: 0; right: 0; content: ''; background-color: rgba(0, 0, 0, 0.4); overflow: hidden; opacity: 0; -webkit-transition: opacity .5s; transition: opacity .5s; will-change: opacity; z-index: 1000; }
.ui.sidebar.menu .item { border-radius: 0 !important; }
.pushable > .pusher.dimmed:after { width: 100% !important; height: 100% !important; opacity: 1 !important; }
.ui.animating.sidebar { visibility: visible; }
.ui.visible.sidebar { visibility: visible; -webkit-transform: translate3d(0, 0, 0); transform: translate3d(0, 0, 0); }
.ui.left.visible.sidebar, .ui.right.visible.sidebar { -webkit-box-shadow: 0 0 20px rgba(34, 36, 38, 0.15); box-shadow: 0 0 20px rgba(34, 36, 38, 0.15); }
.ui.bottom.visible.sidebar, .ui.top.visible.sidebar { -webkit-box-shadow: 0 0 20px rgba(34, 36, 38, 0.15); box-shadow: 0 0 20px rgba(34, 36, 38, 0.15); }
.ui.visible.left.sidebar ~ .fixed, .ui.visible.left.sidebar ~ .pusher { -webkit-transform: translate3d(260px, 0, 0); transform: translate3d(260px, 0, 0); }
.ui.visible.right.sidebar ~ .fixed, .ui.visible.right.sidebar ~ .pusher { -webkit-transform: translate3d(-260px, 0, 0); transform: translate3d(-260px, 0, 0); }
.ui.visible.top.sidebar ~ .fixed, .ui.visible.top.sidebar ~ .pusher { -webkit-transform: translate3d(0, 36px, 0); transform: translate3d(0, 36px, 0); }
.ui.visible.bottom.sidebar ~ .fixed, .ui.visible.bottom.sidebar ~ .pusher { -webkit-transform: translate3d(0, -36px, 0); transform: translate3d(0, -36px, 0); }
.ui.visible.left.sidebar ~ .ui.visible.right.sidebar ~ .fixed, .ui.visible.left.sidebar ~ .ui.visible.right.sidebar ~ .pusher, .ui.visible.right.sidebar ~ .ui.visible.left.sidebar ~ .fixed, .ui.visible.right.sidebar ~ .ui.visible.left.sidebar ~ .pusher { -webkit-transform: translate3d(0, 0, 0); transform: translate3d(0, 0, 0); }
.ui.thin.left.sidebar, .ui.thin.right.sidebar { width: 150px; }
.ui[class*="very thin"].left.sidebar, .ui[class*="very thin"].right.sidebar { width: 60px; }
.ui.left.sidebar, .ui.right.sidebar { width: 260px; }
.ui.wide.left.sidebar, .ui.wide.right.sidebar { width: 350px; }
.ui[class*="very wide"].left.sidebar, .ui[class*="very wide"].right.sidebar { width: 475px; }
.ui.visible.thin.left.sidebar ~ .fixed, .ui.visible.thin.left.sidebar ~ .pusher { -webkit-transform: translate3d(150px, 0, 0); transform: translate3d(150px, 0, 0); }
.ui.visible[class*="very thin"].left.sidebar ~ .fixed, .ui.visible[class*="very thin"].left.sidebar ~ .pusher { -webkit-transform: translate3d(60px, 0, 0); transform: translate3d(60px, 0, 0); }
.ui.visible.wide.left.sidebar ~ .fixed, .ui.visible.wide.left.sidebar ~ .pusher { -webkit-transform: translate3d(350px, 0, 0); transform: translate3d(350px, 0, 0); }
.ui.visible[class*="very wide"].left.sidebar ~ .fixed, .ui.visible[class*="very wide"].left.sidebar ~ .pusher { -webkit-transform: translate3d(475px, 0, 0); transform: translate3d(475px, 0, 0); }
.ui.visible.thin.right.sidebar ~ .fixed, .ui.visible.thin.right.sidebar ~ .pusher { -webkit-transform: translate3d(-150px, 0, 0); transform: translate3d(-150px, 0, 0); }
.ui.visible[class*="very thin"].right.sidebar ~ .fixed, .ui.visible[class*="very thin"].right.sidebar ~ .pusher { -webkit-transform: translate3d(-60px, 0, 0); transform: translate3d(-60px, 0, 0); }
.ui.visible.wide.right.sidebar ~ .fixed, .ui.visible.wide.right.sidebar ~ .pusher { -webkit-transform: translate3d(-350px, 0, 0); transform: translate3d(-350px, 0, 0); }
.ui.visible[class*="very wide"].right.sidebar ~ .fixed, .ui.visible[class*="very wide"].right.sidebar ~ .pusher { -webkit-transform: translate3d(-475px, 0, 0); transform: translate3d(-475px, 0, 0); }
.ui.overlay.sidebar { z-index: 102; }
.ui.left.overlay.sidebar { -webkit-transform: translate3d(-100%, 0, 0); transform: translate3d(-100%, 0, 0); }
.ui.right.overlay.sidebar { -webkit-transform: translate3d(100%, 0, 0); transform: translate3d(100%, 0, 0); }
.ui.top.overlay.sidebar { -webkit-transform: translate3d(0, -100%, 0); transform: translate3d(0, -100%, 0); }
.ui.bottom.overlay.sidebar { -webkit-transform: translate3d(0, 100%, 0); transform: translate3d(0, 100%, 0); }
.animating.ui.overlay.sidebar, .ui.visible.overlay.sidebar { -webkit-transition: -webkit-transform .5s ease; transition: -webkit-transform .5s ease; transition: transform .5s ease; transition: transform .5s ease,-webkit-transform .5s ease; }
.ui.visible.left.overlay.sidebar { -webkit-transform: translate3d(0, 0, 0); transform: translate3d(0, 0, 0); }
.ui.visible.right.overlay.sidebar { -webkit-transform: translate3d(0, 0, 0); transform: translate3d(0, 0, 0); }
.ui.visible.top.overlay.sidebar { -webkit-transform: translate3d(0, 0, 0); transform: translate3d(0, 0, 0); }
.ui.visible.bottom.overlay.sidebar { -webkit-transform: translate3d(0, 0, 0); transform: translate3d(0, 0, 0); }
.ui.visible.overlay.sidebar ~ .fixed, .ui.visible.overlay.sidebar ~ .pusher { -webkit-transform: none !important; transform: none !important; }
.ui.push.sidebar { -webkit-transition: -webkit-transform .5s ease; transition: -webkit-transform .5s ease; transition: transform .5s ease; transition: transform .5s ease,-webkit-transform .5s ease; z-index: 102; }
.ui.left.push.sidebar { -webkit-transform: translate3d(-100%, 0, 0); transform: translate3d(-100%, 0, 0); }
.ui.right.push.sidebar { -webkit-transform: translate3d(100%, 0, 0); transform: translate3d(100%, 0, 0); }
.ui.top.push.sidebar { -webkit-transform: translate3d(0, -100%, 0); transform: translate3d(0, -100%, 0); }
.ui.bottom.push.sidebar { -webkit-transform: translate3d(0, 100%, 0); transform: translate3d(0, 100%, 0); }
.ui.visible.push.sidebar { -webkit-transform: translate3d(0, 0, 0); transform: translate3d(0, 0, 0); }
.ui.uncover.sidebar { -webkit-transform: translate3d(0, 0, 0); transform: translate3d(0, 0, 0); z-index: 1; }
.ui.visible.uncover.sidebar { -webkit-transform: translate3d(0, 0, 0); transform: translate3d(0, 0, 0); -webkit-transition: -webkit-transform .5s ease; transition: -webkit-transform .5s ease; transition: transform .5s ease; transition: transform .5s ease,-webkit-transform .5s ease; }
.ui.slide.along.sidebar { z-index: 1; }
.ui.left.slide.along.sidebar { -webkit-transform: translate3d(-50%, 0, 0); transform: translate3d(-50%, 0, 0); }
.ui.right.slide.along.sidebar { -webkit-transform: translate3d(50%, 0, 0); transform: translate3d(50%, 0, 0); }
.ui.top.slide.along.sidebar { -webkit-transform: translate3d(0, -50%, 0); transform: translate3d(0, -50%, 0); }
.ui.bottom.slide.along.sidebar { -webkit-transform: translate3d(0, 50%, 0); transform: translate3d(0, 50%, 0); }
.ui.animating.slide.along.sidebar { -webkit-transition: -webkit-transform .5s ease; transition: -webkit-transform .5s ease; transition: transform .5s ease; transition: transform .5s ease,-webkit-transform .5s ease; }
.ui.visible.slide.along.sidebar { -webkit-transform: translate3d(0, 0, 0); transform: translate3d(0, 0, 0); }
.ui.slide.out.sidebar { z-index: 1; }
.ui.left.slide.out.sidebar { -webkit-transform: translate3d(50%, 0, 0); transform: translate3d(50%, 0, 0); }
.ui.right.slide.out.sidebar { -webkit-transform: translate3d(-50%, 0, 0); transform: translate3d(-50%, 0, 0); }
.ui.top.slide.out.sidebar { -webkit-transform: translate3d(0, 50%, 0); transform: translate3d(0, 50%, 0); }
.ui.bottom.slide.out.sidebar { -webkit-transform: translate3d(0, -50%, 0); transform: translate3d(0, -50%, 0); }
.ui.animating.slide.out.sidebar { -webkit-transition: -webkit-transform .5s ease; transition: -webkit-transform .5s ease; transition: transform .5s ease; transition: transform .5s ease,-webkit-transform .5s ease; }
.ui.visible.slide.out.sidebar { -webkit-transform: translate3d(0, 0, 0); transform: translate3d(0, 0, 0); }
.ui.scale.down.sidebar { -webkit-transition: -webkit-transform .5s ease; transition: -webkit-transform .5s ease; transition: transform .5s ease; transition: transform .5s ease,-webkit-transform .5s ease; z-index: 102; }
.ui.left.scale.down.sidebar { -webkit-transform: translate3d(-100%, 0, 0); transform: translate3d(-100%, 0, 0); }
.ui.right.scale.down.sidebar { -webkit-transform: translate3d(100%, 0, 0); transform: translate3d(100%, 0, 0); }
.ui.top.scale.down.sidebar { -webkit-transform: translate3d(0, -100%, 0); transform: translate3d(0, -100%, 0); }
.ui.bottom.scale.down.sidebar { -webkit-transform: translate3d(0, 100%, 0); transform: translate3d(0, 100%, 0); }
.ui.scale.down.left.sidebar ~ .pusher { -webkit-transform-origin: 75% 50%; transform-origin: 75% 50%; }
.ui.scale.down.right.sidebar ~ .pusher { -webkit-transform-origin: 25% 50%; transform-origin: 25% 50%; }
.ui.scale.down.top.sidebar ~ .pusher { -webkit-transform-origin: 50% 75%; transform-origin: 50% 75%; }
.ui.scale.down.bottom.sidebar ~ .pusher { -webkit-transform-origin: 50% 25%; transform-origin: 50% 25%; }
.ui.animating.scale.down > .visible.ui.sidebar { -webkit-transition: -webkit-transform .5s ease; transition: -webkit-transform .5s ease; transition: transform .5s ease; transition: transform .5s ease,-webkit-transform .5s ease; }
.ui.animating.scale.down.sidebar ~ .pusher, .ui.visible.scale.down.sidebar ~ .pusher { display: block !important; width: 100%; height: 100%; overflow: hidden !important; }
.ui.visible.scale.down.sidebar { -webkit-transform: translate3d(0, 0, 0); transform: translate3d(0, 0, 0); }
.ui.visible.scale.down.sidebar ~ .pusher { -webkit-transform: scale(0.75); transform: scale(0.75); }
.ui.sticky { position: static; -webkit-transition: none; transition: none; z-index: 800; }
.ui.sticky.bound { position: absolute; left: auto; right: auto; }
.ui.sticky.fixed { position: fixed; left: auto; right: auto; }
.ui.sticky.bound.top, .ui.sticky.fixed.top { top: 0; bottom: auto; }
.ui.sticky.bound.bottom, .ui.sticky.fixed.bottom { top: auto; bottom: 0; }
.ui.native.sticky { position: -webkit-sticky; position: -moz-sticky; position: -ms-sticky; position: -o-sticky; position: sticky; }
.ui.tab { display: none; }
.ui.tab.active, .ui.tab.open { display: block; }
.ui.tab.loading { position: relative; overflow: hidden; display: block; min-height: 250px; }
.ui.tab.loading * { position: relative !important; left: -10000px !important; }
.ui.tab.loading.segment:before, .ui.tab.loading:before { position: absolute; content: ''; top: 100px; left: 50%; margin: -1.25em 0 0 -1.25em; width: 2.5em; height: 2.5em; border-radius: 500rem; border: 0.2em solid rgba(0, 0, 0, 0.1); }
.ui.tab.loading.segment:after, .ui.tab.loading:after { position: absolute; content: ''; top: 100px; left: 50%; margin: -1.25em 0 0 -1.25em; width: 2.5em; height: 2.5em; -webkit-animation: button-spin .6s linear; animation: button-spin .6s linear; -webkit-animation-iteration-count: infinite; animation-iteration-count: infinite; border-radius: 500rem; border-color: #767676 transparent transparent; border-style: solid; border-width: .2em; -webkit-box-shadow: 0 0 0 1px transparent; box-shadow: 0 0 0 1px transparent; }
.ui.table { width: 100%; background: #fff; margin: 1em 0; border: 1px solid rgba(34, 36, 38, 0.15); -webkit-box-shadow: none; box-shadow: none; border-radius: .25rem; text-align: left; color: rgba(0, 0, 0, 0.87); border-collapse: separate; border-spacing: 0; }
.ui.table:first-child { margin-top: 0; }
.ui.table:last-child { margin-bottom: 0; }
.ui.table td, .ui.table th { -webkit-transition: background .1s ease,color .1s ease; transition: background .1s ease,color .1s ease; }
.ui.table thead { -webkit-box-shadow: none; box-shadow: none; }
.ui.table thead th { cursor: auto; background: #f9fafb; text-align: inherit; color: rgba(0, 0, 0, 0.87); padding: .875em .625em; vertical-align: inherit; font-style: none; font-weight: 700; text-transform: none; border-bottom: 1px solid rgba(34, 36, 38, 0.1); border-left: none; }
.ui.table thead tr > th:first-child { border-left: none; }
.ui.table thead tr:first-child > th:first-child { border-radius: .25rem 0 0 0; }
.ui.table thead tr:first-child > th:last-child { border-radius: 0 .25rem 0 0; }
.ui.table thead tr:first-child > th:only-child { border-radius: .25rem .25rem 0 0; }
.ui.table tfoot { -webkit-box-shadow: none; box-shadow: none; }
.ui.table tfoot th { cursor: auto; border-top: 1px solid rgba(34, 36, 38, 0.15); background: #f9fafb; text-align: inherit; color: rgba(0, 0, 0, 0.87); padding: .625em .625em; vertical-align: middle; font-style: normal; font-weight: 400; text-transform: none; }
.ui.table tfoot tr > th:first-child { border-left: none; }
.ui.table tfoot tr:first-child > th:first-child { border-radius: 0 0 0 .25rem; }
.ui.table tfoot tr:first-child > th:last-child { border-radius: 0 0 .25rem 0; }
.ui.table tfoot tr:first-child > th:only-child { border-radius: 0 0 .25rem .25rem; }
.ui.table tr td { border-top: 1px solid rgba(34, 36, 38, 0.1); }
.ui.table tr:first-child td { border-top: none; }
.ui.table tbody + tbody tr:first-child td { border-top: 1px solid rgba(34, 36, 38, 0.1); }
.ui.table td { padding: .625em .625em; text-align: inherit; }
.ui.table > .icon { vertical-align: baseline; }
.ui.table > .icon:only-child { margin: 0; }
.ui.table.segment { padding: 0; }
.ui.table.segment:after { display: none; }
.ui.table.segment.stacked:after { display: block; }
@media only screen and (max-width: 767px) { .ui.table:not(.unstackable) { width: 100%; }
  .ui.table:not(.unstackable) tbody, .ui.table:not(.unstackable) tr, .ui.table:not(.unstackable) tr > td, .ui.table:not(.unstackable) tr > th { width: auto !important; display: block !important; }
  .ui.table:not(.unstackable) { padding: 0; }
  .ui.table:not(.unstackable) thead { display: block; }
  .ui.table:not(.unstackable) tfoot { display: block; }
  .ui.table:not(.unstackable) tr { padding-top: 1em; padding-bottom: 1em; -webkit-box-shadow: 0 -1px 0 0 rgba(0, 0, 0, 0.1) inset !important; box-shadow: 0 -1px 0 0 rgba(0, 0, 0, 0.1) inset !important; }
  .ui.table:not(.unstackable) tr > td, .ui.table:not(.unstackable) tr > th { background: 0 0; border: none !important; padding: 0.25em 0.75em !important; -webkit-box-shadow: none !important; box-shadow: none !important; }
  .ui.table:not(.unstackable) td:first-child, .ui.table:not(.unstackable) th:first-child { font-weight: 700; }
  .ui.definition.table:not(.unstackable) thead th:first-child { -webkit-box-shadow: none !important; box-shadow: none !important; } }
.ui.table td .image, .ui.table td .image img, .ui.table th .image, .ui.table th .image img { max-width: none; }
.ui.structured.table { border-collapse: collapse; }
.ui.structured.table thead th { border-left: none; border-right: none; }
.ui.structured.sortable.table thead th { border-left: 1px solid rgba(34, 36, 38, 0.15); border-right: 1px solid rgba(34, 36, 38, 0.15); }
.ui.structured.basic.table th { border-left: none; border-right: none; }
.ui.structured.celled.table tr td, .ui.structured.celled.table tr th { border-left: 1px solid rgba(34, 36, 38, 0.1); border-right: 1px solid rgba(34, 36, 38, 0.1); }
.ui.definition.table thead:not(.full-width) th:first-child { pointer-events: none; background: 0 0; font-weight: 400; color: rgba(0, 0, 0, 0.4); -webkit-box-shadow: -1px -1px 0 1px #fff; box-shadow: -1px -1px 0 1px #fff; }
.ui.definition.table tfoot:not(.full-width) th:first-child { pointer-events: none; background: 0 0; font-weight: rgba(0, 0, 0, 0.4); color: normal; -webkit-box-shadow: 1px 1px 0 1px #fff; box-shadow: 1px 1px 0 1px #fff; }
.ui.celled.definition.table thead:not(.full-width) th:first-child { -webkit-box-shadow: 0 -1px 0 1px #fff; box-shadow: 0 -1px 0 1px #fff; }
.ui.celled.definition.table tfoot:not(.full-width) th:first-child { -webkit-box-shadow: 0 1px 0 1px #fff; box-shadow: 0 1px 0 1px #fff; }
.ui.definition.table tr td.definition, .ui.definition.table tr td:first-child:not(.ignored) { background: rgba(0, 0, 0, 0.03); font-weight: 700; color: rgba(0, 0, 0, 0.95); text-transform: ''; -webkit-box-shadow: ''; box-shadow: ''; text-align: ''; font-size: 1em; padding-left: ''; padding-right: ''; }
.ui.definition.table thead:not(.full-width) th:nth-child(2) { border-left: 1px solid rgba(34, 36, 38, 0.15); }
.ui.definition.table tfoot:not(.full-width) th:nth-child(2) { border-left: 1px solid rgba(34, 36, 38, 0.15); }
.ui.definition.table td:nth-child(2) { border-left: 1px solid rgba(34, 36, 38, 0.15); }
.ui.table td.positive, .ui.table tr.positive { -webkit-box-shadow: 0 0 0 #a3c293 inset; box-shadow: 0 0 0 #a3c293 inset; }
.ui.table td.positive, .ui.table tr.positive { background: #fcfff5 !important; color: #2c662d !important; }
.ui.table td.negative, .ui.table tr.negative { -webkit-box-shadow: 0 0 0 #e0b4b4 inset; box-shadow: 0 0 0 #e0b4b4 inset; }
.ui.table td.negative, .ui.table tr.negative { background: #fff6f6 !important; color: #9f3a38 !important; }
.ui.table td.error, .ui.table tr.error { -webkit-box-shadow: 0 0 0 #e0b4b4 inset; box-shadow: 0 0 0 #e0b4b4 inset; }
.ui.table td.error, .ui.table tr.error { background: #fff6f6 !important; color: #9f3a38 !important; }
.ui.table td.warning, .ui.table tr.warning { -webkit-box-shadow: 0 0 0 #d6b46e inset; box-shadow: 0 0 0 #d6b46e inset; }
.ui.table td.warning, .ui.table tr.warning { background: #fffaf3 !important; color: #d67e08 !important; }
.ui.table td.active, .ui.table tr.active { -webkit-box-shadow: 0 0 0 rgba(0, 0, 0, 0.87) inset; box-shadow: 0 0 0 rgba(0, 0, 0, 0.87) inset; }
.ui.table td.active, .ui.table tr.active { background: #e0e0e0 !important; color: rgba(0, 0, 0, 0.87) !important; }
.ui.table tr td.disabled, .ui.table tr.disabled td, .ui.table tr.disabled:hover, .ui.table tr:hover td.disabled { pointer-events: none; color: rgba(40, 40, 40, 0.3); }
@media only screen and (max-width: 991px) { .ui[class*="tablet stackable"].table, .ui[class*="tablet stackable"].table tbody, .ui[class*="tablet stackable"].table tr, .ui[class*="tablet stackable"].table tr > td, .ui[class*="tablet stackable"].table tr > th { width: 100% !important; display: block !important; }
  .ui[class*="tablet stackable"].table { padding: 0; }
  .ui[class*="tablet stackable"].table thead { display: block; }
  .ui[class*="tablet stackable"].table tfoot { display: block; }
  .ui[class*="tablet stackable"].table tr { padding-top: 1em; padding-bottom: 1em; -webkit-box-shadow: 0 -1px 0 0 rgba(0, 0, 0, 0.1) inset !important; box-shadow: 0 -1px 0 0 rgba(0, 0, 0, 0.1) inset !important; }
  .ui[class*="tablet stackable"].table tr > td, .ui[class*="tablet stackable"].table tr > th { background: 0 0; border: none !important; padding: .25em .75em; -webkit-box-shadow: none !important; box-shadow: none !important; }
  .ui.definition[class*="tablet stackable"].table thead th:first-child { -webkit-box-shadow: none !important; box-shadow: none !important; } }
.ui.table [class*="left aligned"], .ui.table[class*="left aligned"] { text-align: left; }
.ui.table [class*="center aligned"], .ui.table[class*="center aligned"] { text-align: center; }
.ui.table [class*="right aligned"], .ui.table[class*="right aligned"] { text-align: right; }
.ui.table [class*="top aligned"], .ui.table[class*="top aligned"] { vertical-align: top; }
.ui.table [class*="middle aligned"], .ui.table[class*="middle aligned"] { vertical-align: middle; }
.ui.table [class*="bottom aligned"], .ui.table[class*="bottom aligned"] { vertical-align: bottom; }
.ui.table td.collapsing, .ui.table th.collapsing { width: 1px; white-space: nowrap; }
.ui.fixed.table { table-layout: fixed; }
.ui.fixed.table td, .ui.fixed.table th { overflow: hidden; text-overflow: ellipsis; }
.ui.selectable.table tbody tr:hover, .ui.table tbody tr td.selectable:hover { background: rgba(0, 0, 0, 0.05) !important; color: rgba(0, 0, 0, 0.95) !important; }
.ui.inverted.table tbody tr td.selectable:hover, .ui.selectable.inverted.table tbody tr:hover { background: rgba(255, 255, 255, 0.08) !important; color: #fff !important; }
.ui.table tbody tr td.selectable { padding: 0; }
.ui.table tbody tr td.selectable > a:not(.ui) { display: block; color: inherit; padding: .625em .625em; }
.ui.selectable.table tr.error:hover, .ui.selectable.table tr:hover td.error, .ui.table tr td.selectable.error:hover { background: #ffe7e7 !important; color: #943634 !important; }
.ui.selectable.table tr.warning:hover, .ui.selectable.table tr:hover td.warning, .ui.table tr td.selectable.warning:hover { background: #fff4e4 !important; color: #c77507 !important; }
.ui.selectable.table tr.active:hover, .ui.selectable.table tr:hover td.active, .ui.table tr td.selectable.active:hover { background: #e0e0e0 !important; color: rgba(0, 0, 0, 0.87) !important; }
.ui.selectable.table tr.positive:hover, .ui.selectable.table tr:hover td.positive, .ui.table tr td.selectable.positive:hover { background: #f7ffe6 !important; color: #275b28 !important; }
.ui.selectable.table tr.negative:hover, .ui.selectable.table tr:hover td.negative, .ui.table tr td.selectable.negative:hover { background: #ffe7e7 !important; color: #943634 !important; }
.ui.attached.table { top: 0; bottom: 0; border-radius: 0; margin: 0 -1px; width: calc(100% - (-1px * 2)); max-width: calc(100% - (-1px * 2)); -webkit-box-shadow: none; box-shadow: none; border: 1px solid #d4d4d5; }
.ui.attached + .ui.attached.table:not(.top) { border-top: none; }
.ui[class*="top attached"].table { bottom: 0; margin-bottom: 0; top: 0; margin-top: 1em; border-radius: .25rem .25rem 0 0; }
.ui.table[class*="top attached"]:first-child { margin-top: 0; }
.ui[class*="bottom attached"].table { bottom: 0; margin-top: 0; top: 0; margin-bottom: 1em; -webkit-box-shadow: none,none; box-shadow: none,none; border-radius: 0 0 .25rem .25rem; }
.ui[class*="bottom attached"].table:last-child { margin-bottom: 0; }
.ui.striped.table tbody tr:nth-child(2n), .ui.striped.table > tr:nth-child(2n) { background-color: rgba(0, 0, 50, 0.02); }
.ui.inverted.striped.table tbody tr:nth-child(2n), .ui.inverted.striped.table > tr:nth-child(2n) { background-color: rgba(255, 255, 255, 0.05); }
.ui.striped.selectable.selectable.selectable.table tbody tr.active:hover { background: #efefef !important; color: rgba(0, 0, 0, 0.95) !important; }
.ui.table [class*="single line"], .ui.table[class*="single line"] { white-space: nowrap; }
.ui.table [class*="single line"], .ui.table[class*="single line"] { white-space: nowrap; }
.ui.red.table { border-top: .2em solid #db2828; }
.ui.inverted.red.table { background-color: #db2828 !important; color: #fff !important; }
.ui.orange.table { border-top: .2em solid #f2711c; }
.ui.inverted.orange.table { background-color: #f2711c !important; color: #fff !important; }
.ui.yellow.table { border-top: .2em solid #fbbd08; }
.ui.inverted.yellow.table { background-color: #fbbd08 !important; color: #fff !important; }
.ui.olive.table { border-top: .2em solid #b5cc18; }
.ui.inverted.olive.table { background-color: #b5cc18 !important; color: #fff !important; }
.ui.green.table { border-top: .2em solid #21ba45; }
.ui.inverted.green.table { background-color: #21ba45 !important; color: #fff !important; }
.ui.teal.table { border-top: .2em solid #00b5ad; }
.ui.inverted.teal.table { background-color: #00b5ad !important; color: #fff !important; }
.ui.blue.table { border-top: .2em solid #2185d0; }
.ui.inverted.blue.table { background-color: #2185d0 !important; color: #fff !important; }
.ui.violet.table { border-top: .2em solid #6435c9; }
.ui.inverted.violet.table { background-color: #6435c9 !important; color: #fff !important; }
.ui.purple.table { border-top: .2em solid #a333c8; }
.ui.inverted.purple.table { background-color: #a333c8 !important; color: #fff !important; }
.ui.pink.table { border-top: .2em solid #e03997; }
.ui.inverted.pink.table { background-color: #e03997 !important; color: #fff !important; }
.ui.brown.table { border-top: .2em solid #a5673f; }
.ui.inverted.brown.table { background-color: #a5673f !important; color: #fff !important; }
.ui.grey.table { border-top: .2em solid #767676; }
.ui.inverted.grey.table { background-color: #767676 !important; color: #fff !important; }
.ui.black.table { border-top: .2em solid #1b1c1d; }
.ui.inverted.black.table { background-color: #1b1c1d !important; color: #fff !important; }
.ui.one.column.table td { width: 100%; }
.ui.two.column.table td { width: 50%; }
.ui.three.column.table td { width: 33.33333333%; }
.ui.four.column.table td { width: 25%; }
.ui.five.column.table td { width: 20%; }
.ui.six.column.table td { width: 16.66666667%; }
.ui.seven.column.table td { width: 14.28571429%; }
.ui.eight.column.table td { width: 12.5%; }
.ui.nine.column.table td { width: 11.11111111%; }
.ui.ten.column.table td { width: 10%; }
.ui.eleven.column.table td { width: 9.09090909%; }
.ui.twelve.column.table td { width: 8.33333333%; }
.ui.thirteen.column.table td { width: 7.69230769%; }
.ui.fourteen.column.table td { width: 7.14285714%; }
.ui.fifteen.column.table td { width: 6.66666667%; }
.ui.sixteen.column.table td { width: 6.25%; }
.ui.table td.one.wide, .ui.table th.one.wide { width: 6.25%; }
.ui.table td.two.wide, .ui.table th.two.wide { width: 12.5%; }
.ui.table td.three.wide, .ui.table th.three.wide { width: 18.75%; }
.ui.table td.four.wide, .ui.table th.four.wide { width: 25%; }
.ui.table td.five.wide, .ui.table th.five.wide { width: 31.25%; }
.ui.table td.six.wide, .ui.table th.six.wide { width: 37.5%; }
.ui.table td.seven.wide, .ui.table th.seven.wide { width: 43.75%; }
.ui.table td.eight.wide, .ui.table th.eight.wide { width: 50%; }
.ui.table td.nine.wide, .ui.table th.nine.wide { width: 56.25%; }
.ui.table td.ten.wide, .ui.table th.ten.wide { width: 62.5%; }
.ui.table td.eleven.wide, .ui.table th.eleven.wide { width: 68.75%; }
.ui.table td.twelve.wide, .ui.table th.twelve.wide { width: 75%; }
.ui.table td.thirteen.wide, .ui.table th.thirteen.wide { width: 81.25%; }
.ui.table td.fourteen.wide, .ui.table th.fourteen.wide { width: 87.5%; }
.ui.table td.fifteen.wide, .ui.table th.fifteen.wide { width: 93.75%; }
.ui.table td.sixteen.wide, .ui.table th.sixteen.wide { width: 100%; }
.ui.sortable.table thead th { cursor: pointer; white-space: nowrap; border-left: 1px solid rgba(34, 36, 38, 0.15); color: rgba(0, 0, 0, 0.87); }
.ui.sortable.table thead th:first-child { border-left: none; }
.ui.sortable.table thead th.sorted, .ui.sortable.table thead th.sorted:hover { -webkit-user-select: none; -moz-user-select: none; -ms-user-select: none; user-select: none; }
.ui.sortable.table thead th:after { display: none; font-style: normal; font-weight: 400; text-decoration: inherit; content: ''; height: 1em; width: auto; opacity: .8; margin: 0 0 0 .5em; font-family: Icons; }
.ui.sortable.table thead th.ascending:after { content: '\f0d8'; }
.ui.sortable.table thead th.descending:after { content: '\f0d7'; }
.ui.sortable.table th.disabled:hover { cursor: auto; color: rgba(40, 40, 40, 0.3); }
.ui.sortable.table thead th:hover { background: rgba(0, 0, 0, 0.05); color: rgba(0, 0, 0, 0.8); }
.ui.sortable.table thead th.sorted { background: rgba(0, 0, 0, 0.05); color: rgba(0, 0, 0, 0.95); }
.ui.sortable.table thead th.sorted:after { display: inline-block; }
.ui.sortable.table thead th.sorted:hover { background: rgba(0, 0, 0, 0.05); color: rgba(0, 0, 0, 0.95); }
.ui.inverted.sortable.table thead th.sorted { background: rgba(255, 255, 255, 0.15) -webkit-gradient(linear, left top, left bottom, from(transparent), to(rgba(0, 0, 0, 0.05))); background: rgba(255, 255, 255, 0.15) -webkit-linear-gradient(transparent, rgba(0, 0, 0, 0.05)); background: rgba(255, 255, 255, 0.15) linear-gradient(transparent, rgba(0, 0, 0, 0.05)); color: #fff; }
.ui.inverted.sortable.table thead th:hover { background: rgba(255, 255, 255, 0.08) -webkit-gradient(linear, left top, left bottom, from(transparent), to(rgba(0, 0, 0, 0.05))); background: rgba(255, 255, 255, 0.08) -webkit-linear-gradient(transparent, rgba(0, 0, 0, 0.05)); background: rgba(255, 255, 255, 0.08) linear-gradient(transparent, rgba(0, 0, 0, 0.05)); color: #fff; }
.ui.inverted.sortable.table thead th { border-left-color: transparent; border-right-color: transparent; }
.ui.inverted.table { background: #333; color: rgba(255, 255, 255, 0.9); border: none; }
.ui.inverted.table th { background-color: rgba(0, 0, 0, 0.15); border-color: rgba(255, 255, 255, 0.1) !important; color: rgba(255, 255, 255, 0.9) !important; }
.ui.inverted.table tr td { border-color: rgba(255, 255, 255, 0.1) !important; }
.ui.inverted.table tr td.disabled, .ui.inverted.table tr.disabled td, .ui.inverted.table tr.disabled:hover td, .ui.inverted.table tr:hover td.disabled { pointer-events: none; color: rgba(225, 225, 225, 0.3); }
.ui.inverted.definition.table tfoot:not(.full-width) th:first-child, .ui.inverted.definition.table thead:not(.full-width) th:first-child { background: #fff; }
.ui.inverted.definition.table tr td:first-child { background: rgba(255, 255, 255, 0.02); color: #fff; }
.ui.collapsing.table { width: auto; }
.ui.basic.table { background: 0 0; border: 1px solid rgba(34, 36, 38, 0.15); -webkit-box-shadow: none; box-shadow: none; }
.ui.basic.table tfoot, .ui.basic.table thead { -webkit-box-shadow: none; box-shadow: none; }
.ui.basic.table th { background: 0 0; border-left: none; }
.ui.basic.table tbody tr { border-bottom: 1px solid rgba(0, 0, 0, 0.1); }
.ui.basic.table td { background: 0 0; }
.ui.basic.striped.table tbody tr:nth-child(2n) { background-color: rgba(0, 0, 0, 0.05) !important; }
.ui[class*="very basic"].table { border: none; }
.ui[class*="very basic"].table:not(.sortable):not(.striped) td, .ui[class*="very basic"].table:not(.sortable):not(.striped) th { padding: ''; }
.ui[class*="very basic"].table:not(.sortable):not(.striped) td:first-child, .ui[class*="very basic"].table:not(.sortable):not(.striped) th:first-child { padding-left: 0; }
.ui[class*="very basic"].table:not(.sortable):not(.striped) td:last-child, .ui[class*="very basic"].table:not(.sortable):not(.striped) th:last-child { padding-right: 0; }
.ui[class*="very basic"].table:not(.sortable):not(.striped) thead tr:first-child th { padding-top: 0; }
.ui.celled.table tr td, .ui.celled.table tr th { border-left: 1px solid rgba(34, 36, 38, 0.1); }
.ui.celled.table tr td:first-child, .ui.celled.table tr th:first-child { border-left: none; }
.ui.padded.table th { padding-left: 1em; padding-right: 1em; }
.ui.padded.table td, .ui.padded.table th { padding: 1em 1em; }
.ui[class*="very padded"].table th { padding-left: 1.5em; padding-right: 1.5em; }
.ui[class*="very padded"].table td { padding: 1.5em 1.5em; }
.ui.compact.table th { padding-left: .7em; padding-right: .7em; }
.ui.compact.table td { padding: .5em .7em; }
.ui[class*="very compact"].table th { padding-left: .6em; padding-right: .6em; }
.ui[class*="very compact"].table td { padding: .4em .6em; }
.ui.small.table { font-size: .9em; }
.ui.table { font-size: 1em; }
.ui.large.table { font-size: 1.1em; }
.transition { -webkit-animation-iteration-count: 1; animation-iteration-count: 1; -webkit-animation-duration: .3s; animation-duration: .3s; -webkit-animation-timing-function: ease; animation-timing-function: ease; -webkit-animation-fill-mode: both; animation-fill-mode: both; }
.animating.transition { -webkit-backface-visibility: hidden; backface-visibility: hidden; visibility: visible !important; }
.loading.transition { position: absolute; top: -99999px; left: -99999px; }
.hidden.transition { display: none; visibility: hidden; }
.visible.transition { display: block !important; visibility: visible !important; }
.disabled.transition { -webkit-animation-play-state: paused; animation-play-state: paused; }
.looping.transition { -webkit-animation-iteration-count: infinite; animation-iteration-count: infinite; }
.transition.browse { -webkit-animation-duration: .5s; animation-duration: .5s; }
.transition.browse.in { -webkit-animation-name: browseIn; animation-name: browseIn; }
.transition.browse.left.out, .transition.browse.out { -webkit-animation-name: browseOutLeft; animation-name: browseOutLeft; }
.transition.browse.right.out { -webkit-animation-name: browseOutRight; animation-name: browseOutRight; }
@-webkit-keyframes browseIn { 0% { -webkit-transform: scale(0.8) translateZ(0); transform: scale(0.8) translateZ(0); z-index: -1; }
  10% { -webkit-transform: scale(0.8) translateZ(0); transform: scale(0.8) translateZ(0); z-index: -1; opacity: .7; }
  80% { -webkit-transform: scale(1.05) translateZ(0); transform: scale(1.05) translateZ(0); opacity: 1; z-index: 999; }
  100% { -webkit-transform: scale(1) translateZ(0); transform: scale(1) translateZ(0); z-index: 999; } }
@keyframes browseIn { 0% { -webkit-transform: scale(0.8) translateZ(0); transform: scale(0.8) translateZ(0); z-index: -1; }
  10% { -webkit-transform: scale(0.8) translateZ(0); transform: scale(0.8) translateZ(0); z-index: -1; opacity: .7; }
  80% { -webkit-transform: scale(1.05) translateZ(0); transform: scale(1.05) translateZ(0); opacity: 1; z-index: 999; }
  100% { -webkit-transform: scale(1) translateZ(0); transform: scale(1) translateZ(0); z-index: 999; } }
@-webkit-keyframes browseOutLeft { 0% { z-index: 999; -webkit-transform: translateX(0) rotateY(0) rotateX(0); transform: translateX(0) rotateY(0) rotateX(0); }
  50% { z-index: -1; -webkit-transform: translateX(-105%) rotateY(35deg) rotateX(10deg) translateZ(-10px); transform: translateX(-105%) rotateY(35deg) rotateX(10deg) translateZ(-10px); }
  80% { opacity: 1; }
  100% { z-index: -1; -webkit-transform: translateX(0) rotateY(0) rotateX(0) translateZ(-10px); transform: translateX(0) rotateY(0) rotateX(0) translateZ(-10px); opacity: 0; } }
@keyframes browseOutLeft { 0% { z-index: 999; -webkit-transform: translateX(0) rotateY(0) rotateX(0); transform: translateX(0) rotateY(0) rotateX(0); }
  50% { z-index: -1; -webkit-transform: translateX(-105%) rotateY(35deg) rotateX(10deg) translateZ(-10px); transform: translateX(-105%) rotateY(35deg) rotateX(10deg) translateZ(-10px); }
  80% { opacity: 1; }
  100% { z-index: -1; -webkit-transform: translateX(0) rotateY(0) rotateX(0) translateZ(-10px); transform: translateX(0) rotateY(0) rotateX(0) translateZ(-10px); opacity: 0; } }
@-webkit-keyframes browseOutRight { 0% { z-index: 999; -webkit-transform: translateX(0) rotateY(0) rotateX(0); transform: translateX(0) rotateY(0) rotateX(0); }
  50% { z-index: 1; -webkit-transform: translateX(105%) rotateY(35deg) rotateX(10deg) translateZ(-10px); transform: translateX(105%) rotateY(35deg) rotateX(10deg) translateZ(-10px); }
  80% { opacity: 1; }
  100% { z-index: 1; -webkit-transform: translateX(0) rotateY(0) rotateX(0) translateZ(-10px); transform: translateX(0) rotateY(0) rotateX(0) translateZ(-10px); opacity: 0; } }
@keyframes browseOutRight { 0% { z-index: 999; -webkit-transform: translateX(0) rotateY(0) rotateX(0); transform: translateX(0) rotateY(0) rotateX(0); }
  50% { z-index: 1; -webkit-transform: translateX(105%) rotateY(35deg) rotateX(10deg) translateZ(-10px); transform: translateX(105%) rotateY(35deg) rotateX(10deg) translateZ(-10px); }
  80% { opacity: 1; }
  100% { z-index: 1; -webkit-transform: translateX(0) rotateY(0) rotateX(0) translateZ(-10px); transform: translateX(0) rotateY(0) rotateX(0) translateZ(-10px); opacity: 0; } }
.drop.transition { -webkit-transform-origin: top center; transform-origin: top center; -webkit-animation-duration: .4s; animation-duration: .4s; -webkit-animation-timing-function: cubic-bezier(0.34, 1.61, 0.7, 1); animation-timing-function: cubic-bezier(0.34, 1.61, 0.7, 1); }
.drop.transition.in { -webkit-animation-name: dropIn; animation-name: dropIn; }
.drop.transition.out { -webkit-animation-name: dropOut; animation-name: dropOut; }
@-webkit-keyframes dropIn { 0% { opacity: 0; -webkit-transform: scale(0); transform: scale(0); }
  100% { opacity: 1; -webkit-transform: scale(1); transform: scale(1); } }
@keyframes dropIn { 0% { opacity: 0; -webkit-transform: scale(0); transform: scale(0); }
  100% { opacity: 1; -webkit-transform: scale(1); transform: scale(1); } }
@-webkit-keyframes dropOut { 0% { opacity: 1; -webkit-transform: scale(1); transform: scale(1); }
  100% { opacity: 0; -webkit-transform: scale(0); transform: scale(0); } }
@keyframes dropOut { 0% { opacity: 1; -webkit-transform: scale(1); transform: scale(1); }
  100% { opacity: 0; -webkit-transform: scale(0); transform: scale(0); } }
.transition.fade.in { -webkit-animation-name: fadeIn; animation-name: fadeIn; }
.transition[class*="fade up"].in { -webkit-animation-name: fadeInUp; animation-name: fadeInUp; }
.transition[class*="fade down"].in { -webkit-animation-name: fadeInDown; animation-name: fadeInDown; }
.transition[class*="fade left"].in { -webkit-animation-name: fadeInLeft; animation-name: fadeInLeft; }
.transition[class*="fade right"].in { -webkit-animation-name: fadeInRight; animation-name: fadeInRight; }
.transition.fade.out { -webkit-animation-name: fadeOut; animation-name: fadeOut; }
.transition[class*="fade up"].out { -webkit-animation-name: fadeOutUp; animation-name: fadeOutUp; }
.transition[class*="fade down"].out { -webkit-animation-name: fadeOutDown; animation-name: fadeOutDown; }
.transition[class*="fade left"].out { -webkit-animation-name: fadeOutLeft; animation-name: fadeOutLeft; }
.transition[class*="fade right"].out { -webkit-animation-name: fadeOutRight; animation-name: fadeOutRight; }
@-webkit-keyframes fadeIn { 0% { opacity: 0; }
  100% { opacity: 1; } }
@keyframes fadeIn { 0% { opacity: 0; }
  100% { opacity: 1; } }
@-webkit-keyframes fadeInUp { 0% { opacity: 0; -webkit-transform: translateY(10%); transform: translateY(10%); }
  100% { opacity: 1; -webkit-transform: translateY(0); transform: translateY(0); } }
@keyframes fadeInUp { 0% { opacity: 0; -webkit-transform: translateY(10%); transform: translateY(10%); }
  100% { opacity: 1; -webkit-transform: translateY(0); transform: translateY(0); } }
@-webkit-keyframes fadeInDown { 0% { opacity: 0; -webkit-transform: translateY(-10%); transform: translateY(-10%); }
  100% { opacity: 1; -webkit-transform: translateY(0); transform: translateY(0); } }
@keyframes fadeInDown { 0% { opacity: 0; -webkit-transform: translateY(-10%); transform: translateY(-10%); }
  100% { opacity: 1; -webkit-transform: translateY(0); transform: translateY(0); } }
@-webkit-keyframes fadeInLeft { 0% { opacity: 0; -webkit-transform: translateX(10%); transform: translateX(10%); }
  100% { opacity: 1; -webkit-transform: translateX(0); transform: translateX(0); } }
@keyframes fadeInLeft { 0% { opacity: 0; -webkit-transform: translateX(10%); transform: translateX(10%); }
  100% { opacity: 1; -webkit-transform: translateX(0); transform: translateX(0); } }
@-webkit-keyframes fadeInRight { 0% { opacity: 0; -webkit-transform: translateX(-10%); transform: translateX(-10%); }
  100% { opacity: 1; -webkit-transform: translateX(0); transform: translateX(0); } }
@keyframes fadeInRight { 0% { opacity: 0; -webkit-transform: translateX(-10%); transform: translateX(-10%); }
  100% { opacity: 1; -webkit-transform: translateX(0); transform: translateX(0); } }
@-webkit-keyframes fadeOut { 0% { opacity: 1; }
  100% { opacity: 0; } }
@keyframes fadeOut { 0% { opacity: 1; }
  100% { opacity: 0; } }
@-webkit-keyframes fadeOutUp { 0% { opacity: 1; -webkit-transform: translateY(0); transform: translateY(0); }
  100% { opacity: 0; -webkit-transform: translateY(5%); transform: translateY(5%); } }
@keyframes fadeOutUp { 0% { opacity: 1; -webkit-transform: translateY(0); transform: translateY(0); }
  100% { opacity: 0; -webkit-transform: translateY(5%); transform: translateY(5%); } }
@-webkit-keyframes fadeOutDown { 0% { opacity: 1; -webkit-transform: translateY(0); transform: translateY(0); }
  100% { opacity: 0; -webkit-transform: translateY(-5%); transform: translateY(-5%); } }
@keyframes fadeOutDown { 0% { opacity: 1; -webkit-transform: translateY(0); transform: translateY(0); }
  100% { opacity: 0; -webkit-transform: translateY(-5%); transform: translateY(-5%); } }
@-webkit-keyframes fadeOutLeft { 0% { opacity: 1; -webkit-transform: translateX(0); transform: translateX(0); }
  100% { opacity: 0; -webkit-transform: translateX(5%); transform: translateX(5%); } }
@keyframes fadeOutLeft { 0% { opacity: 1; -webkit-transform: translateX(0); transform: translateX(0); }
  100% { opacity: 0; -webkit-transform: translateX(5%); transform: translateX(5%); } }
@-webkit-keyframes fadeOutRight { 0% { opacity: 1; -webkit-transform: translateX(0); transform: translateX(0); }
  100% { opacity: 0; -webkit-transform: translateX(-5%); transform: translateX(-5%); } }
@keyframes fadeOutRight { 0% { opacity: 1; -webkit-transform: translateX(0); transform: translateX(0); }
  100% { opacity: 0; -webkit-transform: translateX(-5%); transform: translateX(-5%); } }
.flip.transition.in, .flip.transition.out { -webkit-animation-duration: .6s; animation-duration: .6s; }
.horizontal.flip.transition.in { -webkit-animation-name: horizontalFlipIn; animation-name: horizontalFlipIn; }
.horizontal.flip.transition.out { -webkit-animation-name: horizontalFlipOut; animation-name: horizontalFlipOut; }
.vertical.flip.transition.in { -webkit-animation-name: verticalFlipIn; animation-name: verticalFlipIn; }
.vertical.flip.transition.out { -webkit-animation-name: verticalFlipOut; animation-name: verticalFlipOut; }
@-webkit-keyframes horizontalFlipIn { 0% { -webkit-transform: perspective(2000px) rotateY(-90deg); transform: perspective(2000px) rotateY(-90deg); opacity: 0; }
  100% { -webkit-transform: perspective(2000px) rotateY(0); transform: perspective(2000px) rotateY(0); opacity: 1; } }
@keyframes horizontalFlipIn { 0% { -webkit-transform: perspective(2000px) rotateY(-90deg); transform: perspective(2000px) rotateY(-90deg); opacity: 0; }
  100% { -webkit-transform: perspective(2000px) rotateY(0); transform: perspective(2000px) rotateY(0); opacity: 1; } }
@-webkit-keyframes verticalFlipIn { 0% { -webkit-transform: perspective(2000px) rotateX(-90deg); transform: perspective(2000px) rotateX(-90deg); opacity: 0; }
  100% { -webkit-transform: perspective(2000px) rotateX(0); transform: perspective(2000px) rotateX(0); opacity: 1; } }
@keyframes verticalFlipIn { 0% { -webkit-transform: perspective(2000px) rotateX(-90deg); transform: perspective(2000px) rotateX(-90deg); opacity: 0; }
  100% { -webkit-transform: perspective(2000px) rotateX(0); transform: perspective(2000px) rotateX(0); opacity: 1; } }
@-webkit-keyframes horizontalFlipOut { 0% { -webkit-transform: perspective(2000px) rotateY(0); transform: perspective(2000px) rotateY(0); opacity: 1; }
  100% { -webkit-transform: perspective(2000px) rotateY(90deg); transform: perspective(2000px) rotateY(90deg); opacity: 0; } }
@keyframes horizontalFlipOut { 0% { -webkit-transform: perspective(2000px) rotateY(0); transform: perspective(2000px) rotateY(0); opacity: 1; }
  100% { -webkit-transform: perspective(2000px) rotateY(90deg); transform: perspective(2000px) rotateY(90deg); opacity: 0; } }
@-webkit-keyframes verticalFlipOut { 0% { -webkit-transform: perspective(2000px) rotateX(0); transform: perspective(2000px) rotateX(0); opacity: 1; }
  100% { -webkit-transform: perspective(2000px) rotateX(-90deg); transform: perspective(2000px) rotateX(-90deg); opacity: 0; } }
@keyframes verticalFlipOut { 0% { -webkit-transform: perspective(2000px) rotateX(0); transform: perspective(2000px) rotateX(0); opacity: 1; }
  100% { -webkit-transform: perspective(2000px) rotateX(-90deg); transform: perspective(2000px) rotateX(-90deg); opacity: 0; } }
.scale.transition.in { -webkit-animation-name: scaleIn; animation-name: scaleIn; }
.scale.transition.out { -webkit-animation-name: scaleOut; animation-name: scaleOut; }
@-webkit-keyframes scaleIn { 0% { opacity: 0; -webkit-transform: scale(0.8); transform: scale(0.8); }
  100% { opacity: 1; -webkit-transform: scale(1); transform: scale(1); } }
@keyframes scaleIn { 0% { opacity: 0; -webkit-transform: scale(0.8); transform: scale(0.8); }
  100% { opacity: 1; -webkit-transform: scale(1); transform: scale(1); } }
@-webkit-keyframes scaleOut { 0% { opacity: 1; -webkit-transform: scale(1); transform: scale(1); }
  100% { opacity: 0; -webkit-transform: scale(0.9); transform: scale(0.9); } }
@keyframes scaleOut { 0% { opacity: 1; -webkit-transform: scale(1); transform: scale(1); }
  100% { opacity: 0; -webkit-transform: scale(0.9); transform: scale(0.9); } }
.transition.fly { -webkit-animation-duration: .6s; animation-duration: .6s; -webkit-transition-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1); transition-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1); }
.transition.fly.in { -webkit-animation-name: flyIn; animation-name: flyIn; }
.transition[class*="fly up"].in { -webkit-animation-name: flyInUp; animation-name: flyInUp; }
.transition[class*="fly down"].in { -webkit-animation-name: flyInDown; animation-name: flyInDown; }
.transition[class*="fly left"].in { -webkit-animation-name: flyInLeft; animation-name: flyInLeft; }
.transition[class*="fly right"].in { -webkit-animation-name: flyInRight; animation-name: flyInRight; }
.transition.fly.out { -webkit-animation-name: flyOut; animation-name: flyOut; }
.transition[class*="fly up"].out { -webkit-animation-name: flyOutUp; animation-name: flyOutUp; }
.transition[class*="fly down"].out { -webkit-animation-name: flyOutDown; animation-name: flyOutDown; }
.transition[class*="fly left"].out { -webkit-animation-name: flyOutLeft; animation-name: flyOutLeft; }
.transition[class*="fly right"].out { -webkit-animation-name: flyOutRight; animation-name: flyOutRight; }
@-webkit-keyframes flyIn { 0% { opacity: 0; -webkit-transform: scale3d(0.3, 0.3, 0.3); transform: scale3d(0.3, 0.3, 0.3); }
  20% { -webkit-transform: scale3d(1.1, 1.1, 1.1); transform: scale3d(1.1, 1.1, 1.1); }
  40% { -webkit-transform: scale3d(0.9, 0.9, 0.9); transform: scale3d(0.9, 0.9, 0.9); }
  60% { opacity: 1; -webkit-transform: scale3d(1.03, 1.03, 1.03); transform: scale3d(1.03, 1.03, 1.03); }
  80% { -webkit-transform: scale3d(0.97, 0.97, 0.97); transform: scale3d(0.97, 0.97, 0.97); }
  100% { opacity: 1; -webkit-transform: scale3d(1, 1, 1); transform: scale3d(1, 1, 1); } }
@keyframes flyIn { 0% { opacity: 0; -webkit-transform: scale3d(0.3, 0.3, 0.3); transform: scale3d(0.3, 0.3, 0.3); }
  20% { -webkit-transform: scale3d(1.1, 1.1, 1.1); transform: scale3d(1.1, 1.1, 1.1); }
  40% { -webkit-transform: scale3d(0.9, 0.9, 0.9); transform: scale3d(0.9, 0.9, 0.9); }
  60% { opacity: 1; -webkit-transform: scale3d(1.03, 1.03, 1.03); transform: scale3d(1.03, 1.03, 1.03); }
  80% { -webkit-transform: scale3d(0.97, 0.97, 0.97); transform: scale3d(0.97, 0.97, 0.97); }
  100% { opacity: 1; -webkit-transform: scale3d(1, 1, 1); transform: scale3d(1, 1, 1); } }
@-webkit-keyframes flyInUp { 0% { opacity: 0; -webkit-transform: translate3d(0, 1500px, 0); transform: translate3d(0, 1500px, 0); }
  60% { opacity: 1; -webkit-transform: translate3d(0, -20px, 0); transform: translate3d(0, -20px, 0); }
  75% { -webkit-transform: translate3d(0, 10px, 0); transform: translate3d(0, 10px, 0); }
  90% { -webkit-transform: translate3d(0, -5px, 0); transform: translate3d(0, -5px, 0); }
  100% { -webkit-transform: translate3d(0, 0, 0); transform: translate3d(0, 0, 0); } }
@keyframes flyInUp { 0% { opacity: 0; -webkit-transform: translate3d(0, 1500px, 0); transform: translate3d(0, 1500px, 0); }
  60% { opacity: 1; -webkit-transform: translate3d(0, -20px, 0); transform: translate3d(0, -20px, 0); }
  75% { -webkit-transform: translate3d(0, 10px, 0); transform: translate3d(0, 10px, 0); }
  90% { -webkit-transform: translate3d(0, -5px, 0); transform: translate3d(0, -5px, 0); }
  100% { -webkit-transform: translate3d(0, 0, 0); transform: translate3d(0, 0, 0); } }
@-webkit-keyframes flyInDown { 0% { opacity: 0; -webkit-transform: translate3d(0, -1500px, 0); transform: translate3d(0, -1500px, 0); }
  60% { opacity: 1; -webkit-transform: translate3d(0, 25px, 0); transform: translate3d(0, 25px, 0); }
  75% { -webkit-transform: translate3d(0, -10px, 0); transform: translate3d(0, -10px, 0); }
  90% { -webkit-transform: translate3d(0, 5px, 0); transform: translate3d(0, 5px, 0); }
  100% { -webkit-transform: none; transform: none; } }
@keyframes flyInDown { 0% { opacity: 0; -webkit-transform: translate3d(0, -1500px, 0); transform: translate3d(0, -1500px, 0); }
  60% { opacity: 1; -webkit-transform: translate3d(0, 25px, 0); transform: translate3d(0, 25px, 0); }
  75% { -webkit-transform: translate3d(0, -10px, 0); transform: translate3d(0, -10px, 0); }
  90% { -webkit-transform: translate3d(0, 5px, 0); transform: translate3d(0, 5px, 0); }
  100% { -webkit-transform: none; transform: none; } }
@-webkit-keyframes flyInLeft { 0% { opacity: 0; -webkit-transform: translate3d(1500px, 0, 0); transform: translate3d(1500px, 0, 0); }
  60% { opacity: 1; -webkit-transform: translate3d(-25px, 0, 0); transform: translate3d(-25px, 0, 0); }
  75% { -webkit-transform: translate3d(10px, 0, 0); transform: translate3d(10px, 0, 0); }
  90% { -webkit-transform: translate3d(-5px, 0, 0); transform: translate3d(-5px, 0, 0); }
  100% { -webkit-transform: none; transform: none; } }
@keyframes flyInLeft { 0% { opacity: 0; -webkit-transform: translate3d(1500px, 0, 0); transform: translate3d(1500px, 0, 0); }
  60% { opacity: 1; -webkit-transform: translate3d(-25px, 0, 0); transform: translate3d(-25px, 0, 0); }
  75% { -webkit-transform: translate3d(10px, 0, 0); transform: translate3d(10px, 0, 0); }
  90% { -webkit-transform: translate3d(-5px, 0, 0); transform: translate3d(-5px, 0, 0); }
  100% { -webkit-transform: none; transform: none; } }
@-webkit-keyframes flyInRight { 0% { opacity: 0; -webkit-transform: translate3d(-1500px, 0, 0); transform: translate3d(-1500px, 0, 0); }
  60% { opacity: 1; -webkit-transform: translate3d(25px, 0, 0); transform: translate3d(25px, 0, 0); }
  75% { -webkit-transform: translate3d(-10px, 0, 0); transform: translate3d(-10px, 0, 0); }
  90% { -webkit-transform: translate3d(5px, 0, 0); transform: translate3d(5px, 0, 0); }
  100% { -webkit-transform: none; transform: none; } }
@keyframes flyInRight { 0% { opacity: 0; -webkit-transform: translate3d(-1500px, 0, 0); transform: translate3d(-1500px, 0, 0); }
  60% { opacity: 1; -webkit-transform: translate3d(25px, 0, 0); transform: translate3d(25px, 0, 0); }
  75% { -webkit-transform: translate3d(-10px, 0, 0); transform: translate3d(-10px, 0, 0); }
  90% { -webkit-transform: translate3d(5px, 0, 0); transform: translate3d(5px, 0, 0); }
  100% { -webkit-transform: none; transform: none; } }
@-webkit-keyframes flyOut { 20% { -webkit-transform: scale3d(0.9, 0.9, 0.9); transform: scale3d(0.9, 0.9, 0.9); }
  50%,55% { opacity: 1; -webkit-transform: scale3d(1.1, 1.1, 1.1); transform: scale3d(1.1, 1.1, 1.1); }
  100% { opacity: 0; -webkit-transform: scale3d(0.3, 0.3, 0.3); transform: scale3d(0.3, 0.3, 0.3); } }
@keyframes flyOut { 20% { -webkit-transform: scale3d(0.9, 0.9, 0.9); transform: scale3d(0.9, 0.9, 0.9); }
  50%,55% { opacity: 1; -webkit-transform: scale3d(1.1, 1.1, 1.1); transform: scale3d(1.1, 1.1, 1.1); }
  100% { opacity: 0; -webkit-transform: scale3d(0.3, 0.3, 0.3); transform: scale3d(0.3, 0.3, 0.3); } }
@-webkit-keyframes flyOutUp { 20% { -webkit-transform: translate3d(0, 10px, 0); transform: translate3d(0, 10px, 0); }
  40%,45% { opacity: 1; -webkit-transform: translate3d(0, -20px, 0); transform: translate3d(0, -20px, 0); }
  100% { opacity: 0; -webkit-transform: translate3d(0, 2000px, 0); transform: translate3d(0, 2000px, 0); } }
@keyframes flyOutUp { 20% { -webkit-transform: translate3d(0, 10px, 0); transform: translate3d(0, 10px, 0); }
  40%,45% { opacity: 1; -webkit-transform: translate3d(0, -20px, 0); transform: translate3d(0, -20px, 0); }
  100% { opacity: 0; -webkit-transform: translate3d(0, 2000px, 0); transform: translate3d(0, 2000px, 0); } }
@-webkit-keyframes flyOutDown { 20% { -webkit-transform: translate3d(0, -10px, 0); transform: translate3d(0, -10px, 0); }
  40%,45% { opacity: 1; -webkit-transform: translate3d(0, 20px, 0); transform: translate3d(0, 20px, 0); }
  100% { opacity: 0; -webkit-transform: translate3d(0, -2000px, 0); transform: translate3d(0, -2000px, 0); } }
@keyframes flyOutDown { 20% { -webkit-transform: translate3d(0, -10px, 0); transform: translate3d(0, -10px, 0); }
  40%,45% { opacity: 1; -webkit-transform: translate3d(0, 20px, 0); transform: translate3d(0, 20px, 0); }
  100% { opacity: 0; -webkit-transform: translate3d(0, -2000px, 0); transform: translate3d(0, -2000px, 0); } }
@-webkit-keyframes flyOutRight { 20% { opacity: 1; -webkit-transform: translate3d(20px, 0, 0); transform: translate3d(20px, 0, 0); }
  100% { opacity: 0; -webkit-transform: translate3d(-2000px, 0, 0); transform: translate3d(-2000px, 0, 0); } }
@keyframes flyOutRight { 20% { opacity: 1; -webkit-transform: translate3d(20px, 0, 0); transform: translate3d(20px, 0, 0); }
  100% { opacity: 0; -webkit-transform: translate3d(-2000px, 0, 0); transform: translate3d(-2000px, 0, 0); } }
@-webkit-keyframes flyOutLeft { 20% { opacity: 1; -webkit-transform: translate3d(-20px, 0, 0); transform: translate3d(-20px, 0, 0); }
  100% { opacity: 0; -webkit-transform: translate3d(2000px, 0, 0); transform: translate3d(2000px, 0, 0); } }
@keyframes flyOutLeft { 20% { opacity: 1; -webkit-transform: translate3d(-20px, 0, 0); transform: translate3d(-20px, 0, 0); }
  100% { opacity: 0; -webkit-transform: translate3d(2000px, 0, 0); transform: translate3d(2000px, 0, 0); } }
.transition.slide.in, .transition[class*="slide down"].in { -webkit-animation-name: slideInY; animation-name: slideInY; -webkit-transform-origin: top center; transform-origin: top center; }
.transition[class*="slide up"].in { -webkit-animation-name: slideInY; animation-name: slideInY; -webkit-transform-origin: bottom center; transform-origin: bottom center; }
.transition[class*="slide left"].in { -webkit-animation-name: slideInX; animation-name: slideInX; -webkit-transform-origin: center right; transform-origin: center right; }
.transition[class*="slide right"].in { -webkit-animation-name: slideInX; animation-name: slideInX; -webkit-transform-origin: center left; transform-origin: center left; }
.transition.slide.out, .transition[class*="slide down"].out { -webkit-animation-name: slideOutY; animation-name: slideOutY; -webkit-transform-origin: top center; transform-origin: top center; }
.transition[class*="slide up"].out { -webkit-animation-name: slideOutY; animation-name: slideOutY; -webkit-transform-origin: bottom center; transform-origin: bottom center; }
.transition[class*="slide left"].out { -webkit-animation-name: slideOutX; animation-name: slideOutX; -webkit-transform-origin: center right; transform-origin: center right; }
.transition[class*="slide right"].out { -webkit-animation-name: slideOutX; animation-name: slideOutX; -webkit-transform-origin: center left; transform-origin: center left; }
@-webkit-keyframes slideInY { 0% { opacity: 0; -webkit-transform: scaleY(0); transform: scaleY(0); }
  100% { opacity: 1; -webkit-transform: scaleY(1); transform: scaleY(1); } }
@keyframes slideInY { 0% { opacity: 0; -webkit-transform: scaleY(0); transform: scaleY(0); }
  100% { opacity: 1; -webkit-transform: scaleY(1); transform: scaleY(1); } }
@-webkit-keyframes slideInX { 0% { opacity: 0; -webkit-transform: scaleX(0); transform: scaleX(0); }
  100% { opacity: 1; -webkit-transform: scaleX(1); transform: scaleX(1); } }
@keyframes slideInX { 0% { opacity: 0; -webkit-transform: scaleX(0); transform: scaleX(0); }
  100% { opacity: 1; -webkit-transform: scaleX(1); transform: scaleX(1); } }
@-webkit-keyframes slideOutY { 0% { opacity: 1; -webkit-transform: scaleY(1); transform: scaleY(1); }
  100% { opacity: 0; -webkit-transform: scaleY(0); transform: scaleY(0); } }
@keyframes slideOutY { 0% { opacity: 1; -webkit-transform: scaleY(1); transform: scaleY(1); }
  100% { opacity: 0; -webkit-transform: scaleY(0); transform: scaleY(0); } }
@-webkit-keyframes slideOutX { 0% { opacity: 1; -webkit-transform: scaleX(1); transform: scaleX(1); }
  100% { opacity: 0; -webkit-transform: scaleX(0); transform: scaleX(0); } }
@keyframes slideOutX { 0% { opacity: 1; -webkit-transform: scaleX(1); transform: scaleX(1); }
  100% { opacity: 0; -webkit-transform: scaleX(0); transform: scaleX(0); } }
.transition.swing { -webkit-animation-duration: .8s; animation-duration: .8s; }
.transition[class*="swing down"].in { -webkit-animation-name: swingInX; animation-name: swingInX; -webkit-transform-origin: top center; transform-origin: top center; }
.transition[class*="swing up"].in { -webkit-animation-name: swingInX; animation-name: swingInX; -webkit-transform-origin: bottom center; transform-origin: bottom center; }
.transition[class*="swing left"].in { -webkit-animation-name: swingInY; animation-name: swingInY; -webkit-transform-origin: center right; transform-origin: center right; }
.transition[class*="swing right"].in { -webkit-animation-name: swingInY; animation-name: swingInY; -webkit-transform-origin: center left; transform-origin: center left; }
.transition.swing.out, .transition[class*="swing down"].out { -webkit-animation-name: swingOutX; animation-name: swingOutX; -webkit-transform-origin: top center; transform-origin: top center; }
.transition[class*="swing up"].out { -webkit-animation-name: swingOutX; animation-name: swingOutX; -webkit-transform-origin: bottom center; transform-origin: bottom center; }
.transition[class*="swing left"].out { -webkit-animation-name: swingOutY; animation-name: swingOutY; -webkit-transform-origin: center right; transform-origin: center right; }
.transition[class*="swing right"].out { -webkit-animation-name: swingOutY; animation-name: swingOutY; -webkit-transform-origin: center left; transform-origin: center left; }
@-webkit-keyframes swingInX { 0% { -webkit-transform: perspective(1000px) rotateX(90deg); transform: perspective(1000px) rotateX(90deg); opacity: 0; }
  40% { -webkit-transform: perspective(1000px) rotateX(-30deg); transform: perspective(1000px) rotateX(-30deg); opacity: 1; }
  60% { -webkit-transform: perspective(1000px) rotateX(15deg); transform: perspective(1000px) rotateX(15deg); }
  80% { -webkit-transform: perspective(1000px) rotateX(-7.5deg); transform: perspective(1000px) rotateX(-7.5deg); }
  100% { -webkit-transform: perspective(1000px) rotateX(0); transform: perspective(1000px) rotateX(0); } }
@keyframes swingInX { 0% { -webkit-transform: perspective(1000px) rotateX(90deg); transform: perspective(1000px) rotateX(90deg); opacity: 0; }
  40% { -webkit-transform: perspective(1000px) rotateX(-30deg); transform: perspective(1000px) rotateX(-30deg); opacity: 1; }
  60% { -webkit-transform: perspective(1000px) rotateX(15deg); transform: perspective(1000px) rotateX(15deg); }
  80% { -webkit-transform: perspective(1000px) rotateX(-7.5deg); transform: perspective(1000px) rotateX(-7.5deg); }
  100% { -webkit-transform: perspective(1000px) rotateX(0); transform: perspective(1000px) rotateX(0); } }
@-webkit-keyframes swingInY { 0% { -webkit-transform: perspective(1000px) rotateY(-90deg); transform: perspective(1000px) rotateY(-90deg); opacity: 0; }
  40% { -webkit-transform: perspective(1000px) rotateY(30deg); transform: perspective(1000px) rotateY(30deg); opacity: 1; }
  60% { -webkit-transform: perspective(1000px) rotateY(-17.5deg); transform: perspective(1000px) rotateY(-17.5deg); }
  80% { -webkit-transform: perspective(1000px) rotateY(7.5deg); transform: perspective(1000px) rotateY(7.5deg); }
  100% { -webkit-transform: perspective(1000px) rotateY(0); transform: perspective(1000px) rotateY(0); } }
@keyframes swingInY { 0% { -webkit-transform: perspective(1000px) rotateY(-90deg); transform: perspective(1000px) rotateY(-90deg); opacity: 0; }
  40% { -webkit-transform: perspective(1000px) rotateY(30deg); transform: perspective(1000px) rotateY(30deg); opacity: 1; }
  60% { -webkit-transform: perspective(1000px) rotateY(-17.5deg); transform: perspective(1000px) rotateY(-17.5deg); }
  80% { -webkit-transform: perspective(1000px) rotateY(7.5deg); transform: perspective(1000px) rotateY(7.5deg); }
  100% { -webkit-transform: perspective(1000px) rotateY(0); transform: perspective(1000px) rotateY(0); } }
@-webkit-keyframes swingOutX { 0% { -webkit-transform: perspective(1000px) rotateX(0); transform: perspective(1000px) rotateX(0); }
  40% { -webkit-transform: perspective(1000px) rotateX(-7.5deg); transform: perspective(1000px) rotateX(-7.5deg); }
  60% { -webkit-transform: perspective(1000px) rotateX(17.5deg); transform: perspective(1000px) rotateX(17.5deg); }
  80% { -webkit-transform: perspective(1000px) rotateX(-30deg); transform: perspective(1000px) rotateX(-30deg); opacity: 1; }
  100% { -webkit-transform: perspective(1000px) rotateX(90deg); transform: perspective(1000px) rotateX(90deg); opacity: 0; } }
@keyframes swingOutX { 0% { -webkit-transform: perspective(1000px) rotateX(0); transform: perspective(1000px) rotateX(0); }
  40% { -webkit-transform: perspective(1000px) rotateX(-7.5deg); transform: perspective(1000px) rotateX(-7.5deg); }
  60% { -webkit-transform: perspective(1000px) rotateX(17.5deg); transform: perspective(1000px) rotateX(17.5deg); }
  80% { -webkit-transform: perspective(1000px) rotateX(-30deg); transform: perspective(1000px) rotateX(-30deg); opacity: 1; }
  100% { -webkit-transform: perspective(1000px) rotateX(90deg); transform: perspective(1000px) rotateX(90deg); opacity: 0; } }
@-webkit-keyframes swingOutY { 0% { -webkit-transform: perspective(1000px) rotateY(0); transform: perspective(1000px) rotateY(0); }
  40% { -webkit-transform: perspective(1000px) rotateY(7.5deg); transform: perspective(1000px) rotateY(7.5deg); }
  60% { -webkit-transform: perspective(1000px) rotateY(-10deg); transform: perspective(1000px) rotateY(-10deg); }
  80% { -webkit-transform: perspective(1000px) rotateY(30deg); transform: perspective(1000px) rotateY(30deg); opacity: 1; }
  100% { -webkit-transform: perspective(1000px) rotateY(-90deg); transform: perspective(1000px) rotateY(-90deg); opacity: 0; } }
@keyframes swingOutY { 0% { -webkit-transform: perspective(1000px) rotateY(0); transform: perspective(1000px) rotateY(0); }
  40% { -webkit-transform: perspective(1000px) rotateY(7.5deg); transform: perspective(1000px) rotateY(7.5deg); }
  60% { -webkit-transform: perspective(1000px) rotateY(-10deg); transform: perspective(1000px) rotateY(-10deg); }
  80% { -webkit-transform: perspective(1000px) rotateY(30deg); transform: perspective(1000px) rotateY(30deg); opacity: 1; }
  100% { -webkit-transform: perspective(1000px) rotateY(-90deg); transform: perspective(1000px) rotateY(-90deg); opacity: 0; } }
.transition.zoom.in { -webkit-animation-name: zoomIn; animation-name: zoomIn; }
.transition.zoom.out { -webkit-animation-name: zoomOut; animation-name: zoomOut; }
@-webkit-keyframes zoomIn { 0% { opacity: 1; -webkit-transform: scale(0); transform: scale(0); }
  100% { opacity: 1; -webkit-transform: scale(1); transform: scale(1); } }
@keyframes zoomIn { 0% { opacity: 1; -webkit-transform: scale(0); transform: scale(0); }
  100% { opacity: 1; -webkit-transform: scale(1); transform: scale(1); } }
@-webkit-keyframes zoomOut { 0% { opacity: 1; -webkit-transform: scale(1); transform: scale(1); }
  100% { opacity: 1; -webkit-transform: scale(0); transform: scale(0); } }
@keyframes zoomOut { 0% { opacity: 1; -webkit-transform: scale(1); transform: scale(1); }
  100% { opacity: 1; -webkit-transform: scale(0); transform: scale(0); } }
.flash.transition { -webkit-animation-duration: 750ms; animation-duration: 750ms; -webkit-animation-name: flash; animation-name: flash; }
.shake.transition { -webkit-animation-duration: 750ms; animation-duration: 750ms; -webkit-animation-name: shake; animation-name: shake; }
.bounce.transition { -webkit-animation-duration: 750ms; animation-duration: 750ms; -webkit-animation-name: bounce; animation-name: bounce; }
.tada.transition { -webkit-animation-duration: 750ms; animation-duration: 750ms; -webkit-animation-name: tada; animation-name: tada; }
.pulse.transition { -webkit-animation-duration: .5s; animation-duration: .5s; -webkit-animation-name: pulse; animation-name: pulse; }
.jiggle.transition { -webkit-animation-duration: 750ms; animation-duration: 750ms; -webkit-animation-name: jiggle; animation-name: jiggle; }
.transition.glow { -webkit-animation-duration: 2s; animation-duration: 2s; -webkit-animation-timing-function: cubic-bezier(0.19, 1, 0.22, 1); animation-timing-function: cubic-bezier(0.19, 1, 0.22, 1); }
.transition.glow { -webkit-animation-name: glow; animation-name: glow; }
@-webkit-keyframes flash { 0%,100%,50% { opacity: 1; }
  25%,75% { opacity: 0; } }
@keyframes flash { 0%,100%,50% { opacity: 1; }
  25%,75% { opacity: 0; } }
@-webkit-keyframes shake { 0%,100% { -webkit-transform: translateX(0); transform: translateX(0); }
  10%,30%,50%,70%,90% { -webkit-transform: translateX(-10px); transform: translateX(-10px); }
  20%,40%,60%,80% { -webkit-transform: translateX(10px); transform: translateX(10px); } }
@keyframes shake { 0%,100% { -webkit-transform: translateX(0); transform: translateX(0); }
  10%,30%,50%,70%,90% { -webkit-transform: translateX(-10px); transform: translateX(-10px); }
  20%,40%,60%,80% { -webkit-transform: translateX(10px); transform: translateX(10px); } }
@-webkit-keyframes bounce { 0%,100%,20%,50%,80% { -webkit-transform: translateY(0); transform: translateY(0); }
  40% { -webkit-transform: translateY(-30px); transform: translateY(-30px); }
  60% { -webkit-transform: translateY(-15px); transform: translateY(-15px); } }
@keyframes bounce { 0%,100%,20%,50%,80% { -webkit-transform: translateY(0); transform: translateY(0); }
  40% { -webkit-transform: translateY(-30px); transform: translateY(-30px); }
  60% { -webkit-transform: translateY(-15px); transform: translateY(-15px); } }
@-webkit-keyframes tada { 0% { -webkit-transform: scale(1); transform: scale(1); }
  10%,20% { -webkit-transform: scale(0.9) rotate(-3deg); transform: scale(0.9) rotate(-3deg); }
  30%,50%,70%,90% { -webkit-transform: scale(1.1) rotate(3deg); transform: scale(1.1) rotate(3deg); }
  40%,60%,80% { -webkit-transform: scale(1.1) rotate(-3deg); transform: scale(1.1) rotate(-3deg); }
  100% { -webkit-transform: scale(1) rotate(0); transform: scale(1) rotate(0); } }
@keyframes tada { 0% { -webkit-transform: scale(1); transform: scale(1); }
  10%,20% { -webkit-transform: scale(0.9) rotate(-3deg); transform: scale(0.9) rotate(-3deg); }
  30%,50%,70%,90% { -webkit-transform: scale(1.1) rotate(3deg); transform: scale(1.1) rotate(3deg); }
  40%,60%,80% { -webkit-transform: scale(1.1) rotate(-3deg); transform: scale(1.1) rotate(-3deg); }
  100% { -webkit-transform: scale(1) rotate(0); transform: scale(1) rotate(0); } }
@-webkit-keyframes pulse { 0% { -webkit-transform: scale(1); transform: scale(1); opacity: 1; }
  50% { -webkit-transform: scale(0.9); transform: scale(0.9); opacity: .7; }
  100% { -webkit-transform: scale(1); transform: scale(1); opacity: 1; } }
@keyframes pulse { 0% { -webkit-transform: scale(1); transform: scale(1); opacity: 1; }
  50% { -webkit-transform: scale(0.9); transform: scale(0.9); opacity: .7; }
  100% { -webkit-transform: scale(1); transform: scale(1); opacity: 1; } }
@-webkit-keyframes jiggle { 0% { -webkit-transform: scale3d(1, 1, 1); transform: scale3d(1, 1, 1); }
  30% { -webkit-transform: scale3d(1.25, 0.75, 1); transform: scale3d(1.25, 0.75, 1); }
  40% { -webkit-transform: scale3d(0.75, 1.25, 1); transform: scale3d(0.75, 1.25, 1); }
  50% { -webkit-transform: scale3d(1.15, 0.85, 1); transform: scale3d(1.15, 0.85, 1); }
  65% { -webkit-transform: scale3d(0.95, 1.05, 1); transform: scale3d(0.95, 1.05, 1); }
  75% { -webkit-transform: scale3d(1.05, 0.95, 1); transform: scale3d(1.05, 0.95, 1); }
  100% { -webkit-transform: scale3d(1, 1, 1); transform: scale3d(1, 1, 1); } }
@keyframes jiggle { 0% { -webkit-transform: scale3d(1, 1, 1); transform: scale3d(1, 1, 1); }
  30% { -webkit-transform: scale3d(1.25, 0.75, 1); transform: scale3d(1.25, 0.75, 1); }
  40% { -webkit-transform: scale3d(0.75, 1.25, 1); transform: scale3d(0.75, 1.25, 1); }
  50% { -webkit-transform: scale3d(1.15, 0.85, 1); transform: scale3d(1.15, 0.85, 1); }
  65% { -webkit-transform: scale3d(0.95, 1.05, 1); transform: scale3d(0.95, 1.05, 1); }
  75% { -webkit-transform: scale3d(1.05, 0.95, 1); transform: scale3d(1.05, 0.95, 1); }
  100% { -webkit-transform: scale3d(1, 1, 1); transform: scale3d(1, 1, 1); } }
@-webkit-keyframes glow { 0% { background-color: #fcfcfd; }
  30% { background-color: #fff6cd; }
  100% { background-color: #fcfcfd; } }
@keyframes glow { 0% { background-color: #fcfcfd; }
  30% { background-color: #fff6cd; }
  100% { background-color: #fcfcfd; } }
/* Emoji sizes to match semantic ui vocabulary and leverage souce being 128px x 128px */
img.emoji { width: auto; vertical-align: middle; height: 1.25em; /* medium */ }
.ui.mini > img.emoji { height: 1.5em; }
.ui.tiny > img.emoji { height: 1.25em; }
.ui.small > img.emoji { height: 1.125em; }
.ui.large > img.emoji { height: 1.5em; }
.ui.big > img.emoji { height: 1.75em; }
.ui.huge > img.emoji { height: 2em; }
.ui.massive > img.emoji { height: 3em; }
/*!
* Remixed from StackOverflow <kbd> css, user Jin
* https://meta.superuser.com/questions/4788/css-for-the-new-kbd-style
* https://creativecommons.org/licenses/by-sa/3.0/
*/
kbd { background-color: #f7f7f7; border-radius: 3px; border: 1px solid #ccc; box-shadow: 0 1px 0 rgba(0, 0, 0, 0.2), 0 0 0 2px #fff inset; color: #333; display: inline-block; font-family: Arial,Helvetica,sans-serif; font-size: 75%; line-height: 140%; margin: 0 .1em; padding: .1em .6em; text-shadow: 0 1px 0 #fff; user-select: none; }
/*!
 * svg-based version of:
 *   # Semantic UI 2.3.1 - Icon
 *   http://github.com/semantic-org/semantic-ui/
 *
 * Released under the MIT license
 * http://opensource.org/licenses/MIT
 */
/*******************************
Changes from Semantic-UI font-based icons:
1. no icon font, no references to font files or font properties
2. css is defined for <svg> tags, not <i> tags
3. no icon symbols are defined in css; all icons are defined in svg.html as symbol definitions
specifically, by commented section:
- Icon : tweaked to remove font references
- Types : same
- States : same
- Variations : same
- Groups : same
- Icons : removed (see _data/svg_icons.yml for all symbol definitions and ids)
- Outline Icons : removed (see _data/svg_icons.yml for all symbol definitions and ids)
- Brand Icons : removed (see _data/svg_icons.yml for all symbol definitions and ids)
Usage:
 font: <i class="info circle icon"></i> svg : {% include icon.liquid id='info-circle' %}
Why?
- https://blog.github.com/2016-02-22-delivering-octicons-with-svg/
- https://css-tricks.com/icon-fonts-vs-svg/
*******************************/
/******************************* SVG Icon
*******************************/
svg.icon { display: inline-block; position: relative; top: .18em; width: 1.18em; height: 1em; opacity: 1; margin: 0; fill: currentColor; speak: none; }
svg.icon:before { background: none !important; }
/******************************* Types
*******************************/
/*-------------- Loading
---------------*/
svg.icon.loading { height: 1em; line-height: 1; -webkit-animation: icon-loading 2s linear infinite; animation: icon-loading 2s linear infinite; }
@-webkit-keyframes icon-loading { from { -webkit-transform: rotate(0deg); transform: rotate(0deg); }
  to { -webkit-transform: rotate(360deg); transform: rotate(360deg); } }
@keyframes icon-loading { from { -webkit-transform: rotate(0deg); transform: rotate(0deg); }
  to { -webkit-transform: rotate(360deg); transform: rotate(360deg); } }
/******************************* States
*******************************/
svg.icon.hover { opacity: 1 !important; }
svg.icon.active { opacity: 1 !important; }
svg.emphasized.icon { opacity: 1 !important; }
svg.disabled.icon { opacity: 0.45 !important; }
/******************************* Variations
*******************************/
/*------------------- Fitted
--------------------*/
svg.fitted.icon { width: auto; margin: 0em !important; }
/*------------------- Link
--------------------*/
svg.link.icon, svg.link.icons { cursor: pointer; opacity: 0.8; -webkit-transition: opacity 0.1s ease; transition: opacity 0.1s ease; }
svg.link.icon:hover, svg.link.icons:hover { opacity: 1 !important; }
/*------------------- Circular
--------------------*/
svg.circular.icon { border-radius: 500em !important; line-height: 1 !important; padding: 0.5em 0.5em !important; -webkit-box-shadow: 0em 0em 0em 0.1em rgba(0, 0, 0, 0.1) inset; box-shadow: 0em 0em 0em 0.1em rgba(0, 0, 0, 0.1) inset; width: 2em !important; height: 2em !important; }
svg.circular.inverted.icon { border: none; -webkit-box-shadow: none; box-shadow: none; }
/*------------------- Flipped
--------------------*/
svg.flipped.icon, svg.horizontally.flipped.icon { -webkit-transform: scale(-1, 1); transform: scale(-1, 1); }
svg.vertically.flipped.icon { -webkit-transform: scale(1, -1); transform: scale(1, -1); }
/*------------------- Rotated
--------------------*/
svg.rotated.icon, svg.right.rotated.icon, svg.clockwise.rotated.icon { -webkit-transform: rotate(90deg); transform: rotate(90deg); }
svg.left.rotated.icon, svg.counterclockwise.rotated.icon { -webkit-transform: rotate(-90deg); transform: rotate(-90deg); }
/*------------------- Bordered
--------------------*/
svg.bordered.icon { line-height: 1; vertical-align: baseline; width: 2em; height: 2em; padding: 0.5em 0em !important; -webkit-box-shadow: 0em 0em 0em 0.1em rgba(0, 0, 0, 0.1) inset; box-shadow: 0em 0em 0em 0.1em rgba(0, 0, 0, 0.1) inset; }
svg.bordered.inverted.icon { border: none; -webkit-box-shadow: none; box-shadow: none; }
/*------------------- Inverted
--------------------*/
/* Inverted Shapes */
svg.inverted.bordered.icon, svg.inverted.circular.icon { background-color: #1B1C1D !important; color: #FFFFFF !important; }
svg.inverted.icon { color: #FFFFFF; }
/*------------------- Colors
--------------------*/
/* Red */
svg.red.icon { color: #DB2828 !important; }
svg.inverted.red.icon { color: #FF695E !important; }
svg.inverted.bordered.red.icon, svg.inverted.circular.red.icon { background-color: #DB2828 !important; color: #FFFFFF !important; }
/* Orange */
svg.orange.icon { color: #F2711C !important; }
svg.inverted.orange.icon { color: #FF851B !important; }
svg.inverted.bordered.orange.icon, svg.inverted.circular.orange.icon { background-color: #F2711C !important; color: #FFFFFF !important; }
/* Yellow */
svg.yellow.icon { color: #FBBD08 !important; }
svg.inverted.yellow.icon { color: #FFE21F !important; }
svg.inverted.bordered.yellow.icon, svg.inverted.circular.yellow.icon { background-color: #FBBD08 !important; color: #FFFFFF !important; }
/* Olive */
svg.olive.icon { color: #B5CC18 !important; }
svg.inverted.olive.icon { color: #D9E778 !important; }
svg.inverted.bordered.olive.icon, svg.inverted.circular.olive.icon { background-color: #B5CC18 !important; color: #FFFFFF !important; }
/* Green */
svg.green.icon { color: #21BA45 !important; }
svg.inverted.green.icon { color: #2ECC40 !important; }
svg.inverted.bordered.green.icon, svg.inverted.circular.green.icon { background-color: #21BA45 !important; color: #FFFFFF !important; }
/* Teal */
svg.teal.icon { color: #00B5AD !important; }
svg.inverted.teal.icon { color: #6DFFFF !important; }
svg.inverted.bordered.teal.icon, svg.inverted.circular.teal.icon { background-color: #00B5AD !important; color: #FFFFFF !important; }
/* Blue */
svg.blue.icon { color: #2185D0 !important; }
svg.inverted.blue.icon { color: #54C8FF !important; }
svg.inverted.bordered.blue.icon, svg.inverted.circular.blue.icon { background-color: #2185D0 !important; color: #FFFFFF !important; }
/* Violet */
svg.violet.icon { color: #6435C9 !important; }
svg.inverted.violet.icon { color: #A291FB !important; }
svg.inverted.bordered.violet.icon, svg.inverted.circular.violet.icon { background-color: #6435C9 !important; color: #FFFFFF !important; }
/* Purple */
svg.purple.icon { color: #A333C8 !important; }
svg.inverted.purple.icon { color: #DC73FF !important; }
svg.inverted.bordered.purple.icon, svg.inverted.circular.purple.icon { background-color: #A333C8 !important; color: #FFFFFF !important; }
/* Pink */
svg.pink.icon { color: #E03997 !important; }
svg.inverted.pink.icon { color: #FF8EDF !important; }
svg.inverted.bordered.pink.icon, svg.inverted.circular.pink.icon { background-color: #E03997 !important; color: #FFFFFF !important; }
/* Brown */
svg.brown.icon { color: #A5673F !important; }
svg.inverted.brown.icon { color: #D67C1C !important; }
svg.inverted.bordered.brown.icon, svg.inverted.circular.brown.icon { background-color: #A5673F !important; color: #FFFFFF !important; }
/* Grey */
svg.grey.icon { color: #767676 !important; }
svg.inverted.grey.icon { color: #DCDDDE !important; }
svg.inverted.bordered.grey.icon, svg.inverted.circular.grey.icon { background-color: #767676 !important; color: #FFFFFF !important; }
/* Black */
svg.black.icon { color: #1B1C1D !important; }
svg.inverted.black.icon { color: #545454 !important; }
svg.inverted.bordered.black.icon, svg.inverted.circular.black.icon { background-color: #1B1C1D !important; color: #FFFFFF !important; }
/*------------------- Sizes
--------------------*/
svg.mini.icon, svg.mini.icons { line-height: 1; font-size: 0.4em; }
svg.tiny.icon, svg.tiny.icons { line-height: 1; font-size: 0.5em; }
svg.small.icon, svg.small.icons { line-height: 1; font-size: 0.75em; }
svg.icon, svg.icons { font-size: 1em; }
svg.large.icon, svg.large.icons { line-height: 1; vertical-align: middle; font-size: 1.5em; }
svg.big.icon, svg.big.icons { line-height: 1; vertical-align: middle; font-size: 2em; }
svg.huge.icon, svg.huge.icons { line-height: 1; vertical-align: middle; font-size: 4em; }
svg.massive.icon, svg.massive.icons { line-height: 1; vertical-align: middle; font-size: 8em; }
/******************************* Groups
*******************************/
svg.icons { display: inline-block; position: relative; line-height: 1; }
svg.icons .icon { position: absolute; top: 50%; left: 50%; -webkit-transform: translateX(-50%) translateY(-50%); transform: translateX(-50%) translateY(-50%); margin: 0em; margin: 0; }
svg.icons .icon:first-child { position: static; width: auto; height: auto; vertical-align: top; -webkit-transform: none; transform: none; margin-right: 0.25rem; }
/* Corner Icon */
svg.icons .corner.icon { top: auto; left: auto; right: 0; bottom: 0; -webkit-transform: none; transform: none; font-size: 0.45em; text-shadow: -1px -1px 0 #FFFFFF, 1px -1px 0 #FFFFFF, -1px 1px 0 #FFFFFF, 1px 1px 0 #FFFFFF; }
svg.icons .top.right.corner.icon { top: 0; left: auto; right: 0; bottom: auto; }
svg.icons .top.left.corner.icon { top: 0; left: 0; right: auto; bottom: auto; }
svg.icons .bottom.left.corner.icon { top: auto; left: 0; right: auto; bottom: 0; }
svg.icons .bottom.right.corner.icon { top: auto; left: auto; right: 0; bottom: 0; }
svg.icons .inverted.corner.icon { text-shadow: -1px -1px 0 #1B1C1D, 1px -1px 0 #1B1C1D, -1px 1px 0 #1B1C1D, 1px 1px 0 #1B1C1D; }
/*!
 * monokai original author: Wimer Hazenberg
 * theme modified from: https://github.com/richleland/pygments-css/blob/master/monokai.css
 * rules synced with rouge token types (see: https://github.com/jneen/rouge/blob/master/lib/rouge/token.rb)
 */
pre.highlight { background-color: #272822; color: #f8f8f2; padding: .5em; border-radius: .5em; }
.highlight .bp { color: #f8f8f2; }
/* Name.Builtin.Pseudo */
.highlight .c { color: #75715e; }
/* Comment */
.highlight .c1 { color: #75715e; }
/* Comment.Single */
.highlight .cd { color: #75715e; }
/* Comment.Doc */
.highlight .cm { color: #75715e; }
/* Comment.Multiline */
.highlight .cp { color: #75715e; }
/* Comment.Preproc */
.highlight .cs { color: #75715e; }
/* Comment.Special */
.highlight .err { color: #960050; background-color: #1e0010; }
/* Error */
.highlight .g { color: #66d9ef; }
/* Generic */
.highlight .gd { color: #f92672; }
/* Generic.Deleted */
.highlight .ge { font-style: italic; }
/* Generic.Emph */
.highlight .gh { color: #75715e; }
/* Generic.Heading */
.highlight .gi { color: #a6e22e; }
/* Generic.Inserted */
.highlight .gl { color: #66efd9; }
/* Generic.Lineno */
.highlight .go { color: #66d9ef; }
/* Generic.Output */
.highlight .gp { color: #66efd9; }
/* Generic.Prompt */
.highlight .gr { color: #960050; background-color: #1e0010; }
/* Generic.Error */
.highlight .gs { font-weight: bold; }
/* Generic.Strong */
.highlight .gt { color: #66efd9; }
/* Generic.Traceback */
.highlight .gu { color: #75715e; }
/* Generic.Subheading */
.highlight .il { color: #ae81ff; }
/* Literal.Number.Integer.Long */
.highlight .k { color: #66d9ef; }
/* Keyword */
.highlight .kc { color: #66d9ef; }
/* Keyword.Constant */
.highlight .kd { color: #66d9ef; }
/* Keyword.Declaration */
.highlight .kn { color: #f92672; }
/* Keyword.Namespace */
.highlight .kp { color: #66d9ef; }
/* Keyword.Pseudo */
.highlight .kr { color: #66d9ef; }
/* Keyword.Reserved */
.highlight .kt { color: #66d9ef; }
/* Keyword.Type */
.highlight .kv { color: #66d9ef; }
/* Keyword.Variable */
.highlight .l { color: #ae81ff; }
/* Literal */
.highlight .ld { color: #e6db74; }
/* Literal.Date */
.highlight .m { color: #ae81ff; }
/* Literal.Number */
.highlight .mb { color: #ae81ff; }
/* Literal.Number.Bin */
.highlight .mf { color: #ae81ff; }
/* Literal.Number.Float */
.highlight .mh { color: #ae81ff; }
/* Literal.Number.Hex */
.highlight .mi { color: #ae81ff; }
/* Literal.Number.Integer */
.highlight .mo { color: #ae81ff; }
/* Literal.Number.Oct */
.highlight .mx { color: #ae81ff; }
/* Literal.Number.Other */
.highlight .n { color: #f8f8f2; }
/* Name */
.highlight .na { color: #a6e22e; }
/* Name.Attribute */
.highlight .nb { color: #f8f8f2; }
/* Name.Builtin */
.highlight .nc { color: #a6e22e; }
/* Name.Class */
.highlight .nd { color: #a6e22e; }
/* Name.Decorator */
.highlight .ne { color: #a6e22e; }
/* Name.Exception */
.highlight .nf { color: #a6e22e; }
/* Name.Function */
.highlight .ni { color: #f8f8f2; }
/* Name.Entity */
.highlight .nl { color: #f8f8f2; }
/* Name.Label */
.highlight .nn { color: #f8f8f2; }
/* Name.Namespace */
.highlight .no { color: #66d9ef; }
/* Name.Constant */
.highlight .nt { color: #f92672; }
/* Name.Tag */
.highlight .nv { color: #f8f8f2; }
/* Name.Variable */
.highlight .nx { color: #a6e22e; }
/* Name.Other */
.highlight .o { color: #f92672; }
/* Operator */
.highlight .ow { color: #f92672; }
/* Operator.Word */
.highlight .p { color: #f8f8f2; }
/* Punctuation */
.highlight .pi { color: #f8f8f2; }
/* Punctuation.Indicator */
.highlight .py { color: #f8f8f2; }
/* Name.Property */
.highlight .s { color: #e6db74; }
/* Literal.String */
.highlight .s1 { color: #e6db74; }
/* Literal.String.Single */
.highlight .s2 { color: #e6db74; }
/* Literal.String.Double */
.highlight .sb { color: #e6db74; }
/* Literal.String.Backtick */
.highlight .sc { color: #e6db74; }
/* Literal.String.Char */
.highlight .sd { color: #e6db74; }
/* Literal.String.Doc */
.highlight .se { color: #ae81ff; }
/* Literal.String.Escape */
.highlight .sh { color: #e6db74; }
/* Literal.String.Heredoc */
.highlight .si { color: #e6db74; }
/* Literal.String.Interpol */
.highlight .sr { color: #e6db74; }
/* Literal.String.Regex */
.highlight .ss { color: #e6db74; }
/* Literal.String.Symbol */
.highlight .sx { color: #e6db74; }
/* Literal.String.Other */
.highlight .vc { color: #f8f8f2; }
/* Name.Variable.Class */
.highlight .vg { color: #f8f8f2; }
/* Name.Variable.Global */
.highlight .vi { color: #f8f8f2; }
/* Name.Variable.Instance */
.highlight .w { color: #f8f8f2; }
/* Text.Whitespace */
/* CSS customizations for the programming pages theme */
/* add cross-platform support for unicode characters used in the theme */
@font-face { font-family: 'progp-symbol'; src: url("fonts/progp-symbol.woff2") format("woff2");
  /* path relative to /assets/site.css */
unicode-range: U+2B8C;
  /* ⮌ | U+2B8C: ANTICLOCKWISE TRIANGLE-HEADED RIGHT U-SHAPED ARROW */ }
.reversefootnote { /* kramdown applies this class to footnote backlinks */ font-family: 'progp-symbol', 'Segoe UI Symbol', sans-serif; font-size: 80%; }
/* use flexbox to keep footer stuck to bottom */
.pusher { display: flex; min-height: 100vh; flex-direction: column; }
#page-container { flex: 1; }
/* toggle visibility of menu toggle / sidebar at 'mobile' width */
#site-title .toggle.item { display: none; }
#sidebar-fixed { height: 100%; max-height: 100vh; border-right: #F7F7F7 1px; border-right-style: none; border-style: inset;}
#sidebar-retractable { width: 15rem; }
.pusher #page-container { margin-left: 15rem; /* position page to left of sidebar when it's not retractable */ }
@media only screen and (max-width: 767px) { #site-title .toggle.item { display: flex; }
  .pusher #sidebar-fixed { display: none; }
  .pusher #page-container { margin-left: 0; } }
/* adjust anchor positions so in-page links appear below fixed top menu */
:target::before { display: block; content: " "; margin-top: -3.75rem; padding-top: 3.75rem; height: 3.75rem; visibility: hidden; pointer-events: none; }
sup:target::before { display: inline-block; margin-top: -5rem; padding-top: 5rem; height: 5rem; }
/* animate a highlight of the link target to help users orient to new location */
:target { animation: highlight 2.5s cubic-bezier(0.24, 0.01, 0.235, 0.995); /* https://matthewlein.com/tools/ceaser */ }
@keyframes highlight { 0% { text-shadow: -1px 0 0 rgba(255, 221, 0, 0.4), 0 1px 0 rgba(255, 221, 0, 0.4), 1px 0 0 rgba(255, 221, 0, 0.4); }
  20% { text-shadow: -3px 0 0 rgba(255, 221, 0, 0.8), 0 5px 0 rgba(255, 221, 0, 0.8), 3px 0 0 rgba(255, 221, 0, 0.8); }
  100% { text-shadow: -1px 0 0 rgba(255, 221, 0, 0), 0 1px 0 rgba(255, 221, 0, 0), 1px 0 0 rgba(255, 221, 0, 0); } }
/* adjustments to fixed top title */
#page-container { margin-top: 0 rem; /* position page under top menu */ }
#site-title .header { height: 3.5rem; }
#site-title a.borderless.item svg.icon { top: -.06em; margin-right: .18em; }
/* tighten things up as viewport shrinks */
#site-title { background-color: #eee; font-size: calc(14px + 4 * ((100vw - 320px) / (1910 - 320))); }
#site-title .header .text { max-width: calc(40vw); /* not to exceed 40% of viewport width */ width: min-content; /* but shrink to the smallest width needed by content, after wrapping */ }
@media only screen and (min-width: 768px) { #site-title .header .text { max-width: calc(60vw); /* grant up to 60% of viewport width */ width: max-content; /* and contract to the smallest width needed by content without wrapping */ } }
#site-title .borderless.item { padding-left: calc(1.5em + 2 * ((100vw - 320px) / (1910 - 320))); padding-right: .25em; }
/* sidebar menu styling */
#site-search { width: 12rem; margin-left: -.5rem; }
#site-search .results { overflow: auto; }
#site-search input { padding-left: 2em; }
#sidebar-collection-indices { padding-bottom: 75vh; /* add space underneath indices so bottom-most item can scroll into view */ }
#sidebar-collection-indices .ui.large.fixed.menu .item { padding-top: 1.4em; }
#sidebar-collection-indices .ui.tab.segment { /* adjust tab segment to to fit under n rendered collections */ top: 9rem; /* 1 -> 5 , 2 -> 6.5 , 3 -> 8 , .. */ padding: 0 0 0 .7em; margin-top: 0; }
#sidebar-collection-indices .ui.list .header.item { font-weight: normal; }
#sidebar-collection-tabs { background-color: {{ site.sidebar_highlight_color }}; }
#sidebar-fixed #sidebar-collection-indices .ui.large.fixed.menu { top: 0rem; /* for sidebar fixed, keep search and tabs fixed at top */ width: 15rem; }
#sidebar-fixed #sidebar-collection-tabs { top: 2.8rem; }
#sidebar-retractable #sidebar-collection-indices .ui.large.fixed.menu { top: 0; /* for sidebar retractable, items still need to be positioned, since they've been fixed */ }
#sidebar-retractable #sidebar-collection-tabs { top: 2.5rem; }
#sidebar-retractable.ui.push.sidebar { z-index: 100; /* underneath top fixed menu */ }
#sidebar-retractable.ui.menu { top: 3.5rem; /* below top fixed menu */ }
#sidebar-fixed.ui.menu { position: fixed; top: 0rem; left: auto; }
.ui.menu { min-height: 1em; /* SUI default is too large for a single item, at 2.75em */ }
/* tweaks to existing semantic-ui rules */
.ui.secondary.pointing.menu .item { padding: .5em .75em; }
.ui.secondary.vertical.pointing.menu .item { border-bottom: none; /*            same as sui */ border-radius: 0 !important; /*     ''          */ border-right: none; /*             switch border from right to left */ border-left-style: solid; border-left-color: transparent; border-left-width: 2px; margin: 0 0 0 -2px; }
.ui.vertical.text.menu .tight.item { margin: 0; padding: .5em; }
.ui.vertical.text.menu .very.tight.item { margin: 0; padding: .125em; }
.ui.segment { overflow-x: auto; }
.ui.tight.header { margin-bottom: .5em; }
.ui.very.tight.header { margin-bottom: .25em; }
.ui.tight.segment { padding: .5em; }
.ui.tight.label { padding: .25em; }
.ui.message { max-width: 45rem; }
.ui.message svg.icon { top: .125em; }
.ui.success.message, .ui.info.message, .ui.warning.message, .ui.error.message { border-left-style: solid; border-left-width: .25em; }
/* custom styling */
blockquote { background: #f9f9f9; border-left: .5em solid #4183c4; margin: 1.5em .5em; padding: .5em .5em; }
blockquote p { display: inline; }
code, pre, samp { font-family: Consolas,'Lucida Console','Andale Mono',monospace; }
code.highlighter-rouge { padding: 2px 4px; font-size: 90%; color: #d87b00; background-color: #f5f4e8; border-radius: 4px; overflow-x: auto; width: fit-content; max-width: 100%; }
pre.highlight { line-height: 1.18em; overflow-x: auto; width: fit-content; max-width: 100%; }
.example.segment { min-height: 4rem; background-color: transparent; }
.collapsible.example { display: block; }
.collapsible.example.collapsed { display: none; }
.larger.text { font-size: 150%; }
.larger.text li, p.larger.text { line-height: 130%; max-width: 50rem; }
.smaller.text { font-size: 80%; }
.smaller.text li, p.smaller.text { line-height: 90%; }
.normal.text { font-weight: normal; }
.ui.tab.segment .link.list .item > .icon { float: right; }
.ui.list .item > .icon { float: left; }
/* CSS customizations  this file is included after all other stye sheet files you can add rules here that will take precedence over any already defined by the theme */
